(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     11566,        377]*)
(*NotebookOutlinePosition[     12249,        400]*)
(*  CellTagsIndexPosition[     12205,        396]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Algebra calculations", "Section"]], "Chapter"],

Cell["Tens3D provides tools for tensorial algebra calculations.", "Text",
  CellDingbat->None],

Cell[TextData[{
  "You can define tensors by components in any variances and  in any basis \
with ",
  StyleBox[ButtonBox["DefineTensor",
    ButtonData:>{"DefineTensor", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["DefineGeneralTensor",
    ButtonData:>{"DefineGeneralTensor", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " and you can test if a symbol is a Tens3D tensor with ",
  StyleBox[ButtonBox["Tens3DQ",
    ButtonData:>{"Tens3DQ", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ".\nThe rank of a tensor is given by ",
  StyleBox[ButtonBox["Rank",
    ButtonData:>{"Rank", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "If the components are functions of variables , the tensor is variable and \
can be derivated with the ",
  ButtonBox["partial derivative function ",
    ButtonData:>{"Deriv", None},
    ButtonStyle->"AddOnsLink"],
  StyleBox[ButtonBox["D",
    ButtonData:>{"Derivative", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "You can define a new basis with ",
  StyleBox[ButtonBox["DefineBasis",
    ButtonData:>{"DefineBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " and test if a symbol is a Tens3D basis with ",
  StyleBox[ButtonBox["BasisQ",
    ButtonData:>{"BasisQ", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ".\nYou can extract the basis vectors of a basis with ",
  StyleBox[ButtonBox["BasisVectors",
    ButtonData:>{"BasisVectors", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " ou ",
  StyleBox[ButtonBox["DualBasisVectors",
    ButtonData:>{"BasisVectors", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ".\nYou can normalize the vectors of a basis with ",
  StyleBox[ButtonBox["NormalizedBasis",
    ButtonData:>{"NormalizedBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ",\nSee also ",
  StyleBox[ButtonBox["DefineCoordinateSystem",
    ButtonData:>{"DefineCoordinateSystem", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "You can display components of a tensor in any variances and in any basis \
with ",
  StyleBox[ButtonBox["Components",
    ButtonData:>{"Components", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " ."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "You can define tensors with algebraic operations on tensors :\n\tAddition \
: ",
  Cell[BoxData[
      \(TraditionalForm\`\[CirclePlus]\)]],
  " (",
  StyleBox[ButtonBox["CirclePlus",
    ButtonData:>{"CirclePlus", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "),\n\tSubstraction : ",
  Cell[BoxData[
      \(TraditionalForm\`\[CircleMinus]\)]],
  " (",
  StyleBox[ButtonBox["CircleMinus",
    ButtonData:>{"CircleMinus", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "),\n\tProduct by a scalar :  \[SmallCircle] (",
  StyleBox[ButtonBox["SmallCircle",
    ButtonData:>{"SmallCircle", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "),\n\tTensorial product : ",
  Cell[BoxData[
      \(TraditionalForm\`\[CircleTimes]\)]],
  " (",
  StyleBox[ButtonBox["CircleTimes",
    ButtonData:>{"CircleTimes", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "),\n\tSeveral contracted products :  . (",
  StyleBox[ButtonBox["Dot",
    ButtonData:>{"Contracted", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "),   \[Colon] (",
  StyleBox[ButtonBox["Colon",
    ButtonData:>{"Contracted", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "),   \[Therefore] (",
  StyleBox[ButtonBox["Therefore",
    ButtonData:>{"Contracted", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "),  and  \[Proportion] (",
  StyleBox[ButtonBox["Proportion",
    ButtonData:>{"Contracted", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ")\n\tContraction of a tensor : ",
  StyleBox[ButtonBox["AutoContract",
    ButtonData:>{"AutoContract", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ",\n\tEuclidian norm : ",
  StyleBox[ButtonBox["EuclidianNorm",
    ButtonData:>{"EuclidianNorm", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ",\n\tCrossproduct of vectors : ",
  Cell[BoxData[
      \(TraditionalForm\`\[Wedge]\)]],
  " (",
  StyleBox[ButtonBox["Wedge",
    ButtonData:>{"Wedge", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ").\n\t\nFollowing operations are specific to rank 2 tensors :\n\t\
Invariants : \n\t\t- ",
  StyleBox[ButtonBox["FirstInvariant",
    ButtonData:>{"Invariant", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["I1",
    ButtonData:>{"Invariant", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", or ",
  ButtonBox["J1,",
    ButtonData:>{"Invariant", None},
    ButtonStyle->"AddOnsLink"],
  "\n\t\t- ",
  StyleBox[ButtonBox["SecondInvariant",
    ButtonData:>{"Invariant", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["I2",
    ButtonData:>{"Invariant", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", or",
  ButtonBox[" J2",
    ButtonData:>{"Invariant", None},
    ButtonStyle->"AddOnsLink"],
  ",\n\t\t- ",
  StyleBox[ButtonBox["ThirdInvariant",
    ButtonData:>{"Invariant", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  ButtonBox["I3",
    ButtonData:>{"Invariant", None},
    ButtonStyle->"AddOnsLink"],
  " or ",
  StyleBox[ButtonBox["Det",
    ButtonData:>{"Det", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  StyleBox[", or ",
    FontFamily->"Times New Roman"],
  ButtonBox["J3",
    ButtonData:>{"Invariant", None},
    ButtonStyle->"AddOnsLink"],
  StyleBox[",",
    FontFamily->"Times New Roman"],
  "\n\tDeterminant : ",
  ButtonBox["Det",
    ButtonData:>{"Det", None},
    ButtonStyle->"AddOnsLink"],
  ",\n\tTransposition : ",
  StyleBox[ButtonBox["Transpose",
    ButtonData:>{"Transpose", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "\n\tSymmetric part : ",
  StyleBox[ButtonBox["SymmetricPart",
    ButtonData:>{"SymmetricT3D", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["Sym",
    ButtonData:>{"SymmetricT3D", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ",\n\tAntisymmetric part : ",
  StyleBox[ButtonBox["AntisymmetricPart",
    ButtonData:>{"SymmetricT3D", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["Asym",
    ButtonData:>{"SymmetricT3D", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ",\n\tSpherical part : ",
  StyleBox[ButtonBox["SphericalPart",
    ButtonData:>{"Spheric", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["Sph",
    ButtonData:>{"Spheric", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ",\n\tTraceless part : ",
  StyleBox[ButtonBox["TracelessPart",
    ButtonData:>{"Spheric", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  ButtonBox["Dev",
    ButtonData:>{"Spheric", None},
    ButtonStyle->"AddOnsLink"],
  ",\n\tPolar decomposition : ",
  StyleBox[ButtonBox["RightPolarDecomposition",
    ButtonData:>{"PolarDecomposition", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["LeftPolarDecomposition",
    ButtonData:>{"PolarDecomposition", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ",\n\tEven rank identityTensor : ",
  StyleBox[ButtonBox["IdentityTensor",
    ButtonData:>{"Identity", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ",\n\tOrthogonal tensors : ",
  StyleBox[ButtonBox["DefineOrthogonalTensor",
    ButtonData:>{"Orthogonal", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["IdentifyOrthogonalTensor",
    ButtonData:>{"Orthogonal", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "\nFollowing functions are specific to even rank tensors :\n\tEigen system \
: ",
  StyleBox[ButtonBox["Eigensystem",
    ButtonData:>{"Eigen", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["Eigenvalues",
    ButtonData:>{"Eigen", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["Eigentensors",
    ButtonData:>{"Eigen", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ","
}], "Text"],

Cell[TextData[{
  "\tInverse : ",
  StyleBox[ButtonBox["Inverse",
    ButtonData:>{"Inverse", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ","
}], "Text"],

Cell[TextData[{
  "See also ",
  StyleBox[ButtonBox["Analysis calculations",
    ButtonData:>{"Analysis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Times New Roman"],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{724, 740},
WindowMargins->{{Automatic, 165}, {Automatic, 43}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 70, 0, 105, "Chapter"],
Cell[1849, 55, 94, 1, 29, "Text"],
Cell[1946, 58, 816, 24, 75, "Text"],
Cell[2765, 84, 378, 11, 48, "Text"],
Cell[3146, 97, 1160, 33, 110, "Text"],
Cell[4309, 132, 291, 9, 29, "Text"],
Cell[4603, 143, 6025, 193, 650, "Text"],
Cell[10631, 338, 533, 18, 83, "Text"],
Cell[11167, 358, 182, 7, 29, "Text"],
Cell[11352, 367, 198, 7, 29, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

