(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6117,        188]*)
(*NotebookOutlinePosition[      6801,        211]*)
(*  CellTagsIndexPosition[      6757,        207]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Analysis calculations", "Section"],

Cell[TextData[{
  "Tens3D provides analysis tools on three dimensional tensorial fields using \
any coordinates system.\n\nTens3D tensorial fields are tensors varying with \
the coordinates of a point ",
  StyleBox["M",
    FontSlant->"Italic"],
  " \[Element] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalE]\_3\)]],
  ", a mapping ",
  StyleBox["M",
    FontSlant->"Italic"],
  " \[LongRightArrow] ",
  StyleBox["T",
    FontSlant->"Italic"],
  "(",
  StyleBox["M",
    FontSlant->"Italic"],
  ").\nTo identify the point ",
  StyleBox["M",
    FontSlant->"Italic"],
  " you may use any coordinates system. \n\nA coordinates system is a mapping \
  (",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`c\_3\)]],
  ") \[Element] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalR]\^3\)]],
  " \[LongRightArrow] ",
  StyleBox["M ",
    FontSlant->"Italic"],
  "\[Element] ",
  Cell[BoxData[
      \(TraditionalForm\`\[DoubleStruckCapitalE]\_3\)]],
  ". The three real numbers ",
  Cell[BoxData[
      \(TraditionalForm\`c\_1\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`c\_2\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`c\_3\)]],
  " are called coordinates of ",
  StyleBox["M",
    FontSlant->"Italic"],
  ". Defining a coordinate system is simply giving the rules of this mapping.\
\n\nBefore using analysis tools you have to define the coordinate system you \
want with ",
  StyleBox[ButtonBox["DefineCoordinateSystem",
    ButtonData:>{"DefineCoordinateSystem", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ".\nThis function returns the natural basis of the coordinate system. You \
may show the Christoffel coefficients with ",
  StyleBox[ButtonBox["PrintChristoffel",
    ButtonData:>{"Christoffel", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["ChristoffelArray",
    ButtonData:>{"Christoffel", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ".\n\nGenerally, the vectors of a natural basis of a coordinates system are \
not orthogonal and not unit vectors. You may use ",
  StyleBox[ButtonBox["NormalizedBasis",
    ButtonData:>{"NormalizedBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " to generate a colinear normalized basis.\n\nOnce you have defined a \
coordinate system, you can use the classic differential operators ",
  StyleBox[ButtonBox["Gradient",
    ButtonData:>{"Gradient", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["Divergence",
    ButtonData:>{"Divergence", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["Curl",
    ButtonData:>{"Curl", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " and ",
  StyleBox[ButtonBox["Laplacian",
    ButtonData:>{"Laplacian", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ". These operators acts on any rank (include 0) tensorial fields (see ",
  StyleBox[ButtonBox["DefineTensor",
    ButtonData:>{"DefineTensor", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " and ",
  StyleBox[ButtonBox["DefineGeneralTensor",
    ButtonData:>{"DefineGeneralTensor", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ").\n\nYou can easily write the intrinsic differential equations of the \
most problems in classical physics. Classical differential equations systems \
are simply obtained with ",
  StyleBox[ButtonBox["Components",
    ButtonData:>{"Components", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " of these tensors on a basis.\n\nA compact notation of differential \
equations may be obtained with ",
  StyleBox[ButtonBox["CompactDerivativeForm",
    ButtonData:>{"CompactDerivativeForm", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "."
}], "Text"],

Cell[TextData[{
  "See also ",
  StyleBox[ButtonBox["Algebra calculations",
    ButtonData:>{"Algebraic", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Times New Roman"],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{831, 740},
WindowMargins->{{115, Automatic}, {Automatic, 56}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 40, 0, 80, "Section"],
Cell[1819, 55, 4081, 121, 575, "Text"],
Cell[5903, 178, 198, 7, 29, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

