(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8458,        312]*)
(*NotebookOutlinePosition[      9140,        335]*)
(*  CellTagsIndexPosition[      9096,        331]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["AutoContract",
  FontFamily->"Courier New"]], "Subsection"],

Cell[TextData[{
  StyleBox["AutoContract[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["i1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["i2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  returns the Tens3D tensor obtained by autocontraction on indices ",
  StyleBox["i1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i2",
    FontSlant->"Italic"],
  "."
}], "DefinitionBox"],

Cell[TextData[{
  "The result is a ",
  StyleBox["Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]-2",
    FontFamily->"Courier New"],
  " tensor."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "If",
  StyleBox[" Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]=2",
    FontFamily->"Courier New"],
  ", the result is a scalar. This is the trace of the tensor."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "If",
  StyleBox[" Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]<2",
    FontFamily->"Courier New"],
  ",  ",
  StyleBox["AutoContract",
    FontFamily->"Courier New"],
  " remains unvaluated."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "Indices ",
  StyleBox["i1",
    FontSlant->"Italic"],
  " and ",
  StyleBox["i2",
    FontSlant->"Italic"],
  " are optional. They must be two different integers in the range ",
  StyleBox["[1,Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier New"],
  StyleBox[". Default values are ",
    FontFamily->"Times New Roman"],
  StyleBox["i1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["=1",
    FontFamily->"Courier New"],
  StyleBox[" and ",
    FontFamily->"Times New Roman"],
  StyleBox["i2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox["=2",
    FontFamily->"Courier New"],
  StyleBox[". So you can use it in postfix form.",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "If an argument is invalid ",
  StyleBox["AutoContract",
    FontFamily->"Courier New"],
  " remains unvaluated."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(Needs["\<Tens3D`\>"]\)], "Input",
  CellLabel->"In[1]:=",
  CellFrame->{{0, 0}, {0, 0.5}}],

Cell["We define a rank 2 tensor :", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(t =. ;\)\), "\[IndentingNewLine]", 
    \(\(T = 
        DefineGeneralTensor[t, {1, 1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(T // Components\) // MatrixForm\)}], "Input",
  CellLabel->"In[2]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[2]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"t11", "t12", "t13"},
            {"t21", "t22", "t23"},
            {"t31", "t32", "t33"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[4]//MatrixForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["AutoContract",
        FontFamily->"Courier New"], "[", "T", "]"}]], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \(t11 + t22 + t33\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["AutoContract",
        FontFamily->"Courier New"], "[", \(T, 1, 2\), "]"}]], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \(t11 + t22 + t33\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["Now, we define a non orthonormal basis B :", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(v1 = 
        DefineTensor[{0, 1, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v2 = 
        DefineTensor[{1, 0, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v3 = 
        DefineTensor[{1, 1, 0}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(B = DefineBasis[v1, v2, v3];\)\)}], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \("Direct basis."\)], "Print",
  CellLabel->"From In[7]:="]
}, Open  ]],

Cell["\<\
and a rank 2 tensor by its contravariant-contravariant components :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{\(u =. ;\), "\[IndentingNewLine]", \(U = 
        DefineGeneralTensor[u, {1, 1}, B];\), "\[IndentingNewLine]", 
    RowBox[{
      StyleBox["AutoContract",
        FontFamily->"Courier New"], "[", "U", "]"}]}], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(2\ u11 + u12 + u13 + u21 + 2\ u22 + u23 + u31 + u32 + 
      2\ u33\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["The auto contraction of a rank 3 tensor is a vector :", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{\(v =. ;\), "\[IndentingNewLine]", \(V = 
        DefineGeneralTensor[v, {1, 1, \(-1\)}, B];\), "\[IndentingNewLine]", 
    RowBox[{
      RowBox[{"Components", "[", " ", 
        RowBox[{
          RowBox[{
            StyleBox["AutoContract",
              FontFamily->"Courier New"], "[", \(V, 2, 3\), "]"}], " ", 
          ",", \({1}\), ",", "B"}], "]"}], " ", "//", " ", 
      "MatrixForm"}]}], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(v111 + v122 + v133\)},
              {\(v211 + v222 + v233\)},
              {\(v311 + v322 + v333\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[16]//MatrixForm=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{725, 740},
WindowMargins->{{Automatic, 99}, {26, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 83, 1, 47, "Subsection"],
Cell[1862, 56, 654, 25, 69, "DefinitionBox"],
Cell[2519, 83, 280, 11, 29, "Text"],
Cell[2802, 96, 317, 11, 29, "Text"],
Cell[3122, 109, 347, 14, 29, "Text"],
Cell[3472, 125, 944, 34, 49, "Text"],
Cell[4419, 161, 177, 6, 29, "Text"],
Cell[4599, 169, 110, 3, 44, "Input"],
Cell[4712, 174, 77, 1, 29, "Text"],

Cell[CellGroupData[{
Cell[4814, 179, 245, 6, 75, "Input"],
Cell[5062, 187, 220, 5, 27, "Print"],
Cell[5285, 194, 411, 12, 81, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5733, 211, 144, 4, 33, "Input"],
Cell[5880, 217, 73, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5990, 224, 152, 4, 33, "Input"],
Cell[6145, 230, 73, 2, 32, "Output"]
}, Open  ]],
Cell[6233, 235, 92, 1, 29, "Text"],

Cell[CellGroupData[{
Cell[6350, 240, 415, 11, 96, "Input"],
Cell[6768, 253, 77, 2, 27, "Print"]
}, Open  ]],
Cell[6860, 258, 91, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[6976, 264, 258, 5, 75, "Input"],
Cell[7237, 271, 126, 3, 32, "Output"]
}, Open  ]],
Cell[7378, 277, 103, 1, 29, "Text"],

Cell[CellGroupData[{
Cell[7506, 282, 449, 10, 75, "Input"],
Cell[7958, 294, 472, 14, 92, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

