(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8095,        308]*)
(*NotebookOutlinePosition[     10702,        391]*)
(*  CellTagsIndexPosition[     10632,        385]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["BasisVectors\nDualBasisVectors",
  FontFamily->"Courier New"]], "Subsection",
  CellTags->"b:0.1"],

Cell[TextData[{
  StyleBox["BasisVectors[",
    FontFamily->"Courier New"],
  StyleBox["basis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  "returns the list of the three Tens3D vectors of the Tens3D basis  (created \
with ",
  StyleBox[ButtonBox["DefineBasis",
    ButtonData:>{"DefineBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["NormalizedBasis",
    ButtonData:>{"NormalizedBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["DefineCoordinateSystem",
    ButtonData:>{"DefineCoordinateSystem", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ") .\n\n",
  StyleBox["DualBasisVectors[",
    FontFamily->"Courier New"],
  StyleBox["basis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  " returns the list of the three Tens3D vectors of the dual basis of  ",
  StyleBox["basis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  "."
}], "DefinitionBox",
  CellTags->"b:0.1"],

Cell[TextData[{
  StyleBox["BasisVectors[",
    FontFamily->"Courier New"],
  StyleBox["basis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  StyleBox["and",
    FontFamily->"Times New Roman"],
  StyleBox[" DualBasisVectors[",
    FontFamily->"Courier New"],
  StyleBox["basis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  StyleBox["remain unevaluated if ",
    FontFamily->"Times New Roman"],
  StyleBox["basis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" is not a Tens3D basis. ",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[27]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.1"],

Cell[TextData[{
  "The three vectors of ",
  StyleBox[ButtonBox["CanonicalBasis",
    ButtonData:>{"Predef", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " are :"
}], "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \({e1, e2, e3} = BasisVectors[CanonicalBasis]\)], "Input",
  CellLabel->"In[28]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \({Tens3D`Private`Tensor$407, Tens3D`Private`Tensor$408, 
      Tens3D`Private`Tensor$409}\)], "Output",
  CellLabel->"Out[28]=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(e1 // Components\)], "Input",
  CellLabel->"In[29]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[29]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \({1, 0, 0}\)], "Output",
  CellLabel->"Out[29]=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[TextData[{
  "The following basis ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " is not orthonormal :"
}], "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(v1 = 
        DefineTensor[{0, 1, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v2 = 
        DefineTensor[{1, 0, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v3 = 
        DefineTensor[{1, 1, 0}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(B = DefineBasis[v1, v2, v3];\)\), "\[IndentingNewLine]", 
    \(\(L = BasisVectors[B];\)\)}], "Input",
  CellLabel->"In[30]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \("Direct basis."\)], "Print",
  CellLabel->"From In[30]:=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[TextData[{
  "The first vector of list ",
  StyleBox["L", "Input"],
  " is ",
  StyleBox["v1", "Input"],
  " :"
}], "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(L[\([1]\)]\ \[CircleMinus]\ v1\  // Components\)], "Input",
  CellLabel->"In[35]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[35]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output",
  CellLabel->"Out[35]=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell["We verify that the  basis B is not orthonormal :", "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \({v1 . v1, v1 . v2}\)], "Input",
  CellLabel->"In[36]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \({2, 1}\)], "Output",
  CellLabel->"Out[36]=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell["The vectors of the (non orthonormal) dual basis are :", "Text",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(\({V1, V2, V3} = DualBasisVectors[B];\)\)], "Input",
  CellLabel->"In[37]:=",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \({V1 . v1, V1 . v2, V1 . v3}\)], "Input",
  CellLabel->"In[38]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \({1, 0, 0}\)], "Output",
  CellLabel->"Out[38]=",
  CellTags->"b:0.1"]
}, Open  ]],

Cell["\<\
We verify that the covariant components of a vector are the scalar products \
of  the vector with the basis : \
\>", "Text",
  CellTags->"b:0.1"],

Cell[BoxData[
    \(\(vec = DefineTensor[{a, b, c}, {1}, B];\)\)], "Input",
  CellLabel->"In[39]:=",
  CellTags->"b:0.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ vec . 
          v1 \[Equal] \(Components[vec, {\(-1\)}, 
            B]\)[\([1]\)]\ , \[IndentingNewLine]\ 
      vec . v2 \[Equal] \(Components[vec, {\(-1\)}, 
            B]\)[\([2]\)]\ , \[IndentingNewLine]\ 
      vec . v3 \[Equal] \(Components[vec, {\(-1\)}, 
            B]\)[\([3]\)]\ }\)], "Input",
  CellLabel->"In[40]:=",
  CellTags->"b:0.1"],

Cell[BoxData[
    \({True, True, True}\)], "Output",
  CellLabel->"Out[40]=",
  CellFrame->{{0, 0}, {0.5, 0}},
  CellTags->"b:0.1"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{697, 740},
WindowMargins->{{Automatic, 116}, {97, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.1"->{
    Cell[1776, 53, 122, 2, 72, "Subsection",
      CellTags->"b:0.1"],
    Cell[1901, 57, 1168, 38, 126, "DefinitionBox",
      CellTags->"b:0.1"],
    Cell[3072, 97, 749, 26, 48, "Text",
      CellTags->"b:0.1"],
    Cell[3824, 125, 137, 4, 44, "Input",
      CellTags->"b:0.1"],
    Cell[3964, 131, 257, 9, 29, "Text",
      CellTags->"b:0.1"],
    Cell[4246, 144, 122, 3, 33, "Input",
      CellTags->"b:0.1"],
    Cell[4371, 149, 168, 4, 53, "Output",
      CellTags->"b:0.1"],
    Cell[4576, 158, 95, 3, 33, "Input",
      CellTags->"b:0.1"],
    Cell[4674, 163, 242, 6, 27, "Print",
      CellTags->"b:0.1"],
    Cell[4919, 171, 89, 3, 32, "Output",
      CellTags->"b:0.1"],
    Cell[5023, 177, 182, 7, 29, "Text",
      CellTags->"b:0.1"],
    Cell[5230, 188, 495, 13, 117, "Input",
      CellTags->"b:0.1"],
    Cell[5728, 203, 99, 3, 27, "Print",
      CellTags->"b:0.1"],
    Cell[5842, 209, 149, 7, 33, "Text",
      CellTags->"b:0.1"],
    Cell[6016, 220, 125, 3, 33, "Input",
      CellTags->"b:0.1"],
    Cell[6144, 225, 242, 6, 27, "Print",
      CellTags->"b:0.1"],
    Cell[6389, 233, 89, 3, 32, "Output",
      CellTags->"b:0.1"],
    Cell[6493, 239, 85, 1, 29, "Text",
      CellTags->"b:0.1"],
    Cell[6603, 244, 97, 3, 33, "Input",
      CellTags->"b:0.1"],
    Cell[6703, 249, 86, 3, 32, "Output",
      CellTags->"b:0.1"],
    Cell[6804, 255, 90, 1, 29, "Text",
      CellTags->"b:0.1"],
    Cell[6897, 258, 118, 3, 33, "Input",
      CellTags->"b:0.1"],
    Cell[7040, 265, 106, 3, 33, "Input",
      CellTags->"b:0.1"],
    Cell[7149, 270, 89, 3, 32, "Output",
      CellTags->"b:0.1"],
    Cell[7253, 276, 155, 4, 48, "Text",
      CellTags->"b:0.1"],
    Cell[7411, 282, 121, 3, 33, "Input",
      CellTags->"b:0.1"],
    Cell[7557, 289, 376, 9, 75, "Input",
      CellTags->"b:0.1"],
    Cell[7936, 300, 131, 4, 43, "Output",
      CellTags->"b:0.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.1", 8724, 324}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 122, 2, 72, "Subsection",
  CellTags->"b:0.1"],
Cell[1901, 57, 1168, 38, 126, "DefinitionBox",
  CellTags->"b:0.1"],
Cell[3072, 97, 749, 26, 48, "Text",
  CellTags->"b:0.1"],
Cell[3824, 125, 137, 4, 44, "Input",
  CellTags->"b:0.1"],
Cell[3964, 131, 257, 9, 29, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[4246, 144, 122, 3, 33, "Input",
  CellTags->"b:0.1"],
Cell[4371, 149, 168, 4, 53, "Output",
  CellTags->"b:0.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4576, 158, 95, 3, 33, "Input",
  CellTags->"b:0.1"],
Cell[4674, 163, 242, 6, 27, "Print",
  CellTags->"b:0.1"],
Cell[4919, 171, 89, 3, 32, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[5023, 177, 182, 7, 29, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[5230, 188, 495, 13, 117, "Input",
  CellTags->"b:0.1"],
Cell[5728, 203, 99, 3, 27, "Print",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[5842, 209, 149, 7, 33, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[6016, 220, 125, 3, 33, "Input",
  CellTags->"b:0.1"],
Cell[6144, 225, 242, 6, 27, "Print",
  CellTags->"b:0.1"],
Cell[6389, 233, 89, 3, 32, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[6493, 239, 85, 1, 29, "Text",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[6603, 244, 97, 3, 33, "Input",
  CellTags->"b:0.1"],
Cell[6703, 249, 86, 3, 32, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[6804, 255, 90, 1, 29, "Text",
  CellTags->"b:0.1"],
Cell[6897, 258, 118, 3, 33, "Input",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[7040, 265, 106, 3, 33, "Input",
  CellTags->"b:0.1"],
Cell[7149, 270, 89, 3, 32, "Output",
  CellTags->"b:0.1"]
}, Open  ]],
Cell[7253, 276, 155, 4, 48, "Text",
  CellTags->"b:0.1"],
Cell[7411, 282, 121, 3, 33, "Input",
  CellTags->"b:0.1"],

Cell[CellGroupData[{
Cell[7557, 289, 376, 9, 75, "Input",
  CellTags->"b:0.1"],
Cell[7936, 300, 131, 4, 43, "Output",
  CellTags->"b:0.1"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

