(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7637,        223]*)
(*NotebookOutlinePosition[      8428,        252]*)
(*  CellTagsIndexPosition[      8358,        246]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["PrintCristoffel\nChristoffelArray",
  FontFamily->"Courier New"]], "Subsection"],

Cell[TextData[{
  StyleBox["PrintChristoffel[",
    FontFamily->"Courier New"],
  StyleBox["coordinatesystem",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  prints the Christoffel's coefficients of the Tens3D coordinates system.\n\
\n",
  StyleBox["ChristoffelArray[",
    FontFamily->"Courier New"],
  StyleBox["coordinatesystem",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  returns  the 3\[Times]3\[Times]3 Array containing the Christoffel's \
coefficients of the Tens3D coordinates system."
}], "DefinitionBox"],

Cell[TextData[{
  StyleBox["coordinatesystem",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " ",
  StyleBox[" ",
    FontSlant->"Italic"],
  "is a previously defined Tens3D coordinates system. (with ",
  StyleBox[ButtonBox["DefineCoordinateSystem",
    ButtonData:>{"DefineCoordinateSystem", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ") ",
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "Christoffel' coefficients  are the contravariant components of the \
derivatives of the vectors of the natural basis :",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          StyleBox[\(\[CapitalGamma]\_ij\%k\),
            FontFamily->"Courier New"]}], TraditionalForm]]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`k\^th\)]],
  " contravariant component in the natural basis of ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\_i\ e\_j\)]],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "Christoffel's coefficients are not components of a tensor. They have the \
symmetry ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[CapitalGamma]\_ij\%k\),
          FontFamily->"Courier New"], TraditionalForm]]],
  "=",
  Cell[BoxData[
      FormBox[
        StyleBox[\(\[CapitalGamma]\_ji\%k\),
          FontFamily->"Courier New"], TraditionalForm]]],
  "."
}], "Text",
  CellDingbat->"\[GraySquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[12]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.7"],

Cell[TextData[{
  "We define the classical cylindrical coordinates system :\na point M is \
function of coordinates ",
  StyleBox["{r,\[Theta],z}",
    FontFamily->"Courier New"],
  " :"
}], "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(r =. ; \[Theta] =. ; z =. ; \ 
    coords = {r, \[Theta], z};\), "\[IndentingNewLine]", 
    \(\($Assumptions = $Assumptions\  && \ 
          r > 0;\)\), "\[IndentingNewLine]", 
    \(\(OM = 
        DefineTensor[{r\ Cos[\[Theta]], r\ Sin[\[Theta]], z}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(cyl = DefineCoordinateSystem[OM, coords];\)\)}], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \("Direct orthogonal natural basis."\)], "Print",
  CellLabel->"From In[13]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(PrintChristoffel[cyl]\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    TagBox[\(\[CapitalGamma]\_rr\%r = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_r\[Theta]\%r = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_rz\%r = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_rr\%\[Theta] = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_r\[Theta]\%\[Theta] = \
\(1\/r\) \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_rz\%\[Theta] = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_rr\%z = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_r\[Theta]\%z = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_rz\%z = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_\[Theta]r\%r = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_\[Theta]\[Theta]\%r = \
\(-r\) \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_\[Theta]z\%r = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_\[Theta]r\%\[Theta] = \
\(1\/r\) \(\(\ \)\(\(,\)\(\ \)\)\) \
\[CapitalGamma]\_\[Theta]\[Theta]\%\[Theta] = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_\[Theta]z\%\[Theta] = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_\[Theta]r\%z = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_\[Theta]\[Theta]\%z = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_\[Theta]z\%z = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_zr\%r = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_z\[Theta]\%r = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_zz\%r = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_zr\%\[Theta] = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_z\[Theta]\%\[Theta] = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_zz\%\[Theta] = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_zr\%z = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_z\[Theta]\%z = 
        0 \(\(\ \)\(\(,\)\(\ \)\)\) \[CapitalGamma]\_zz\%z = 0\),
      DisplayForm]], "Print",
  CellLabel->"From In[17]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ChristoffelArray[cyl]\)], "Input",
  CellLabel->"In[18]:="],

Cell[BoxData[
    InterpretationBox[\("Note : Indices : "\[InvisibleSpace]{r, \[Theta], 
          z}\[InvisibleSpace]" , First(down) , Second(up) , Third(down)"\),
      SequenceForm[ 
      "Note : Indices : ", {r, \[Theta], z}, 
        " , First(down) , Second(up) , Third(down)"],
      Editable->False]], "Print",
  CellLabel->"From In[18]:="],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 1\/r, 0}, {0, 0, 0}}, {{0, \(-r\), 0}, {1\/r, 0, 
          0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\)], "Output",
  CellLabel->"Out[18]=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{643, 740},
WindowMargins->{{52, Automatic}, {Automatic, 58}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.7"->{
    Cell[3958, 128, 137, 4, 44, "Input",
      CellTags->"b:0.7"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.7", 8265, 239}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 104, 1, 72, "Subsection"],
Cell[1883, 56, 652, 19, 126, "DefinitionBox"],
Cell[2538, 77, 440, 15, 48, "Text"],
Cell[2981, 94, 541, 16, 49, "Text"],
Cell[3525, 112, 430, 14, 30, "Text"],
Cell[3958, 128, 137, 4, 44, "Input",
  CellTags->"b:0.7"],
Cell[4098, 134, 232, 7, 56, "Text"],

Cell[CellGroupData[{
Cell[4355, 145, 428, 9, 117, "Input"],
Cell[4786, 156, 97, 2, 27, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4920, 163, 79, 2, 33, "Input"],
Cell[5002, 167, 1917, 30, 185, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6956, 202, 79, 2, 33, "Input"],
Cell[7038, 206, 349, 7, 48, "Print"],
Cell[7390, 215, 219, 4, 120, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

