(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9315,        304]*)
(*NotebookOutlinePosition[     11461,        373]*)
(*  CellTagsIndexPosition[     11391,        367]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["CirclePlus",
    FontFamily->"Courier New"],
  " or ",
  Cell[BoxData[
      \(TraditionalForm\`\[CirclePlus]\)]]
}], "Subsection",
  CellTags->"b:0.3"],

Cell[TextData[{
  StyleBox["CirclePlus[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  or  ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"\[CirclePlus]", " ", 
            StyleBox["tensor2",
              FontFamily->"Times New Roman",
              FontSlant->"Italic"]}]}], TraditionalForm]]],
  "   returns the sum of the two Tens3D tensors."
}], "DefinitionBox",
  CellTags->"b:0.3"],

Cell["The two tensors must have the same rank.", "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.3"],

Cell[TextData[{
  StyleBox["CirclePlus",
    FontFamily->"Courier New"],
  " has attributes ",
  StyleBox["Flat",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["OneIdentity",
    FontFamily->"Courier New"],
  ". You can thus use the infix form ",
  Cell[BoxData[
      \(TraditionalForm\`\[CirclePlus]\)]],
  " for the sum of more two tensors :   ",
  StyleBox["T1 ",
    FontFamily->"Courier New"],
  Cell[BoxData[
      \(TraditionalForm\`\(\[CirclePlus]\ \ T2\ \[CirclePlus]\ T3\)\)],
    FontFamily->"Courier New"],
  " is interpreted as ",
  StyleBox["CirclePlus[T1,T2,T3]",
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.3"],

Cell[TextData[{
  StyleBox["CirclePlus",
    FontFamily->"Courier New"],
  " remains unevaluated if one argument is not Tens3D tensor."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.3"],

Cell[TextData[{
  "Symbol ",
  Cell[BoxData[
      \(TraditionalForm\`\[CirclePlus]\)]],
  " may be found in the front end menu \
File/Palettes/CompleteCharacters/Operators or rapidly typed with \
\[EscapeKey]",
  StyleBox["c+\[EscapeKey]",
    FontFamily->"Courier New"]
}], "Text",
  CellDingbat->"\[GraySquare]",
  CellTags->"b:0.3"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[65]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.3"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(T = 
        DefineGeneralTensor[t, {1, \(-1\)}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(U = 
        DefineGeneralTensor[u, {1, \(-1\)}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(T\ \[CirclePlus]\ U\  // Components\)}], "Input",
  CellLabel->"In[66]:=",
  CellTags->"b:0.3"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[66]:=",
  CellTags->"b:0.3"],

Cell[BoxData[
    \({{t11 + u11, t12 + u12, t13 + u13}, {t21 + u21, t22 + u22, 
        t23 + u23}, {t31 + u31, t32 + u32, t33 + u33}}\)], "Output",
  CellLabel->"Out[68]=",
  CellTags->"b:0.3"]
}, Open  ]],

Cell[TextData[{
  "Here we define another basis ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " :"
}], "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.3"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(v1 = 
        DefineTensor[{0, 1, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v2 = 
        DefineTensor[{1, 0, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v3 = 
        DefineTensor[{1, 1, 0}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(B = DefineBasis[v1, v2, v3];\)\)}], "Input",
  CellLabel->"In[69]:=",
  CellTags->"b:0.3"],

Cell[BoxData[
    \("Direct basis."\)], "Print",
  CellLabel->"From In[69]:=",
  CellTags->"b:0.3"]
}, Open  ]],

Cell[TextData[{
  "and another rank 2 tensor ",
  StyleBox["V",
    FontFamily->"Courier New"],
  " by its covariant-covariant components on basis ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " :"
}], "Text",
  CellTags->"b:0.3"],

Cell[BoxData[
    \(\(V = DefineGeneralTensor[VCcB, {\(-1\), \(-1\)}, B];\)\)], "Input",
  CellLabel->"In[73]:=",
  CellTags->"b:0.3"],

Cell[BoxData[
    \(\(S = V\[CirclePlus]\ T;\)\)], "Input",
  CellLabel->"In[74]:=",
  CellTags->"b:0.3"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(S // Components\) // MatrixForm\)], "Input",
  CellLabel->"In[75]:=",
  CellTags->"b:0.3"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[75]:=",
  CellTags->"b:0.3"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/4\ \((4\ t11 + VCcB11 - VCcB12 - VCcB13 - VCcB21 + VCcB22 + 
                    VCcB23 - VCcB31 + VCcB32 + 
                    VCcB33)\)\), \(1\/4\ \((4\ t12 - VCcB11 + VCcB12 - 
                    VCcB13 + VCcB21 - VCcB22 + VCcB23 + VCcB31 - VCcB32 + 
                    VCcB33)\)\), \(1\/4\ \((4\ t13 - VCcB11 - VCcB12 + 
                    VCcB13 + VCcB21 + VCcB22 - VCcB23 + VCcB31 + VCcB32 - 
                    VCcB33)\)\)},
            {\(1\/4\ \((4\ t21 - VCcB11 + VCcB12 + VCcB13 + VCcB21 - VCcB22 - 
                    VCcB23 - VCcB31 + VCcB32 + 
                    VCcB33)\)\), \(1\/4\ \((4\ t22 + VCcB11 - VCcB12 + 
                    VCcB13 - VCcB21 + VCcB22 - VCcB23 + VCcB31 - VCcB32 + 
                    VCcB33)\)\), \(1\/4\ \((4\ t23 + VCcB11 + VCcB12 - 
                    VCcB13 - VCcB21 - VCcB22 + VCcB23 + VCcB31 + VCcB32 - 
                    VCcB33)\)\)},
            {\(1\/4\ \((4\ t31 - VCcB11 + VCcB12 + VCcB13 - VCcB21 + VCcB22 + 
                    VCcB23 + VCcB31 - VCcB32 - 
                    VCcB33)\)\), \(1\/4\ \((4\ t32 + VCcB11 - VCcB12 + 
                    VCcB13 + VCcB21 - VCcB22 + VCcB23 - VCcB31 + VCcB32 - 
                    VCcB33)\)\), \(1\/4\ \((4\ t33 + VCcB11 + VCcB12 - 
                    VCcB13 + VCcB21 + VCcB22 - VCcB23 - VCcB31 - VCcB32 + 
                    VCcB33)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[75]//MatrixForm=",
  CellTags->"b:0.3"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[S, {\(-1\), \(-1\)}, B] // MatrixForm\)], "Input",
  CellLabel->"In[76]:=",
  CellTags->"b:0.3"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(t22 + t23 + t32 + t33 + VCcB11\), \(t21 + t23 + t31 + t33 + 
                VCcB12\), \(t21 + t22 + t31 + t32 + VCcB13\)},
            {\(t12 + t13 + t32 + t33 + VCcB21\), \(t11 + t13 + t31 + t33 + 
                VCcB22\), \(t11 + t12 + t31 + t32 + VCcB23\)},
            {\(t12 + t13 + t22 + t23 + VCcB31\), \(t11 + t13 + t21 + t23 + 
                VCcB32\), \(t11 + t12 + t21 + t22 + VCcB33\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[76]//MatrixForm=",
  CellFrame->{{0, 0}, {0.5, 0}},
  CellTags->"b:0.3"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{671, 740},
WindowMargins->{{158, Automatic}, {Automatic, 118}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.3"->{
    Cell[1776, 53, 180, 7, 49, "Subsection",
      CellTags->"b:0.3"],
    Cell[1959, 62, 753, 26, 69, "DefinitionBox",
      CellTags->"b:0.3"],
    Cell[2715, 90, 111, 2, 29, "Text",
      CellTags->"b:0.3"],
    Cell[2829, 94, 692, 24, 48, "Text",
      CellTags->"b:0.3"],
    Cell[3524, 120, 202, 6, 29, "Text",
      CellTags->"b:0.3"],
    Cell[3729, 128, 336, 11, 48, "Text",
      CellTags->"b:0.3"],
    Cell[4068, 141, 137, 4, 44, "Input",
      CellTags->"b:0.3"],
    Cell[4230, 149, 344, 9, 75, "Input",
      CellTags->"b:0.3"],
    Cell[4577, 160, 242, 6, 27, "Print",
      CellTags->"b:0.3"],
    Cell[4822, 168, 194, 4, 74, "Output",
      CellTags->"b:0.3"],
    Cell[5031, 175, 172, 7, 29, "Text",
      CellTags->"b:0.3"],
    Cell[5228, 186, 437, 12, 96, "Input",
      CellTags->"b:0.3"],
    Cell[5668, 200, 99, 3, 27, "Print",
      CellTags->"b:0.3"],
    Cell[5782, 206, 237, 9, 29, "Text",
      CellTags->"b:0.3"],
    Cell[6022, 217, 134, 3, 33, "Input",
      CellTags->"b:0.3"],
    Cell[6159, 222, 105, 3, 33, "Input",
      CellTags->"b:0.3"],
    Cell[6289, 229, 112, 3, 33, "Input",
      CellTags->"b:0.3"],
    Cell[6404, 234, 242, 6, 27, "Print",
      CellTags->"b:0.3"],
    Cell[6649, 242, 1693, 31, 111, "Output",
      CellTags->"b:0.3"],
    Cell[8379, 278, 127, 3, 33, "Input",
      CellTags->"b:0.3"],
    Cell[8509, 283, 778, 17, 92, "Output",
      CellTags->"b:0.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.3", 9945, 320}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 180, 7, 49, "Subsection",
  CellTags->"b:0.3"],
Cell[1959, 62, 753, 26, 69, "DefinitionBox",
  CellTags->"b:0.3"],
Cell[2715, 90, 111, 2, 29, "Text",
  CellTags->"b:0.3"],
Cell[2829, 94, 692, 24, 48, "Text",
  CellTags->"b:0.3"],
Cell[3524, 120, 202, 6, 29, "Text",
  CellTags->"b:0.3"],
Cell[3729, 128, 336, 11, 48, "Text",
  CellTags->"b:0.3"],
Cell[4068, 141, 137, 4, 44, "Input",
  CellTags->"b:0.3"],

Cell[CellGroupData[{
Cell[4230, 149, 344, 9, 75, "Input",
  CellTags->"b:0.3"],
Cell[4577, 160, 242, 6, 27, "Print",
  CellTags->"b:0.3"],
Cell[4822, 168, 194, 4, 74, "Output",
  CellTags->"b:0.3"]
}, Open  ]],
Cell[5031, 175, 172, 7, 29, "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{
Cell[5228, 186, 437, 12, 96, "Input",
  CellTags->"b:0.3"],
Cell[5668, 200, 99, 3, 27, "Print",
  CellTags->"b:0.3"]
}, Open  ]],
Cell[5782, 206, 237, 9, 29, "Text",
  CellTags->"b:0.3"],
Cell[6022, 217, 134, 3, 33, "Input",
  CellTags->"b:0.3"],
Cell[6159, 222, 105, 3, 33, "Input",
  CellTags->"b:0.3"],

Cell[CellGroupData[{
Cell[6289, 229, 112, 3, 33, "Input",
  CellTags->"b:0.3"],
Cell[6404, 234, 242, 6, 27, "Print",
  CellTags->"b:0.3"],
Cell[6649, 242, 1693, 31, 111, "Output",
  CellTags->"b:0.3"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8379, 278, 127, 3, 33, "Input",
  CellTags->"b:0.3"],
Cell[8509, 283, 778, 17, 92, "Output",
  CellTags->"b:0.3"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

