(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18449,        559]*)
(*NotebookOutlinePosition[     21201,        646]*)
(*  CellTagsIndexPosition[     21130,        640]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["CircleTimes or \[CircleTimes]", "Subsection",
  CellTags->"b:0.4"],

Cell[TextData[{
  StyleBox["CircleTimes[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " or ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " \[CircleTimes] ",
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  "  returns the tensorial product of the two tensors."
}], "DefinitionBox",
  CellTags->"b:0.4"],

Cell["\<\
The rank of a tensorial product is the sum of the rank of the two tensors.\
\>", "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.4"],

Cell[TextData[{
  StyleBox["CircleTimes",
    FontFamily->"Courier New"],
  " has attributes ",
  StyleBox["Flat",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["OneIdentity",
    FontFamily->"Courier New"],
  ". You can thus use the infix form ",
  Cell[BoxData[
      \(TraditionalForm\`\[CircleTimes]\)]],
  " for the tensorial product of more two tensors :   ",
  StyleBox["T1",
    FontFamily->"Courier New"],
  Cell[BoxData[
      \(TraditionalForm\`\(\[CircleTimes]\ T2\[CircleTimes]T3\)\)],
    FontFamily->"Courier New"],
  " is interpreted as ",
  StyleBox["CircleTimes[T1,T2,T3]",
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.4"],

Cell[TextData[{
  StyleBox["CircleTimes",
    FontFamily->"Courier New"],
  " remains unevaluated if one argument is not Tens3D tensor."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.4"],

Cell[TextData[{
  "Symbol \[CircleTimes] may be found in the front end menu \
File/Palettes/CompleteCharacters/Operators or rapidly typed with \
\[EscapeKey]",
  StyleBox["c*\[EscapeKey]",
    FontFamily->"Courier New"]
}], "Text",
  CellDingbat->"\[GraySquare]",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[1]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.4"],

Cell[TextData[{
  StyleBox["T",
    FontFamily->"Courier New"],
  " is a rank 2 tensor and ",
  StyleBox["V",
    FontFamily->"Courier New"],
  " a rank 1 tensor (a vector) :"
}], "Text",
  CellTags->"b:0.4"],

Cell[BoxData[{
    \(t =. ; v =. ;\), "\[IndentingNewLine]", 
    \(\(T = 
        DefineGeneralTensor[t, {1, \(-1\)}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(V = DefineGeneralTensor[v, {1}, CanonicalBasis];\)\)}], "Input",
  CellLabel->"In[2]:=",
  CellTags->"b:0.4"],

Cell["\<\
The tensorial product of a rank 2 tensor and a vector is a rank 3 tensor :\
\>", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(\(TV = T\ \[CircleTimes]\ V\ ;\)\)], "Input",
  CellLabel->"In[5]:=",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rank[TV]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(3\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell["\<\
Note : MatrixForm of a 3\[Cross]3\[Cross]3 array is a matrix of columns :\
\>", "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(TV // Components\) // MatrixForm\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[7]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t11\ v1\)},
                      {\(t11\ v2\)},
                      {\(t11\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t12\ v1\)},
                      {\(t12\ v2\)},
                      {\(t12\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t13\ v1\)},
                      {\(t13\ v2\)},
                      {\(t13\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t21\ v1\)},
                      {\(t21\ v2\)},
                      {\(t21\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t22\ v1\)},
                      {\(t22\ v2\)},
                      {\(t22\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t23\ v1\)},
                      {\(t23\ v2\)},
                      {\(t23\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t31\ v1\)},
                      {\(t31\ v2\)},
                      {\(t31\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t32\ v1\)},
                      {\(t32\ v2\)},
                      {\(t32\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t33\ v1\)},
                      {\(t33\ v2\)},
                      {\(t33\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[7]//MatrixForm=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell["\<\
The tensorial product of two rank 2 tensors  is a rank 4 tensor :\
\>", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rank[T\[CircleTimes]T]\)], "Input",
  CellLabel->"In[8]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(4\)], "Output",
  CellLabel->"Out[8]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell["\<\
Note : MatrixForm of a 3\[Cross]3\[Cross]3\[Cross]3 array is a matrix of \
matrices :\
\>", "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(T\[CircleTimes]T\  // Components\) // MatrixForm\)], "Input",
  CellLabel->"In[9]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[9]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(t11\^2\), \(t11\ t12\), \(t11\ t13\)},
                    {\(t11\ t21\), \(t11\ t22\), \(t11\ t23\)},
                    {\(t11\ t31\), \(t11\ t32\), \(t11\ t33\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(t11\ t12\), \(t12\^2\), \(t12\ t13\)},
                    {\(t12\ t21\), \(t12\ t22\), \(t12\ t23\)},
                    {\(t12\ t31\), \(t12\ t32\), \(t12\ t33\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(t11\ t13\), \(t12\ t13\), \(t13\^2\)},
                    {\(t13\ t21\), \(t13\ t22\), \(t13\ t23\)},
                    {\(t13\ t31\), \(t13\ t32\), \(t13\ t33\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(t11\ t21\), \(t12\ t21\), \(t13\ t21\)},
                    {\(t21\^2\), \(t21\ t22\), \(t21\ t23\)},
                    {\(t21\ t31\), \(t21\ t32\), \(t21\ t33\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(t11\ t22\), \(t12\ t22\), \(t13\ t22\)},
                    {\(t21\ t22\), \(t22\^2\), \(t22\ t23\)},
                    {\(t22\ t31\), \(t22\ t32\), \(t22\ t33\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(t11\ t23\), \(t12\ t23\), \(t13\ t23\)},
                    {\(t21\ t23\), \(t22\ t23\), \(t23\^2\)},
                    {\(t23\ t31\), \(t23\ t32\), \(t23\ t33\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(t11\ t31\), \(t12\ t31\), \(t13\ t31\)},
                    {\(t21\ t31\), \(t22\ t31\), \(t23\ t31\)},
                    {\(t31\^2\), \(t31\ t32\), \(t31\ t33\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(t11\ t32\), \(t12\ t32\), \(t13\ t32\)},
                    {\(t21\ t32\), \(t22\ t32\), \(t23\ t32\)},
                    {\(t31\ t32\), \(t32\^2\), \(t32\ t33\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", GridBox[{
                    {\(t11\ t33\), \(t12\ t33\), \(t13\ t33\)},
                    {\(t21\ t33\), \(t22\ t33\), \(t23\ t33\)},
                    {\(t31\ t33\), \(t32\ t33\), \(t33\^2\)}
                    },
                  RowSpacings->1,
                  ColumnSpacings->1,
                  ColumnAlignments->{Left}], "\[NoBreak]", ")"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[9]//MatrixForm=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rank[T\[CircleTimes]T\[CircleTimes]T]\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    \(6\)], "Output",
  CellLabel->"Out[10]=",
  CellTags->"b:0.4"]
}, Open  ]],

Cell["\<\
We can easily verify that the tensorial product is not commutative :\
\>", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.4"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(T\[CircleTimes]V\ \[CircleMinus]\ V\ \[CircleTimes]T\  // \ 
        Components\)\  // MatrixForm\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[11]:=",
  CellTags->"b:0.4"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {"0"},
                      {\(\(-t12\)\ v1 + t11\ v2\)},
                      {\(\(-t13\)\ v1 + t11\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(\((t12 - t21)\)\ v1\)},
                      {\(\(-t22\)\ v1 + t12\ v2\)},
                      {\(\(-t23\)\ v1 + t12\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(\((t13 - t31)\)\ v1\)},
                      {\(\(-t32\)\ v1 + t13\ v2\)},
                      {\(\(-t33\)\ v1 + t13\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t21\ v1 - t11\ v2\)},
                      {\(\((\(-t12\) + t21)\)\ v2\)},
                      {\(\(-t13\)\ v2 + t21\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t22\ v1 - t21\ v2\)},
                      {"0"},
                      {\(\(-t23\)\ v2 + t22\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t23\ v1 - t31\ v2\)},
                      {\(\((t23 - t32)\)\ v2\)},
                      {\(\(-t33\)\ v2 + t23\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}]},
            {
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t31\ v1 - t11\ v3\)},
                      {\(t31\ v2 - t12\ v3\)},
                      {\(\((\(-t13\) + t31)\)\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t32\ v1 - t21\ v3\)},
                      {\(t32\ v2 - t22\ v3\)},
                      {\(\((\(-t23\) + t32)\)\ v3\)}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}], 
              RowBox[{"(", "\[NoBreak]", 
                TagBox[GridBox[{
                      {\(t33\ v1 - t31\ v3\)},
                      {\(t33\ v2 - t32\ v3\)},
                      {"0"}
                      },
                    RowSpacings->1,
                    ColumnAlignments->{Left}],
                  Column], "\[NoBreak]", ")"}]}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[11]//MatrixForm=",
  CellFrame->{{0, 0}, {0.5, 0}},
  CellTags->"b:0.4"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{735, 740},
WindowMargins->{{Automatic, 65}, {72, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.4"->{
    Cell[1776, 53, 72, 1, 48, "Subsection",
      CellTags->"b:0.4"],
    Cell[1851, 56, 632, 23, 50, "DefinitionBox",
      CellTags->"b:0.4"],
    Cell[2486, 81, 153, 4, 29, "Text",
      CellTags->"b:0.4"],
    Cell[2642, 87, 704, 24, 48, "Text",
      CellTags->"b:0.4"],
    Cell[3349, 113, 203, 6, 29, "Text",
      CellTags->"b:0.4"],
    Cell[3555, 121, 284, 8, 48, "Text",
      CellTags->"b:0.4"],
    Cell[3842, 131, 136, 4, 44, "Input",
      CellTags->"b:0.4"],
    Cell[3981, 137, 208, 8, 29, "Text",
      CellTags->"b:0.4"],
    Cell[4192, 147, 293, 7, 75, "Input",
      CellTags->"b:0.4"],
    Cell[4488, 156, 153, 4, 29, "Text",
      CellTags->"b:0.4"],
    Cell[4644, 162, 110, 3, 33, "Input",
      CellTags->"b:0.4"],
    Cell[4779, 169, 86, 3, 33, "Input",
      CellTags->"b:0.4"],
    Cell[4868, 174, 80, 3, 32, "Output",
      CellTags->"b:0.4"],
    Cell[4963, 180, 118, 3, 29, "Text",
      CellTags->"b:0.4"],
    Cell[5106, 187, 112, 3, 33, "Input",
      CellTags->"b:0.4"],
    Cell[5221, 192, 241, 6, 27, "Print",
      CellTags->"b:0.4"],
    Cell[5465, 200, 3447, 94, 189, "Output",
      CellTags->"b:0.4"],
    Cell[8927, 297, 144, 4, 29, "Text",
      CellTags->"b:0.4"],
    Cell[9096, 305, 100, 3, 33, "Input",
      CellTags->"b:0.4"],
    Cell[9199, 310, 80, 3, 32, "Output",
      CellTags->"b:0.4"],
    Cell[9294, 316, 130, 4, 29, "Text",
      CellTags->"b:0.4"],
    Cell[9449, 324, 128, 3, 33, "Input",
      CellTags->"b:0.4"],
    Cell[9580, 329, 241, 6, 27, "Print",
      CellTags->"b:0.4"],
    Cell[9824, 337, 3978, 85, 197, "Output",
      CellTags->"b:0.4"],
    Cell[13839, 427, 116, 3, 33, "Input",
      CellTags->"b:0.4"],
    Cell[13958, 432, 81, 3, 32, "Output",
      CellTags->"b:0.4"],
    Cell[14054, 438, 147, 4, 29, "Text",
      CellTags->"b:0.4"],
    Cell[14226, 446, 178, 4, 33, "Input",
      CellTags->"b:0.4"],
    Cell[14407, 452, 242, 6, 27, "Print",
      CellTags->"b:0.4"],
    Cell[14652, 460, 3769, 95, 200, "Output",
      CellTags->"b:0.4"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.4", 19077, 575}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 72, 1, 48, "Subsection",
  CellTags->"b:0.4"],
Cell[1851, 56, 632, 23, 50, "DefinitionBox",
  CellTags->"b:0.4"],
Cell[2486, 81, 153, 4, 29, "Text",
  CellTags->"b:0.4"],
Cell[2642, 87, 704, 24, 48, "Text",
  CellTags->"b:0.4"],
Cell[3349, 113, 203, 6, 29, "Text",
  CellTags->"b:0.4"],
Cell[3555, 121, 284, 8, 48, "Text",
  CellTags->"b:0.4"],
Cell[3842, 131, 136, 4, 44, "Input",
  CellTags->"b:0.4"],
Cell[3981, 137, 208, 8, 29, "Text",
  CellTags->"b:0.4"],
Cell[4192, 147, 293, 7, 75, "Input",
  CellTags->"b:0.4"],
Cell[4488, 156, 153, 4, 29, "Text",
  CellTags->"b:0.4"],
Cell[4644, 162, 110, 3, 33, "Input",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[4779, 169, 86, 3, 33, "Input",
  CellTags->"b:0.4"],
Cell[4868, 174, 80, 3, 32, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[4963, 180, 118, 3, 29, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[5106, 187, 112, 3, 33, "Input",
  CellTags->"b:0.4"],
Cell[5221, 192, 241, 6, 27, "Print",
  CellTags->"b:0.4"],
Cell[5465, 200, 3447, 94, 189, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[8927, 297, 144, 4, 29, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[9096, 305, 100, 3, 33, "Input",
  CellTags->"b:0.4"],
Cell[9199, 310, 80, 3, 32, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[9294, 316, 130, 4, 29, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[9449, 324, 128, 3, 33, "Input",
  CellTags->"b:0.4"],
Cell[9580, 329, 241, 6, 27, "Print",
  CellTags->"b:0.4"],
Cell[9824, 337, 3978, 85, 197, "Output",
  CellTags->"b:0.4"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13839, 427, 116, 3, 33, "Input",
  CellTags->"b:0.4"],
Cell[13958, 432, 81, 3, 32, "Output",
  CellTags->"b:0.4"]
}, Open  ]],
Cell[14054, 438, 147, 4, 29, "Text",
  CellTags->"b:0.4"],

Cell[CellGroupData[{
Cell[14226, 446, 178, 4, 33, "Input",
  CellTags->"b:0.4"],
Cell[14407, 452, 242, 6, 27, "Print",
  CellTags->"b:0.4"],
Cell[14652, 460, 3769, 95, 200, "Output",
  CellTags->"b:0.4"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

