(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6866,        239]*)
(*NotebookOutlinePosition[      7657,        268]*)
(*  CellTagsIndexPosition[      7587,        262]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["CompactDerivativeForm",
  FontFamily->"Courier New"]], "Subsection"],

Cell[TextData[{
  StyleBox["CompactDerivativeForm[",
    FontFamily->"Courier New"],
  StyleBox["exp",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  StyleBox["prints partial derivative in a more compact form than standard ",
    FontFamily->"Times New Roman"],
  StyleBox["OutputForm",
    FontFamily->"Courier New"],
  StyleBox[".",
    FontFamily->"Times New Roman"]
}], "DefinitionBox"],

Cell["\<\
The result can't be used as input. This function has been written only for \
better lisibility purpose. It may be useful for crating formulars.\
\>", "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[57]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.7"],

Cell[TextData[{
  "We define the classical cylindrical coordinates system :\na point M is \
function of coordinates ",
  StyleBox["{r,\[Theta],z}",
    FontFamily->"Courier New"],
  " :"
}], "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(r =. ; \[Theta] =. ; z =. ;\ \), "\[IndentingNewLine]", 
    \(\($Assumptions = $Assumptions\  && \ 
          r > 0;\)\), "\[IndentingNewLine]", 
    \(\(coords = {r, \[Theta], z};\)\), "\[IndentingNewLine]", 
    \(\(OM = 
        DefineTensor[{r\ Cos[\[Theta]], r\ Sin[\[Theta]], z}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(cyl = DefineCoordinateSystem[OM, coords];\)\)}], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \("Direct orthogonal natural basis."\)], "Print",
  CellLabel->"From In[58]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(cylnorm = NormalizedBasis[cyl];\)\)], "Input",
  CellLabel->"In[63]:="],

Cell[BoxData[
    \("Direct normalized orthogonal basis."\)], "Print",
  CellLabel->"From In[63]:="]
}, Open  ]],

Cell[TextData[{
  StyleBox["f[r,\[Theta],z] ",
    FontFamily->"Courier New"],
  "is a general scalar field. The Gradient is a vector field :"
}], "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[BoxData[
    \(\(Gf = Gradient[f[r, \[Theta], z], cyl];\)\)], "Input",
  CellLabel->"In[64]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[Gf, {\(-1\)}, cyl]\)], "Input",
  CellLabel->"In[65]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], ",", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], ",", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[65]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[Gf, {1}, cyl]\)], "Input",
  CellLabel->"In[66]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], ",", 
        FractionBox[
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((0, 1, 0)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), 
            "]"}], \(r\^2\)], ",", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[66]="]
}, Open  ]],

Cell["\<\
Classical formulars give components on the normalized basis :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[Gf, {1}, cylnorm]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], ",", 
        FractionBox[
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((0, 1, 0)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], "r"], 
        ",", 
        RowBox[{
          SuperscriptBox["f", 
            TagBox[\((0, 0, 1)\),
              Derivative],
            MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[71]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[Gf, {1}, cylnorm] // CompactDerivativeForm\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    \({\[PartialD]\_r f, \[PartialD]\_\[Theta] f\/r, \[PartialD]\_z 
        f}\)], "Output",
  CellLabel->"Out[74]=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{696, 740},
WindowMargins->{{Automatic, 152}, {Automatic, 92}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.7"->{
    Cell[2533, 78, 137, 4, 44, "Input",
      CellTags->"b:0.7"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.7", 7495, 255}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 92, 1, 47, "Subsection"],
Cell[1871, 56, 455, 14, 69, "DefinitionBox"],
Cell[2329, 72, 201, 4, 48, "Text"],
Cell[2533, 78, 137, 4, 44, "Input",
  CellTags->"b:0.7"],
Cell[2673, 84, 232, 7, 56, "Text"],

Cell[CellGroupData[{
Cell[2930, 95, 460, 9, 117, "Input"],
Cell[3393, 106, 97, 2, 27, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3527, 113, 93, 2, 33, "Input"],
Cell[3623, 117, 100, 2, 27, "Print"]
}, Open  ]],
Cell[3738, 122, 188, 5, 29, "Text"],
Cell[3929, 129, 100, 2, 33, "Input"],

Cell[CellGroupData[{
Cell[4054, 135, 87, 2, 33, "Input"],
Cell[4144, 139, 647, 19, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4828, 163, 82, 2, 33, "Input"],
Cell[4913, 167, 702, 21, 49, "Output"]
}, Open  ]],
Cell[5630, 191, 85, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[5740, 197, 86, 2, 33, "Input"],
Cell[5829, 201, 693, 21, 49, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6559, 227, 111, 2, 33, "Input"],
Cell[6673, 231, 165, 4, 57, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

