(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12597,        430]*)
(*NotebookOutlinePosition[     15696,        527]*)
(*  CellTagsIndexPosition[     15625,        521]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Components",
  FontFamily->"Courier New"]], "Subsection",
  CellTags->"b:0.5"],

Cell[TextData[{
  StyleBox["Components[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["listvar",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["basis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  returns the array of components of the Tens3D tensor ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  ", in variances given in ",
  StyleBox["listvar",
    FontSlant->"Italic"],
  " and on the Tens3D basis ",
  StyleBox["basis",
    FontSlant->"Italic"],
  "."
}], "DefinitionBox",
  CellTags->"b:0.5"],

Cell[TextData[{
  StyleBox["tensor",
    FontSlant->"Italic"],
  " must be a rank \[GreaterEqual]1 Tens3D tensor (defined with Tens3D \
functions)."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.5"],

Cell[TextData[{
  StyleBox["listvar",
    FontSlant->"Italic"],
  " is the list of the desired variances. It must contain only 1 (for \
contravariant, up indices) or -1 (for covariant, down indices). The length of \
",
  StyleBox["listvar",
    FontSlant->"Italic"],
  " must be equal to the rank of the tensor."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.5"],

Cell[TextData[{
  StyleBox["basis",
    FontSlant->"Italic"],
  " is a Tens3D basis ",
  "(created with ",
  StyleBox[ButtonBox["DefineBasis",
    ButtonData:>{"DefineBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["NormalizedBasis",
    ButtonData:>{"NormalizedBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["DefineCoordinateSystem",
    ButtonData:>{"DefineCoordinateSystem", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ") ",
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.5"],

Cell[TextData[{
  StyleBox["listvar",
    FontSlant->"Italic"],
  " is optional. Default value is completely contravariant."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.5"],

Cell[TextData[{
  StyleBox["basis",
    FontSlant->"Italic"],
  " is optional. Default value is ",
  StyleBox[ButtonBox["CanonicalBasis",
    ButtonData:>{"Predef", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.5"],

Cell[TextData[{
  StyleBox["Components",
    FontFamily->"Courier New"],
  " used in postfix give the components in the canonical basis."
}], "Text",
  CellDingbat->"\[GraySquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[50]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.5"],

Cell["\<\
We define a rank 2 tensor by components in the canonical basis :\
\>", "Text",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(\(T = DefineGeneralTensor[t, {1, \(-1\)}, CanonicalBasis];\)\)], "Input",\

  CellLabel->"In[51]:=",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {1, \(-1\)}, CanonicalBasis]\)], "Input",
  CellLabel->"In[52]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \({{t11, t12, t13}, {t21, t22, t23}, {t31, t32, t33}}\)], "Output",
  CellLabel->"Out[52]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell["We define another basis B (non orthonormal) :", "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(v1 = 
        DefineTensor[{0, 1, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v2 = 
        DefineTensor[{1, 0, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v3 = 
        DefineTensor[{1, 1, 0}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(B = DefineBasis[v1, v2, v3];\)\)}], "Input",
  CellLabel->"In[53]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \("Direct basis."\)], "Print",
  CellLabel->"From In[53]:=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[TextData[{
  "The various components of ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " on basis ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " are :"
}], "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {1, 1}, B] // MatrixForm\)], "Input",
  CellLabel->"In[57]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/4\ \((t11 - t12 - t13 - t21 + t22 + t23 - t31 + t32 + 
                    t33)\)\), \(1\/4\ \((\(-t11\) + t12 - t13 + t21 - t22 + 
                    t23 + t31 - t32 + t33)\)\), \(1\/4\ \((\(-t11\) - t12 + 
                    t13 + t21 + t22 - t23 + t31 + t32 - t33)\)\)},
            {\(1\/4\ \((\(-t11\) + t12 + t13 + t21 - t22 - t23 - t31 + t32 + 
                    t33)\)\), \(1\/4\ \((t11 - t12 + t13 - t21 + t22 - t23 + 
                    t31 - t32 + t33)\)\), \(1\/4\ \((t11 + t12 - t13 - t21 - 
                    t22 + t23 + t31 + t32 - t33)\)\)},
            {\(1\/4\ \((\(-t11\) + t12 + t13 - t21 + t22 + t23 + t31 - t32 - 
                    t33)\)\), \(1\/4\ \((t11 - t12 + t13 + t21 - t22 + t23 - 
                    t31 + t32 - t33)\)\), \(1\/4\ \((t11 + t12 - t13 + t21 + 
                    t22 - t23 - t31 - t32 + t33)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[57]//MatrixForm=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {1, \(-1\)}, B] // MatrixForm\)], "Input",
  CellLabel->"In[58]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/2\ \((\(-t12\) - t13 + t22 + t23 + t32 + 
                    t33)\)\), \(1\/2\ \((\(-t11\) - t13 + t21 + t23 + t31 + 
                    t33)\)\), \(1\/2\ \((\(-t11\) - t12 + t21 + t22 + t31 + 
                    t32)\)\)},
            {\(1\/2\ \((t12 + t13 - t22 - t23 + t32 + 
                    t33)\)\), \(1\/2\ \((t11 + t13 - t21 - t23 + t31 + 
                    t33)\)\), \(1\/2\ \((t11 + t12 - t21 - t22 + t31 + 
                    t32)\)\)},
            {\(1\/2\ \((t12 + t13 + t22 + t23 - t32 - 
                    t33)\)\), \(1\/2\ \((t11 + t13 + t21 + t23 - t31 - 
                    t33)\)\), \(1\/2\ \((t11 + t12 + t21 + t22 - t31 - 
                    t32)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[58]//MatrixForm=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {\(-1\), 1}, B] // MatrixForm\)], "Input",
  CellLabel->"In[59]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/2\ \((\(-t21\) + t22 + t23 - t31 + t32 + 
                    t33)\)\), \(1\/2\ \((t21 - t22 + t23 + t31 - t32 + 
                    t33)\)\), \(1\/2\ \((t21 + t22 - t23 + t31 + t32 - 
                    t33)\)\)},
            {\(1\/2\ \((\(-t11\) + t12 + t13 - t31 + t32 + 
                    t33)\)\), \(1\/2\ \((t11 - t12 + t13 + t31 - t32 + 
                    t33)\)\), \(1\/2\ \((t11 + t12 - t13 + t31 + t32 - 
                    t33)\)\)},
            {\(1\/2\ \((\(-t11\) + t12 + t13 - t21 + t22 + 
                    t23)\)\), \(1\/2\ \((t11 - t12 + t13 + t21 - t22 + 
                    t23)\)\), \(1\/2\ \((t11 + t12 - t13 + t21 + t22 - 
                    t23)\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[59]//MatrixForm=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {\(-1\), \(-1\)}, B] // MatrixForm\)], "Input",
  CellLabel->"In[60]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(t22 + t23 + t32 + t33\), \(t21 + t23 + t31 + t33\), \(t21 + 
                t22 + t31 + t32\)},
            {\(t12 + t13 + t32 + t33\), \(t11 + t13 + t31 + t33\), \(t11 + 
                t12 + t31 + t32\)},
            {\(t12 + t13 + t22 + t23\), \(t11 + t13 + t21 + t23\), \(t11 + 
                t12 + t21 + t22\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[60]//MatrixForm=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[TextData[{
  "Because the two last arguments of ",
  StyleBox["Components",
    FontFamily->"Courier New"],
  " are optional, you can use it in postfix form :"
}], "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T // Components\)], "Input",
  CellLabel->"In[61]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[61]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \({{t11, t12, t13}, {t21, t22, t23}, {t31, t32, t33}}\)], "Output",
  CellLabel->"Out[61]=",
  CellTags->"b:0.5"]
}, Open  ]],

Cell["\<\
The same tensor can be defined by its covariant-contravariant components on \
basis B :\
\>", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(\(a = Components[T, {\(-1\), 1}, B];\)\)], "Input",
  CellLabel->"In[62]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \(\(T1 = DefineTensor[a, {\(-1\), 1}, B];\)\)], "Input",
  CellLabel->"In[63]:=",
  CellTags->"b:0.5"],

Cell[TextData[{
  "Tensors ",
  StyleBox["T1", "Input"],
  " and ",
  StyleBox["T", "Input"],
  " are equal :"
}], "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1\ \[CircleMinus]\ T\  // Components\)], "Input",
  CellLabel->"In[64]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[64]:=",
  CellTags->"b:0.5"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[64]=",
  CellFrame->{{0, 0}, {0.5, 0}},
  CellTags->"b:0.5"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{700, 740},
WindowMargins->{{Automatic, 43}, {49, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.5"->{
    Cell[1776, 53, 102, 2, 47, "Subsection",
      CellTags->"b:0.5"],
    Cell[1881, 57, 774, 29, 69, "DefinitionBox",
      CellTags->"b:0.5"],
    Cell[2658, 88, 215, 7, 29, "Text",
      CellTags->"b:0.5"],
    Cell[2876, 97, 379, 11, 48, "Text",
      CellTags->"b:0.5"],
    Cell[3258, 110, 652, 23, 48, "Text",
      CellTags->"b:0.5"],
    Cell[3913, 135, 191, 6, 29, "Text",
      CellTags->"b:0.5"],
    Cell[4107, 143, 308, 11, 29, "Text",
      CellTags->"b:0.5"],
    Cell[4602, 163, 137, 4, 44, "Input",
      CellTags->"b:0.5"],
    Cell[4742, 169, 109, 3, 29, "Text",
      CellTags->"b:0.5"],
    Cell[4854, 174, 141, 4, 33, "Input",
      CellTags->"b:0.5"],
    Cell[5020, 182, 121, 3, 33, "Input",
      CellTags->"b:0.5"],
    Cell[5144, 187, 131, 3, 32, "Output",
      CellTags->"b:0.5"],
    Cell[5290, 193, 82, 1, 29, "Text",
      CellTags->"b:0.5"],
    Cell[5397, 198, 437, 12, 96, "Input",
      CellTags->"b:0.5"],
    Cell[5837, 212, 99, 3, 27, "Print",
      CellTags->"b:0.5"],
    Cell[5951, 218, 203, 9, 29, "Text",
      CellTags->"b:0.5"],
    Cell[6179, 231, 117, 3, 33, "Input",
      CellTags->"b:0.5"],
    Cell[6299, 236, 1200, 22, 111, "Output",
      CellTags->"b:0.5"],
    Cell[7536, 263, 122, 3, 33, "Input",
      CellTags->"b:0.5"],
    Cell[7661, 268, 1033, 22, 111, "Output",
      CellTags->"b:0.5"],
    Cell[8731, 295, 122, 3, 33, "Input",
      CellTags->"b:0.5"],
    Cell[8856, 300, 1033, 22, 111, "Output",
      CellTags->"b:0.5"],
    Cell[9926, 327, 127, 3, 33, "Input",
      CellTags->"b:0.5"],
    Cell[10056, 332, 664, 16, 81, "Output",
      CellTags->"b:0.5"],
    Cell[10735, 351, 231, 7, 29, "Text",
      CellTags->"b:0.5"],
    Cell[10991, 362, 94, 3, 33, "Input",
      CellTags->"b:0.5"],
    Cell[11088, 367, 242, 6, 27, "Print",
      CellTags->"b:0.5"],
    Cell[11333, 375, 131, 3, 32, "Output",
      CellTags->"b:0.5"],
    Cell[11479, 381, 166, 5, 29, "Text",
      CellTags->"b:0.5"],
    Cell[11648, 388, 117, 3, 33, "Input",
      CellTags->"b:0.5"],
    Cell[11768, 393, 120, 3, 33, "Input",
      CellTags->"b:0.5"],
    Cell[11891, 398, 143, 7, 33, "Text",
      CellTags->"b:0.5"],
    Cell[12059, 409, 116, 3, 33, "Input",
      CellTags->"b:0.5"],
    Cell[12178, 414, 242, 6, 27, "Print",
      CellTags->"b:0.5"],
    Cell[12423, 422, 146, 4, 43, "Output",
      CellTags->"b:0.5"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.5", 13225, 446}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 102, 2, 47, "Subsection",
  CellTags->"b:0.5"],
Cell[1881, 57, 774, 29, 69, "DefinitionBox",
  CellTags->"b:0.5"],
Cell[2658, 88, 215, 7, 29, "Text",
  CellTags->"b:0.5"],
Cell[2876, 97, 379, 11, 48, "Text",
  CellTags->"b:0.5"],
Cell[3258, 110, 652, 23, 48, "Text",
  CellTags->"b:0.5"],
Cell[3913, 135, 191, 6, 29, "Text",
  CellTags->"b:0.5"],
Cell[4107, 143, 308, 11, 29, "Text",
  CellTags->"b:0.5"],
Cell[4418, 156, 181, 5, 29, "Text"],
Cell[4602, 163, 137, 4, 44, "Input",
  CellTags->"b:0.5"],
Cell[4742, 169, 109, 3, 29, "Text",
  CellTags->"b:0.5"],
Cell[4854, 174, 141, 4, 33, "Input",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[5020, 182, 121, 3, 33, "Input",
  CellTags->"b:0.5"],
Cell[5144, 187, 131, 3, 32, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[5290, 193, 82, 1, 29, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[5397, 198, 437, 12, 96, "Input",
  CellTags->"b:0.5"],
Cell[5837, 212, 99, 3, 27, "Print",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[5951, 218, 203, 9, 29, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[6179, 231, 117, 3, 33, "Input",
  CellTags->"b:0.5"],
Cell[6299, 236, 1200, 22, 111, "Output",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7536, 263, 122, 3, 33, "Input",
  CellTags->"b:0.5"],
Cell[7661, 268, 1033, 22, 111, "Output",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8731, 295, 122, 3, 33, "Input",
  CellTags->"b:0.5"],
Cell[8856, 300, 1033, 22, 111, "Output",
  CellTags->"b:0.5"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9926, 327, 127, 3, 33, "Input",
  CellTags->"b:0.5"],
Cell[10056, 332, 664, 16, 81, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[10735, 351, 231, 7, 29, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[10991, 362, 94, 3, 33, "Input",
  CellTags->"b:0.5"],
Cell[11088, 367, 242, 6, 27, "Print",
  CellTags->"b:0.5"],
Cell[11333, 375, 131, 3, 32, "Output",
  CellTags->"b:0.5"]
}, Open  ]],
Cell[11479, 381, 166, 5, 29, "Text",
  CellTags->"b:0.5"],
Cell[11648, 388, 117, 3, 33, "Input",
  CellTags->"b:0.5"],
Cell[11768, 393, 120, 3, 33, "Input",
  CellTags->"b:0.5"],
Cell[11891, 398, 143, 7, 33, "Text",
  CellTags->"b:0.5"],

Cell[CellGroupData[{
Cell[12059, 409, 116, 3, 33, "Input",
  CellTags->"b:0.5"],
Cell[12178, 414, 242, 6, 27, "Print",
  CellTags->"b:0.5"],
Cell[12423, 422, 146, 4, 43, "Output",
  CellTags->"b:0.5"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

