(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     23336,        846]*)
(*NotebookOutlinePosition[     27748,        981]*)
(*  CellTagsIndexPosition[     27677,        975]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Tensorial contracted products", "Subsection",
  CellTags->"b:0.6"],

Cell[TextData[{
  StyleBox["Dot[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " or ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[".",
    FontFamily->"Courier New"],
  StyleBox["tensor2 ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " returns the single contracted tensorial product.\n\n",
  StyleBox["Colon[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " or ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["\[Colon]",
    FontFamily->"Courier New"],
  StyleBox["tensor2 ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " returns the double contracted tensorial product.\n\n",
  StyleBox["Therefore[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " or ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["\[Therefore]",
    FontFamily->"Courier New"],
  StyleBox["tensor2 ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " returns the triple contracted tensorial product.\n\n",
  StyleBox["Proportion[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " or ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["\[Proportion]",
    FontFamily->"Courier New"],
  StyleBox["tensor2 ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " returns the quadruple contracted tensorial product."
}], "DefinitionBox",
  CellFrame->{{0, 0}, {0.5, 0}},
  CellTags->"b:0.6"],

Cell[TextData[{
  StyleBox["Dot",
    FontFamily->"Courier New"],
  " is an overdefinition of the classical ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Dot",
    FontFamily->"Courier New"],
  ". It returns a Tens3D tensor (or a scalar) only if the two arguments are \
rank \[GreaterEqual]1 Tens3D tensors. If arguments are arrays ",
  StyleBox["Dot",
    FontFamily->"Courier New"],
  " operates classically.\n",
  StyleBox["Dot",
    FontFamily->"Courier New"],
  " \"contracts\" the last indice of ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " with the first indice of ",
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  ".\nThe rank of the result is ",
  StyleBox["Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]+Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]-2",
    FontFamily->"Courier New"],
  StyleBox[".\nThe infix symbol \".\" is the ordinary keyboard dot.",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.6"],

Cell[TextData[{
  StyleBox["Colon",
    FontFamily->"Courier New"],
  " returns a Tens3D tensor (or a scalar) if the two arguments are rank \
\[GreaterEqual]2 Tens3D tensors and remains unevaluated else. \n",
  StyleBox["Colon",
    FontFamily->"Courier New"],
  " \"contracts\" the last two indices of ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " with the first two indices of ",
  StyleBox["tensor2 ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["taken",
    FontFamily->"Times New Roman"],
  StyleBox[" in the same order ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[":  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((T \[Colon] U)\)\_ijkl\)]],
  "=",
  Cell[BoxData[
      FormBox[
        SubscriptBox["T", 
          SuperscriptBox[\(\(ij\)\(\ \)\), 
            StyleBox["pq",
              FontColor->RGBColor[1, 0, 0]]]], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["U", 
          StyleBox[
            RowBox[{
              StyleBox["pq",
                FontColor->RGBColor[1, 0, 0]], "kl"}]]], TraditionalForm]]],
  "\nThe rank of the result is ",
  StyleBox["Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]+Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]-4",
    FontFamily->"Courier New"],
  StyleBox[".\nThe infix s",
    FontFamily->"Times New Roman"],
  "ymbol \" \[Colon] \" may be found in the front end menu \
File/Palettes/CompleteCharacters/Operators or rapidly typed with \
\[EscapeKey]",
  StyleBox[":\[EscapeKey]",
    FontFamily->"Courier New"],
  StyleBox[".",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Courier New"],
  StyleBox["It is not the same as  the keybord character",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" \" : \".",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.6"],

Cell[TextData[{
  StyleBox["Therefore",
    FontFamily->"Courier New"],
  " returns a Tens3D tensor (or a scalar) if the two arguments are rank \
\[GreaterEqual]3 Tens3D tensors and remains unevaluated else. \n",
  StyleBox["Therefore",
    FontFamily->"Courier New"],
  " \"contracts\" the last three indices of ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " with the first three indices of ",
  StyleBox["tensor2 ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["taken",
    FontFamily->"Times New Roman"],
  StyleBox[" in the same order ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[":  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((T \[Therefore] U)\)\_ijkl\)]],
  "=",
  Cell[BoxData[
      FormBox[
        SubscriptBox["T", 
          SuperscriptBox["ij", 
            StyleBox["pqr",
              FontColor->RGBColor[1, 0, 0]]]], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["U", 
          StyleBox[
            RowBox[{
              StyleBox["pqr",
                FontColor->RGBColor[1, 0, 0]], "kl"}]]], TraditionalForm]]],
  "\nThe rank of the result is ",
  StyleBox["Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]+Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]-6",
    FontFamily->"Courier New"],
  StyleBox[".\nThe infix s",
    FontFamily->"Times New Roman"],
  "ymbol \" \[Therefore] \" may be found in the front end menu \
File/Palettes/CompleteCharacters/Operators or rapidly typed with \
\[EscapeKey]",
  StyleBox["tf\[EscapeKey]",
    FontFamily->"Courier New"],
  StyleBox[".",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.6"],

Cell[TextData[{
  StyleBox["Proportion",
    FontFamily->"Courier New"],
  " returns a Tens3D tensor (or a scalar) if the two arguments are rank \
\[GreaterEqual]4 Tens3D tensors and remains unevaluated else. \n",
  StyleBox["Proportion",
    FontFamily->"Courier New"],
  " \"contracts\" the last four indices of ",
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " with the first four indices of ",
  StyleBox["tensor2 ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["taken",
    FontFamily->"Times New Roman"],
  StyleBox[" in the same order ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[":  ",
    FontFamily->"Times New Roman"],
  Cell[BoxData[
      \(TraditionalForm\`\((T \[Proportion] U)\)\_ijkl\)]],
  "=",
  Cell[BoxData[
      FormBox[
        SubscriptBox["T", 
          SuperscriptBox[\(\(ij\)\(\ \)\), 
            StyleBox["pqrs",
              FontColor->RGBColor[1, 0, 0]]]], TraditionalForm]]],
  " ",
  Cell[BoxData[
      FormBox[
        SubscriptBox["U", 
          StyleBox[
            RowBox[{
              StyleBox["pqrs",
                FontColor->RGBColor[1, 0, 0]], "kl"}]]], TraditionalForm]]],
  "\nThe rank of the result is ",
  StyleBox["Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]+Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]-8",
    FontFamily->"Courier New"],
  StyleBox[".\nThe infix s",
    FontFamily->"Times New Roman"],
  "ymbol \" \[Proportion] \" may be found in the front end menu \
File/Palettes/CompleteCharacters/Operators/Relational. Unfortunately there do \
not exist a  keyboard shortcut for typing this symbol."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.6"],

Cell["\<\
To avoid misinterpretations in expressions containing these non associative \
operators in infix form, it is highly recommended to put parenthesis around \
these functions in infix form (see last examples below).\
\>", "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.6"],

Cell[TextData[{
  "If you really need higher contracted products,, you may construct \
successive contractions of the tensorial product with the function ",
  StyleBox[ButtonBox["AutoContract",
    ButtonData:>{"AutoContract", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", but with a  low efficiency."
}], "Text",
  CellDingbat->"\[GraySquare]",
  CellTags->"b:0.6"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[12]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.6"],

Cell["We define two random rank 4 tensors :", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.6"],

Cell[BoxData[{
    \(\(T = 
        DefineTensor[Array[Random[] &, {3, 3, 3, 3}], {1, 1, 1, 1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(U = 
        DefineTensor[Array[Random[] &, {3, 3, 3, 3}], {1, 1, 1, 1}, 
          CanonicalBasis];\)\)}], "Input",
  CellLabel->"In[13]:=",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Rank[T . U], Rank[T \[Colon] U], Rank[T \[Therefore] U]}\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \({6, 4, 2}\)], "Output",
  CellLabel->"Out[15]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[TextData[{
  "The result of  ",
  StyleBox["T\[Proportion]U", "Input"],
  StyleBox["  ",
    FontFamily->"Times New Roman"],
  "is a scalar :"
}], "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T \[Proportion] U\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \(22.469896190164775`\)], "Output",
  CellLabel->"Out[16]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell["We can verify an identity :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((OrientationTensor \[Colon] OrientationTensor)\)\ \ \[CircleMinus]\ 
        2\[SmallCircle]MetricTensor // Components\)], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[17]:="],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[17]="]
}, Open  ]],

Cell[TextData[StyleBox["Note the necessary parenthesis on the previous \
command line.",
  FontSize->10]], "Text"],

Cell["Now we define a rank 2 tensor and two vectors :", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.6"],

Cell[BoxData[{
    \(t =. ; 
    T = DefineGeneralTensor[t, {1, 1}, 
        CanonicalBasis];\), "\[IndentingNewLine]", 
    \(u =. ; \ 
    u = DefineGeneralTensor[u, {1}, 
        CanonicalBasis];\), "\[IndentingNewLine]", 
    \(v =. ; \ v = DefineGeneralTensor[v, {1}, CanonicalBasis];\)}], "Input",
  CellLabel->"In[18]:=",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T // Components\)], "Input",
  CellLabel->"In[21]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[21]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \({{t11, t12, t13}, {t21, t22, t23}, {t31, t32, t33}}\)], "Output",
  CellLabel->"Out[21]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(u // Components\)], "Input",
  CellLabel->"In[22]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[22]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \({u1, u2, u3}\)], "Output",
  CellLabel->"Out[22]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Dot",
    FontFamily->"Courier New"],
  " is a ",
  StyleBox["Flat",
    FontFamily->"Courier New"],
  " operator :"
}], "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Hold[u . T . T . v] // FullForm\)], "Input",
  CellLabel->"In[23]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    TagBox[
      StyleBox[\(Hold[Dot[u, T, T, v]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[23]//FullForm=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(u . T . T . v\  - \ u . \((T . T)\) . v\  // Simplify\),
      "Input"]], "Input",
  CellLabel->"In[24]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[24]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(u . T . T . v\  - \ \((u . T)\) . \((T . v)\) // \ Simplify\)], "Input",\

  CellLabel->"In[25]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[25]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[TextData[{
  "How ",
  StyleBox["T.u.v", "Input"],
  " is it interpreted ?"
}], "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Hold[T . u . v] // FullForm\)], "Input",
  CellLabel->"In[26]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    TagBox[
      StyleBox[\(Hold[Dot[T, u, v]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[26]//FullForm=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(T . u . v\  - \ \((T . u)\) . v\),
      "Input"]], "Input",
  CellLabel->"In[27]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[27]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox[\(T . u . v\),
        "Input"], 
      StyleBox[" ",
        "Input"], 
      StyleBox["-",
        "Input"], 
      StyleBox[" ",
        "Input"], 
      RowBox[{
        StyleBox["T",
          "Input"], 
        StyleBox[".",
          "Input"], 
        StyleBox[\((u . v)\),
          "Input"], 
        StyleBox["  ",
          "Input"], 
        RowBox[{
          StyleBox["(*",
            "Input"], 
          StyleBox[" ",
            "Input"], 
          StyleBox[\(tensorial\ nonsense\ \[LongRightArrow]\ unevaluated\),
            "Input",
            FontFamily->"Times New Roman",
            FontWeight->"Plain"], 
          StyleBox[" ",
            "Input"], 
          StyleBox["*)",
            "Input"]}]}]}]], "Input",
  CellLabel->"In[28]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \(\((t11\ u1 + t12\ u2 + t13\ u3)\)\ v1 + \((t21\ u1 + t22\ u2 + 
            t23\ u3)\)\ v2 + \((t31\ u1 + t32\ u2 + t33\ u3)\)\ v3 - 
      Tens3D`Private`Tensor$136 . \((u1\ v1 + u2\ v2 + u3\ v3)\)\)], "Output",\

  CellLabel->"Out[28]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[TextData[{
  "How ",
  StyleBox["u.v.T", "Input"],
  " is it interpreted ?"
}], "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Hold[u . v . T] // FullForm\)], "Input",
  CellLabel->"In[29]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    TagBox[
      StyleBox[\(Hold[Dot[u, v, T]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[29]//FullForm=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(u . v . T\  - u . \((v . T)\)\  // Simplify\)], "Input",
  CellLabel->"In[30]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \(0\)], "Output",
  CellLabel->"Out[30]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(u . v . T\), " ", "-", 
      RowBox[{\((u . v)\), ".", "T", "  ", 
        RowBox[{"(*", " ", 
          StyleBox[\(tensorial\ nonsense\ \[LongRightArrow]\ unevaluated\),
            "Text",
            FontFamily->"Times New Roman",
            FontWeight->"Plain"], " ", "*)"}]}]}]], "Input",
  CellLabel->"In[31]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \(u1\ \((t11\ v1 + t21\ v2 + t31\ v3)\) + 
      u2\ \((t12\ v1 + t22\ v2 + t32\ v3)\) + 
      u3\ \((t13\ v1 + t23\ v2 + t33\ v3)\) - \((u1\ v1 + u2\ v2 + 
            u3\ v3)\) . Tens3D`Private`Tensor$136\)], "Output",
  CellLabel->"Out[31]=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[TextData[{
  "WARNING : How the expression  ",
  StyleBox["T.u.T ", "Input"],
  " is it interpreted ? Here the parenthesis are necessary because the two \
interpretations give different results  :"
}], "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Hold[T . u . T] // FullForm\)], "Input",
  CellLabel->"In[32]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    TagBox[
      StyleBox[\(Hold[Dot[T, u, T]]\),
        ShowSpecialCharacters->False,
        ShowStringCharacters->True,
        NumberMarks->True],
      FullForm]], "Output",
  CellLabel->"Out[32]//FullForm=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(\(T . u . T\ \ \[CircleMinus]\ \ \((T . u)\) . T\  // 
          Components\) // MatrixForm\),
      "Input"]], "Input",
  CellLabel->"In[33]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[33]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(t12\^2\ u1 + t13\^2\ u1 - t21\^2\ u1 - t31\^2\ u1 + 
                  t11\ t21\ u2 - t21\ t22\ u2 - t31\ t32\ u2 - t21\ t23\ u3 + 
                  t11\ t31\ u3 - t31\ t33\ u3 + 
                  t12\ \((\(-t11\)\ u2 + t22\ u2 + t32\ u3)\) + 
                  t13\ \((t23\ u2 - t11\ u3 + t33\ u3)\)\)},
              {\(t11\ \((\(-t12\) + t21)\)\ u1 + t12\ t22\ u1 - 
                  t21\ t22\ u1 + t13\ t23\ u1 - t31\ t32\ u1 - t12\^2\ u2 + 
                  t21\^2\ u2 + t23\^2\ u2 - t32\^2\ u2 - t12\ t13\ u3 - 
                  t22\ t23\ u3 + t21\ t31\ u3 + t22\ t32\ u3 + t23\ t33\ u3 - 
                  t32\ t33\ u3\)},
              {\(\(-t21\)\ t23\ u1 + t11\ \((\(-t13\) + t31)\)\ u1 + 
                  t12\ t32\ u1 + t13\ t33\ u1 - t31\ t33\ u1 - t12\ t13\ u2 - 
                  t22\ t23\ u2 + t21\ t31\ u2 + t22\ t32\ u2 + t23\ t33\ u2 - 
                  t32\ t33\ u2 - t13\^2\ u3 - t23\^2\ u3 + t31\^2\ u3 + 
                  t32\^2\ u3\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[33]//MatrixForm=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(T . u . T\ \ \[CircleMinus]\ \ T . \((u . T)\)\  // 
        Components\),
      "Input"]], "Input",
  CellLabel->"In[34]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[34]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output",
  CellLabel->"Out[34]=",
  CellFrame->{{0, 0}, {0.5, 0}},
  CellTags->"b:0.6"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{840, 740},
WindowMargins->{{9, Automatic}, {Automatic, 60}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.6"->{
    Cell[1776, 53, 72, 1, 48, "Subsection",
      CellTags->"b:0.6"],
    Cell[1851, 56, 2521, 91, 163, "DefinitionBox",
      CellTags->"b:0.6"],
    Cell[4375, 149, 1261, 41, 129, "Text",
      CellTags->"b:0.6"],
    Cell[5639, 192, 2194, 71, 151, "Text",
      CellTags->"b:0.6"],
    Cell[7836, 265, 1953, 63, 168, "Text",
      CellTags->"b:0.6"],
    Cell[9792, 330, 1911, 59, 168, "Text",
      CellTags->"b:0.6"],
    Cell[11706, 391, 291, 6, 48, "Text",
      CellTags->"b:0.6"],
    Cell[12000, 399, 396, 10, 48, "Text",
      CellTags->"b:0.6"],
    Cell[12399, 411, 137, 4, 44, "Input",
      CellTags->"b:0.6"],
    Cell[12539, 417, 108, 2, 29, "Text",
      CellTags->"b:0.6"],
    Cell[12650, 421, 323, 8, 54, "Input",
      CellTags->"b:0.6"],
    Cell[12998, 433, 136, 3, 33, "Input",
      CellTags->"b:0.6"],
    Cell[13137, 438, 89, 3, 32, "Output",
      CellTags->"b:0.6"],
    Cell[13241, 444, 180, 7, 33, "Text",
      CellTags->"b:0.6"],
    Cell[13446, 455, 96, 3, 33, "Input",
      CellTags->"b:0.6"],
    Cell[13545, 460, 99, 3, 32, "Output",
      CellTags->"b:0.6"],
    Cell[14356, 491, 118, 2, 29, "Text",
      CellTags->"b:0.6"],
    Cell[14477, 495, 349, 9, 75, "Input",
      CellTags->"b:0.6"],
    Cell[14851, 508, 94, 3, 33, "Input",
      CellTags->"b:0.6"],
    Cell[14948, 513, 242, 6, 27, "Print",
      CellTags->"b:0.6"],
    Cell[15193, 521, 131, 3, 32, "Output",
      CellTags->"b:0.6"],
    Cell[15361, 529, 94, 3, 33, "Input",
      CellTags->"b:0.6"],
    Cell[15458, 534, 242, 6, 27, "Print",
      CellTags->"b:0.6"],
    Cell[15703, 542, 92, 3, 32, "Output",
      CellTags->"b:0.6"],
    Cell[15810, 548, 177, 8, 29, "Text",
      CellTags->"b:0.6"],
    Cell[16012, 560, 110, 3, 33, "Input",
      CellTags->"b:0.6"],
    Cell[16125, 565, 253, 8, 49, "Output",
      CellTags->"b:0.6"],
    Cell[16415, 578, 157, 4, 33, "Input",
      CellTags->"b:0.6"],
    Cell[16575, 584, 81, 3, 32, "Output",
      CellTags->"b:0.6"],
    Cell[16693, 592, 140, 4, 33, "Input",
      CellTags->"b:0.6"],
    Cell[16836, 598, 81, 3, 32, "Output",
      CellTags->"b:0.6"],
    Cell[16932, 604, 113, 5, 33, "Text",
      CellTags->"b:0.6"],
    Cell[17070, 613, 106, 3, 33, "Input",
      CellTags->"b:0.6"],
    Cell[17179, 618, 250, 8, 49, "Output",
      CellTags->"b:0.6"],
    Cell[17466, 631, 135, 4, 33, "Input",
      CellTags->"b:0.6"],
    Cell[17604, 637, 81, 3, 32, "Output",
      CellTags->"b:0.6"],
    Cell[17722, 645, 831, 33, 33, "Input",
      CellTags->"b:0.6"],
    Cell[18556, 680, 280, 6, 53, "Output",
      CellTags->"b:0.6"],
    Cell[18851, 689, 113, 5, 33, "Text",
      CellTags->"b:0.6"],
    Cell[18989, 698, 106, 3, 33, "Input",
      CellTags->"b:0.6"],
    Cell[19098, 703, 250, 8, 49, "Output",
      CellTags->"b:0.6"],
    Cell[19385, 716, 122, 3, 33, "Input",
      CellTags->"b:0.6"],
    Cell[19510, 721, 81, 3, 32, "Output",
      CellTags->"b:0.6"],
    Cell[19628, 729, 369, 9, 33, "Input",
      CellTags->"b:0.6"],
    Cell[20000, 740, 285, 6, 53, "Output",
      CellTags->"b:0.6"],
    Cell[20300, 749, 235, 6, 52, "Text",
      CellTags->"b:0.6"],
    Cell[20560, 759, 106, 3, 33, "Input",
      CellTags->"b:0.6"],
    Cell[20669, 764, 250, 8, 49, "Output",
      CellTags->"b:0.6"],
    Cell[20956, 777, 195, 5, 33, "Input",
      CellTags->"b:0.6"],
    Cell[21154, 784, 242, 6, 27, "Print",
      CellTags->"b:0.6"],
    Cell[21399, 792, 1327, 26, 89, "Output",
      CellTags->"b:0.6"],
    Cell[22763, 823, 175, 5, 33, "Input",
      CellTags->"b:0.6"],
    Cell[22941, 830, 242, 6, 27, "Print",
      CellTags->"b:0.6"],
    Cell[23186, 838, 122, 4, 43, "Output",
      CellTags->"b:0.6"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.6", 23963, 862}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 72, 1, 48, "Subsection",
  CellTags->"b:0.6"],
Cell[1851, 56, 2521, 91, 163, "DefinitionBox",
  CellTags->"b:0.6"],
Cell[4375, 149, 1261, 41, 129, "Text",
  CellTags->"b:0.6"],
Cell[5639, 192, 2194, 71, 151, "Text",
  CellTags->"b:0.6"],
Cell[7836, 265, 1953, 63, 168, "Text",
  CellTags->"b:0.6"],
Cell[9792, 330, 1911, 59, 168, "Text",
  CellTags->"b:0.6"],
Cell[11706, 391, 291, 6, 48, "Text",
  CellTags->"b:0.6"],
Cell[12000, 399, 396, 10, 48, "Text",
  CellTags->"b:0.6"],
Cell[12399, 411, 137, 4, 44, "Input",
  CellTags->"b:0.6"],
Cell[12539, 417, 108, 2, 29, "Text",
  CellTags->"b:0.6"],
Cell[12650, 421, 323, 8, 54, "Input",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[12998, 433, 136, 3, 33, "Input",
  CellTags->"b:0.6"],
Cell[13137, 438, 89, 3, 32, "Output",
  CellTags->"b:0.6"]
}, Open  ]],
Cell[13241, 444, 180, 7, 33, "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[13446, 455, 96, 3, 33, "Input",
  CellTags->"b:0.6"],
Cell[13545, 460, 99, 3, 32, "Output",
  CellTags->"b:0.6"]
}, Open  ]],
Cell[13659, 466, 43, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[13727, 470, 178, 3, 33, "Input"],
Cell[13908, 475, 221, 5, 27, "Print"],
Cell[14132, 482, 92, 2, 32, "Output"]
}, Open  ]],
Cell[14239, 487, 114, 2, 27, "Text"],
Cell[14356, 491, 118, 2, 29, "Text",
  CellTags->"b:0.6"],
Cell[14477, 495, 349, 9, 75, "Input",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[14851, 508, 94, 3, 33, "Input",
  CellTags->"b:0.6"],
Cell[14948, 513, 242, 6, 27, "Print",
  CellTags->"b:0.6"],
Cell[15193, 521, 131, 3, 32, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15361, 529, 94, 3, 33, "Input",
  CellTags->"b:0.6"],
Cell[15458, 534, 242, 6, 27, "Print",
  CellTags->"b:0.6"],
Cell[15703, 542, 92, 3, 32, "Output",
  CellTags->"b:0.6"]
}, Open  ]],
Cell[15810, 548, 177, 8, 29, "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[16012, 560, 110, 3, 33, "Input",
  CellTags->"b:0.6"],
Cell[16125, 565, 253, 8, 49, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16415, 578, 157, 4, 33, "Input",
  CellTags->"b:0.6"],
Cell[16575, 584, 81, 3, 32, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16693, 592, 140, 4, 33, "Input",
  CellTags->"b:0.6"],
Cell[16836, 598, 81, 3, 32, "Output",
  CellTags->"b:0.6"]
}, Open  ]],
Cell[16932, 604, 113, 5, 33, "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[17070, 613, 106, 3, 33, "Input",
  CellTags->"b:0.6"],
Cell[17179, 618, 250, 8, 49, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17466, 631, 135, 4, 33, "Input",
  CellTags->"b:0.6"],
Cell[17604, 637, 81, 3, 32, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17722, 645, 831, 33, 33, "Input",
  CellTags->"b:0.6"],
Cell[18556, 680, 280, 6, 53, "Output",
  CellTags->"b:0.6"]
}, Open  ]],
Cell[18851, 689, 113, 5, 33, "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[18989, 698, 106, 3, 33, "Input",
  CellTags->"b:0.6"],
Cell[19098, 703, 250, 8, 49, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19385, 716, 122, 3, 33, "Input",
  CellTags->"b:0.6"],
Cell[19510, 721, 81, 3, 32, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19628, 729, 369, 9, 33, "Input",
  CellTags->"b:0.6"],
Cell[20000, 740, 285, 6, 53, "Output",
  CellTags->"b:0.6"]
}, Open  ]],
Cell[20300, 749, 235, 6, 52, "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[20560, 759, 106, 3, 33, "Input",
  CellTags->"b:0.6"],
Cell[20669, 764, 250, 8, 49, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20956, 777, 195, 5, 33, "Input",
  CellTags->"b:0.6"],
Cell[21154, 784, 242, 6, 27, "Print",
  CellTags->"b:0.6"],
Cell[21399, 792, 1327, 26, 89, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22763, 823, 175, 5, 33, "Input",
  CellTags->"b:0.6"],
Cell[22941, 830, 242, 6, 27, "Print",
  CellTags->"b:0.6"],
Cell[23186, 838, 122, 4, 43, "Output",
  CellTags->"b:0.6"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

