(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7739,        287]*)
(*NotebookOutlinePosition[     10153,        364]*)
(*  CellTagsIndexPosition[     10083,        358]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["DefineBasis",
  FontFamily->"Courier New"]], "Subsection",
  CellTags->"b:0.7"],

Cell[TextData[{
  StyleBox["DefineBasis[",
    FontFamily->"Courier New"],
  StyleBox["vector1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["vector2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["vector3",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  "returns the Tens3D basis defined by the three Tens3D vectors (rank 1 \
tens3D tensors)."
}], "DefinitionBox",
  CellTags->"b:0.7"],

Cell[TextData[{
  "If possible, ",
  StyleBox["DefineBasis",
    FontFamily->"Courier New"],
  " prints if the basis is orthogonal , normed and direct or indirect. It may \
be usefull to make some assumptions such that it is possible (see examples \
below)."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.7"],

Cell[TextData[{
  "See also ",
  StyleBox[ButtonBox["DefineCoordinateSystem",
    ButtonData:>{"DefineCoordinateSystem", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["NormalizedBasis",
    ButtonData:>{"NormalizedBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.7"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[1]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.7"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(v1 = 
        DefineTensor[{0, 1, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v2 = 
        DefineTensor[{1, 0, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v3 = 
        DefineTensor[{1, 1, 0}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(basis = DefineBasis[v1, v2, v3]\)}], "Input",
  CellLabel->"In[2]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \("Direct basis."\)], "Print",
  CellLabel->"From In[2]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \(Tens3D`Private`Basis$19\)], "Output",
  CellLabel->"Out[5]=",
  CellTags->"b:0.7"]
}, Open  ]],

Cell["\<\
The covariant components of the metric tensor in this basis are :\
\>", "Text",
  CellTags->"b:0.7"],

Cell[CellGroupData[{

Cell[BoxData[
    \(MTcc = Components[MetricTensor, {\(-1\), \(-1\)}, basis]\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \({{2, 1, 1}, {1, 2, 1}, {1, 1, 2}}\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->"b:0.7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({\ MTcc[\([1, 1]\)] \[Equal] \ v1 . v1\ , \ 
      MTcc[\([1, 2]\)] \[Equal] \ v1 . v2}\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \({True, True}\)], "Output",
  CellLabel->"Out[7]=",
  CellTags->"b:0.7"]
}, Open  ]],

Cell["It may be useful  make some assumptions :", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.7"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\({e1, e2, e3} = 
        BasisVectors[CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(V1 = 
        DefineTensor[{a, b, c}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(V2 = V1\[Wedge]e1;\)\), "\[IndentingNewLine]", 
    \(\(V3 = V1\[Wedge]V2;\)\), "\[IndentingNewLine]", 
    \(basis2 = DefineBasis[V1, V2, V3]\)}], "Input",
  CellLabel->"In[8]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    InterpretationBox[\("Can't find orientation : Sign of \
"\[InvisibleSpace]\(\((b\^2 + c\^2)\)\ \((a\^2 + b\^2 + c\^2)\)\)\),
      SequenceForm[ "Can't find orientation : Sign of ", 
        Times[ 
          Plus[ 
            Power[ b, 2], 
            Power[ c, 2]], 
          Plus[ 
            Power[ a, 2], 
            Power[ b, 2], 
            Power[ c, 2]]]],
      Editable->False]], "Print",
  CellLabel->"From In[8]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \("Unknown orientation orthogonal basis."\)], "Print",
  CellLabel->"From In[8]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \(Tens3D`Private`Basis$102\)], "Output",
  CellLabel->"Out[12]=",
  CellTags->"b:0.7"]
}, Open  ]],

Cell[TextData[StyleBox["Note that the previous warnings are not critical, you \
can always use basis2 in tens3D functions.",
  FontColor->RGBColor[0, 0, 1]]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(DefineTensor[{1, 2, 3}, {1}, basis2]\)], "Input",
  CellLabel->"In[13]:="],

Cell[BoxData[
    \(Tens3D`Private`Tensor$145\)], "Output",
  CellLabel->"Out[13]="]
}, Open  ]],

Cell["\<\
With some assumption the orientation of the basis can be found :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\($Assumptions\  = \ $Assumptions\  && \ a \[NotEqual] 0 && \ 
          a\  \[Element] Reals\  && b \[NotEqual] 0\  && \ 
          b\  \[Element] Reals && c \[NotEqual] 0 && \ 
          c\  \[Element] Reals;\)\), "\[IndentingNewLine]", 
    \(basis2 = DefineBasis[V1, V2, V3]\)}], "Input",
  CellLabel->"In[14]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \("Direct orthogonal basis."\)], "Print",
  CellLabel->"From In[14]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \(Tens3D`Private`Basis$148\)], "Output",
  CellLabel->"Out[15]=",
  CellTags->"b:0.7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(basis3 = NormalizedBasis[basis2];\)\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \("Direct normalized orthogonal basis."\)], "Print",
  CellLabel->"From In[16]:=",
  CellTags->"b:0.7"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[MetricTensor, {\(-1\), \(-1\)}, basis3]\  \[Equal] \ 
      IdentityMatrix[3]\)], "Input",
  CellLabel->"In[17]:=",
  CellTags->"b:0.7"],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[17]=",
  CellFrame->{{0, 0}, {0.5, 0}},
  CellTags->"b:0.7"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{836, 740},
WindowMargins->{{20, Automatic}, {Automatic, 71}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.7"->{
    Cell[1776, 53, 103, 2, 47, "Subsection",
      CellTags->"b:0.7"],
    Cell[1882, 57, 602, 21, 69, "DefinitionBox",
      CellTags->"b:0.7"],
    Cell[2487, 80, 325, 9, 48, "Text",
      CellTags->"b:0.7"],
    Cell[2815, 91, 419, 14, 29, "Text",
      CellTags->"b:0.7"],
    Cell[3237, 107, 136, 4, 44, "Input",
      CellTags->"b:0.7"],
    Cell[3398, 115, 435, 12, 96, "Input",
      CellTags->"b:0.7"],
    Cell[3836, 129, 98, 3, 27, "Print",
      CellTags->"b:0.7"],
    Cell[3937, 134, 102, 3, 32, "Output",
      CellTags->"b:0.7"],
    Cell[4054, 140, 110, 3, 29, "Text",
      CellTags->"b:0.7"],
    Cell[4189, 147, 134, 3, 33, "Input",
      CellTags->"b:0.7"],
    Cell[4326, 152, 112, 3, 32, "Output",
      CellTags->"b:0.7"],
    Cell[4475, 160, 165, 4, 33, "Input",
      CellTags->"b:0.7"],
    Cell[4643, 166, 91, 3, 32, "Output",
      CellTags->"b:0.7"],
    Cell[4749, 172, 112, 2, 29, "Text",
      CellTags->"b:0.7"],
    Cell[4886, 178, 423, 10, 117, "Input",
      CellTags->"b:0.7"],
    Cell[5312, 190, 472, 14, 27, "Print",
      CellTags->"b:0.7"],
    Cell[5787, 206, 122, 3, 27, "Print",
      CellTags->"b:0.7"],
    Cell[5912, 211, 104, 3, 32, "Output",
      CellTags->"b:0.7"],
    Cell[6531, 238, 359, 7, 75, "Input",
      CellTags->"b:0.7"],
    Cell[6893, 247, 110, 3, 27, "Print",
      CellTags->"b:0.7"],
    Cell[7006, 252, 104, 3, 32, "Output",
      CellTags->"b:0.7"],
    Cell[7147, 260, 116, 3, 33, "Input",
      CellTags->"b:0.7"],
    Cell[7266, 265, 121, 3, 27, "Print",
      CellTags->"b:0.7"],
    Cell[7424, 273, 167, 4, 33, "Input",
      CellTags->"b:0.7"],
    Cell[7594, 279, 117, 4, 43, "Output",
      CellTags->"b:0.7"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.7", 8367, 303}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 103, 2, 47, "Subsection",
  CellTags->"b:0.7"],
Cell[1882, 57, 602, 21, 69, "DefinitionBox",
  CellTags->"b:0.7"],
Cell[2487, 80, 325, 9, 48, "Text",
  CellTags->"b:0.7"],
Cell[2815, 91, 419, 14, 29, "Text",
  CellTags->"b:0.7"],
Cell[3237, 107, 136, 4, 44, "Input",
  CellTags->"b:0.7"],

Cell[CellGroupData[{
Cell[3398, 115, 435, 12, 96, "Input",
  CellTags->"b:0.7"],
Cell[3836, 129, 98, 3, 27, "Print",
  CellTags->"b:0.7"],
Cell[3937, 134, 102, 3, 32, "Output",
  CellTags->"b:0.7"]
}, Open  ]],
Cell[4054, 140, 110, 3, 29, "Text",
  CellTags->"b:0.7"],

Cell[CellGroupData[{
Cell[4189, 147, 134, 3, 33, "Input",
  CellTags->"b:0.7"],
Cell[4326, 152, 112, 3, 32, "Output",
  CellTags->"b:0.7"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4475, 160, 165, 4, 33, "Input",
  CellTags->"b:0.7"],
Cell[4643, 166, 91, 3, 32, "Output",
  CellTags->"b:0.7"]
}, Open  ]],
Cell[4749, 172, 112, 2, 29, "Text",
  CellTags->"b:0.7"],

Cell[CellGroupData[{
Cell[4886, 178, 423, 10, 117, "Input",
  CellTags->"b:0.7"],
Cell[5312, 190, 472, 14, 27, "Print",
  CellTags->"b:0.7"],
Cell[5787, 206, 122, 3, 27, "Print",
  CellTags->"b:0.7"],
Cell[5912, 211, 104, 3, 32, "Output",
  CellTags->"b:0.7"]
}, Open  ]],
Cell[6031, 217, 166, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[6222, 223, 94, 2, 33, "Input"],
Cell[6319, 227, 84, 2, 32, "Output"]
}, Open  ]],
Cell[6418, 232, 88, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[6531, 238, 359, 7, 75, "Input",
  CellTags->"b:0.7"],
Cell[6893, 247, 110, 3, 27, "Print",
  CellTags->"b:0.7"],
Cell[7006, 252, 104, 3, 32, "Output",
  CellTags->"b:0.7"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7147, 260, 116, 3, 33, "Input",
  CellTags->"b:0.7"],
Cell[7266, 265, 121, 3, 27, "Print",
  CellTags->"b:0.7"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7424, 273, 167, 4, 33, "Input",
  CellTags->"b:0.7"],
Cell[7594, 279, 117, 4, 43, "Output",
  CellTags->"b:0.7"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

