(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9550,        349]*)
(*NotebookOutlinePosition[     10343,        378]*)
(*  CellTagsIndexPosition[     10272,        372]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["DefineCoordinateSystem",
  FontFamily->"Courier New"]], "Subsection"],

Cell[TextData[{
  StyleBox["DefineCoordinateSystem[",
    FontFamily->"Courier New"],
  StyleBox["vector",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["list",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " returns the natural basis of the coordinates system.\n\n",
  StyleBox["vector",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is a Tens3D vector (a rank 1 Tens3D tensor). It defines the position of a \
point M function of the coordinates.\n\n",
  StyleBox["list",
    FontSlant->"Italic"],
  " is the list of the three names of the coordinates."
}], "DefinitionBox"],

Cell["\<\
The natural basis of a coordinate system is generally non orthonormal.\
\>", "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "The three names of ",
  StyleBox["list",
    FontSlant->"Italic"],
  " must be unassigned symbols."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  StyleBox["vector",
    FontSlant->"Italic"],
  StyleBox[" is normally a function of coordinates names.",
    FontSlant->"Plain"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "If arguments are invalid, ",
  StyleBox["DefineCoordinateSystem",
    FontFamily->"Courier New"],
  " remains unevaluated."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[43]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.7"],

Cell[TextData[{
  "We define the classical cylindrical coordinates system :\na point M is \
function of coordinates ",
  StyleBox["{r,\[Theta],z}",
    FontFamily->"Courier New"],
  " :"
}], "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[BoxData[
    \(r =. ; \[Theta] =. ; z =. ;\)], "Input",
  CellLabel->"In[44]:="],

Cell[BoxData[
    \(\(OM = 
        DefineTensor[{r\ Cos[\[Theta]], r\ Sin[\[Theta]], z}, {1}, 
          CanonicalBasis];\)\)], "Input",
  CellLabel->"In[45]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(OM // Components\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[46]:="],

Cell[BoxData[
    \({r\ Cos[\[Theta]], r\ Sin[\[Theta]], z}\)], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(cyl = DefineCoordinateSystem[OM, {r, \[Theta], z}]\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \("Direct orthogonal natural basis."\)], "Print",
  CellLabel->"From In[47]:="],

Cell[BoxData[
    \(Tens3D`Private`Basis$568\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BasisQ[cyl]\)], "Input",
  CellLabel->"In[48]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[48]="]
}, Open  ]],

Cell["\<\
Previous coordinates system is valid, but with assumptions on r the \
orientation of the natural basis can be found :\
\>", "Text"],

Cell[BoxData[
    \(\($Assumptions\  = \ $Assumptions\  && \ r > 0;\)\)], "Input",
  CellLabel->"In[49]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(cyl = DefineCoordinateSystem[OM, {r, \[Theta], z}]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \("Direct orthogonal natural basis."\)], "Print",
  CellLabel->"From In[50]:="],

Cell[BoxData[
    \(Tens3D`Private`Basis$618\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell["The natural basis is not orthonormal :", "Text"],

Cell[BoxData[
    \(\({e\_r, e\_\[Theta], e\_z} = BasisVectors[cyl];\)\)], "Input",
  CellLabel->"In[51]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \({e\_r . e\_r, e\_\[Theta] . e\_\[Theta], e\_z . e\_z}\)], "Input",
  CellLabel->"In[52]:="],

Cell[BoxData[
    \({1, r\^2, 1}\)], "Output",
  CellLabel->"Out[52]="]
}, Open  ]],

Cell["We can define a colinear basis :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(cylnorm = NormalizedBasis[cyl];\)\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \("Direct normalized orthogonal basis."\)], "Print",
  CellLabel->"From In[53]:="]
}, Open  ]],

Cell["\<\
We define a field vector using the cylindrical coordinates system :\
\>", "Text"],

Cell[BoxData[
    \(\(T = DefineTensor[{a/r, b/r, 0}, {1}, cylnorm];\)\)], "Input",
  CellLabel->"In[54]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {1}, cylnorm]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    \({a\/r, b\/r, 0}\)], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {1}, cyl]\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    \({a\/r, b\/r\^2, 0}\)], "Output",
  CellLabel->"Out[56]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {1}, CanonicalBasis]\)], "Input",
  CellLabel->"In[57]:="],

Cell[BoxData[
    \({\(a\ Cos[\[Theta]] - b\ Sin[\[Theta]]\)\/r, \(b\ Cos[\[Theta]] + a\ \
Sin[\[Theta]]\)\/r, 0}\)], "Output",
  CellLabel->"Out[57]="]
}, Open  ]],

Cell["Definition of the orthonormal catesian coordinates system :", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(x =. ; y =. ; z =. ;\), "\[IndentingNewLine]", 
    \(\(coords = {x, y, z};\)\), "\[IndentingNewLine]", 
    \(\(OM1 = 
        DefineTensor[{x, y, z}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(cart = DefineCoordinateSystem[OM1, coords];\)\)}], "Input",
  CellLabel->"In[58]:="],

Cell[BoxData[
    \("Direct normalized orthogonal natural basis."\)], "Print",
  CellLabel->"From In[58]:="]
}, Open  ]],

Cell["\<\
Definition of the geographical  coordinates system (\[Theta] : longitude , \
\[Phi] : latitude ):\
\>", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(r =. ; \[Theta] =. ; \[Phi] =. ;\), "\[IndentingNewLine]", 
    \(\($Assumptions = $Assumptions\  && \ 
          r > 0\  && \ \[Theta] > 0\  && \ \[Theta] < 
            2\ Pi\  && \ \[Phi] > \ \(-Pi\)/2\  && \ \[Phi] < 
            Pi/2;\)\), "\[IndentingNewLine]", 
    \(\(coords = {r, \[Theta], \[Phi]};\)\), "\[IndentingNewLine]", 
    \(\(OM2 = 
        DefineTensor[{r\ Cos[\[Theta]]\ Cos[\[Phi]], \ 
            r\ Sin[\[Theta]]\ Cos[\[Phi]], r\ Sin[\[Phi]]}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(cart = DefineCoordinateSystem[OM2, coords];\)\)}], "Input",
  CellLabel->"In[62]:="],

Cell[BoxData[
    \("Direct orthogonal natural basis."\)], "Print",
  CellLabel->"From In[62]:="]
}, Open  ]],

Cell["\<\
Definition of the toro\[IHat]dal  coordinates system :\
\>", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(r =. ; \[Theta] =. ; \[Phi] =. ;\), "\[IndentingNewLine]", 
    \(\($Assumptions = $Assumptions\  && \ R > 0\  && r > 0\  && \ 
          r < R\  && \ \[Theta] > 0\  && \ \[Theta] < 2\ Pi\  && \ \[Phi] > \ 
            0\  && \ \[Phi] < 2\ Pi;\)\), "\[IndentingNewLine]", 
    \(\(coords = {r, \[Theta], \[Phi]};\)\), "\[IndentingNewLine]", 
    \(\(OM3 = 
        DefineTensor[{\((R\  + r\ Cos[\[Phi]])\)\ Cos[\[Theta]]\ , \ \((R\  + 
                  r\ Cos[\[Phi]])\)\ \ Sin[\[Theta]], r\ Sin[\[Phi]]}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(tor = DefineCoordinateSystem[OM2, coords];\)\)}], "Input",
  CellLabel->"In[67]:="],

Cell[BoxData[
    \("Direct orthogonal natural basis."\)], "Print",
  CellLabel->"From In[67]:=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{673, 740},
WindowMargins->{{245, Automatic}, {Automatic, 69}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.7"->{
    Cell[3333, 111, 137, 4, 44, "Input",
      CellTags->"b:0.7"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.7", 10179, 365}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 93, 1, 47, "Subsection"],
Cell[1872, 56, 774, 24, 164, "DefinitionBox"],
Cell[2649, 82, 128, 3, 29, "Text"],
Cell[2780, 87, 164, 6, 29, "Text"],
Cell[2947, 95, 192, 6, 29, "Text"],
Cell[3142, 103, 188, 6, 29, "Text"],
Cell[3333, 111, 137, 4, 44, "Input",
  CellTags->"b:0.7"],
Cell[3473, 117, 232, 7, 56, "Text"],
Cell[3708, 126, 85, 2, 33, "Input"],
Cell[3796, 130, 162, 4, 33, "Input"],

Cell[CellGroupData[{
Cell[3983, 138, 74, 2, 33, "Input"],
Cell[4060, 142, 221, 5, 27, "Print"],
Cell[4284, 149, 98, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4419, 156, 108, 2, 33, "Input"],
Cell[4530, 160, 97, 2, 27, "Print"],
Cell[4630, 164, 83, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4750, 171, 69, 2, 33, "Input"],
Cell[4822, 175, 63, 2, 32, "Output"]
}, Open  ]],
Cell[4900, 180, 141, 3, 48, "Text"],
Cell[5044, 185, 107, 2, 33, "Input"],

Cell[CellGroupData[{
Cell[5176, 191, 108, 2, 33, "Input"],
Cell[5287, 195, 97, 2, 27, "Print"],
Cell[5387, 199, 83, 2, 32, "Output"]
}, Open  ]],
Cell[5485, 204, 54, 0, 29, "Text"],
Cell[5542, 206, 108, 2, 33, "Input"],

Cell[CellGroupData[{
Cell[5675, 212, 111, 2, 33, "Input"],
Cell[5789, 216, 71, 2, 32, "Output"]
}, Open  ]],
Cell[5875, 221, 48, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[5948, 225, 93, 2, 33, "Input"],
Cell[6044, 229, 100, 2, 27, "Print"]
}, Open  ]],
Cell[6159, 234, 91, 2, 29, "Text"],
Cell[6253, 238, 108, 2, 33, "Input"],

Cell[CellGroupData[{
Cell[6386, 244, 85, 2, 33, "Input"],
Cell[6474, 248, 74, 2, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6585, 255, 81, 2, 33, "Input"],
Cell[6669, 259, 77, 2, 46, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[6783, 266, 92, 2, 33, "Input"],
Cell[6878, 270, 152, 3, 47, "Output"]
}, Open  ]],
Cell[7045, 276, 109, 1, 29, "Text"],

Cell[CellGroupData[{
Cell[7179, 281, 327, 7, 96, "Input"],
Cell[7509, 290, 108, 2, 27, "Print"]
}, Open  ]],
Cell[7632, 295, 155, 4, 29, "Text"],

Cell[CellGroupData[{
Cell[7812, 303, 644, 12, 180, "Input"],
Cell[8459, 317, 97, 2, 27, "Print"]
}, Open  ]],
Cell[8571, 322, 112, 3, 29, "Text"],

Cell[CellGroupData[{
Cell[8708, 329, 681, 11, 159, "Input"],
Cell[9392, 342, 130, 3, 38, "Print"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

