(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7232,        235]*)
(*NotebookOutlinePosition[      7915,        258]*)
(*  CellTagsIndexPosition[      7871,        254]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["DefineGeneralTensor",
  FontFamily->"Courier New"]], "Subsection"],

Cell[TextData[{
  StyleBox["DefineGeneralTensor[",
    FontFamily->"Courier New"],
  StyleBox["symbol",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["list1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["basis",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["list2",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  StyleBox["returns a Tens3D tensor.\n\n",
    FontFamily->"Times New Roman"],
  StyleBox["symbol",
    FontSlant->"Italic"],
  " is a generic name for the components. It must be unaffected. It will be \
concatened with the value of the indices to form a name for each component.\n\
\n",
  StyleBox["list1",
    FontSlant->"Italic"],
  " is the list of variances of the indices (see ",
  StyleBox[ButtonBox["DefineTensor",
    ButtonData:>{"DefineTensor", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "). The length of ",
  StyleBox["list1",
    FontSlant->"Italic"],
  " is the rank of the tensor.\n\n",
  StyleBox["basis",
    FontSlant->"Italic"],
  " is the Tens3d basis where these components are valid (see ",
  StyleBox[ButtonBox["DefineTensor",
    ButtonData:>{"DefineTensor", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ").\n\n",
  StyleBox["list2",
    FontSlant->"Italic"],
  " is optional. This is the a list of variables if the components are \
functions. Default value is ",
  StyleBox["{} ",
    FontFamily->"Courier New"],
  " (see ",
  ButtonBox["Analysis Calculations",
    ButtonData:>{"Analysis", None},
    ButtonStyle->"AddOnsLink"],
  ")."
}], "DefinitionBox"],

Cell[TextData[{
  "When you are defining a general tensor, you can use the same symbol on the \
left hand side and the right hand side of \"=\"\n(like ",
  StyleBox["T = ", "Input"],
  StyleBox["DefineGeneralTensor[", "Input",
    FontFamily->"Courier New"],
  StyleBox["T", "Input"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["list1",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["basis",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["list2",
    FontSlant->"Italic"],
  StyleBox["]", "Input",
    FontFamily->"Courier New"],
  StyleBox[")",
    FontFamily->"Courier New"],
  StyleBox[" but this command can not be executed twice because ",
    FontFamily->"Times New Roman"],
  StyleBox["T", "Input",
    FontFamily->"Courier New"],
  StyleBox[" is no more an unaffected symbol.",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[{
    \(\(Needs["\<Tens3D`\>"];\)\), "\[IndentingNewLine]", 
    \(\(B0 = CanonicalBasis;\)\)}], "Input",
  CellLabel->"In[24]:=",
  CellFrame->{{0, 0}, {0, 0.5}}],

Cell["Definition of a general rank 3 constant tensor :", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[BoxData[{
    \(\(T =. ;\)\), "\[IndentingNewLine]", 
    \(\(T = DefineGeneralTensor[T, {1, \(-1\), \(-1\)}, B0];\)\)}], "Input",
  CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(T // Components\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[28]:="],

Cell[BoxData[
    \({{{T111, T112, T113}, {T121, T122, T123}, {T131, T132, T133}}, {{T211, 
          T212, T213}, {T221, T222, T223}, {T231, T232, T233}}, {{T311, T312, 
          T313}, {T321, T322, T323}, {T331, T332, T333}}}\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell["Definition of a general rank 2 tensor field :", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[BoxData[
    \(\(P = 
        DefineGeneralTensor[PCc, {1, \(-1\)}, 
          B0, {t, r, \[Theta], z}];\)\)], "Input",
  CellLabel->"In[29]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(P // Components\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[30]:="],

Cell[BoxData[
    \({{PCc11[t, r, \[Theta], z], PCc12[t, r, \[Theta], z], 
        PCc13[t, r, \[Theta], z]}, {PCc21[t, r, \[Theta], z], 
        PCc22[t, r, \[Theta], z], 
        PCc23[t, r, \[Theta], z]}, {PCc31[t, r, \[Theta], z], 
        PCc32[t, r, \[Theta], z], PCc33[t, r, \[Theta], z]}}\)], "Output",
  CellLabel->"Out[30]="]
}, Open  ]],

Cell[TextData[StyleBox["Tip : In the previous command the generic name has \
been choosen like this : P is the name of the tensor, letters C an c reminds \
the variances of the components. This is usefull when components are on a non \
orthonormal basis.",
  FontSize->10]], "Text",
  CellFrame->{{0, 0}, {0.5, 0}}],

Cell[TextData[{
  "See also ",
  StyleBox[ButtonBox["Derivative",
    ButtonData:>{"Deriv", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " and  ",
  StyleBox[ButtonBox["Analysis Calculations",
    ButtonData:>{"Analysis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Times New Roman"],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{686, 740},
WindowMargins->{{Automatic, 168}, {41, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 90, 1, 47, "Subsection"],
Cell[1869, 56, 1727, 57, 260, "DefinitionBox"],
Cell[3599, 115, 985, 31, 101, "Text"],
Cell[4587, 148, 176, 4, 65, "Input"],
Cell[4766, 154, 98, 1, 29, "Text"],
Cell[4867, 157, 160, 3, 54, "Input"],

Cell[CellGroupData[{
Cell[5052, 164, 73, 2, 33, "Input"],
Cell[5128, 168, 221, 5, 27, "Print"],
Cell[5352, 175, 267, 4, 74, "Output"]
}, Open  ]],
Cell[5634, 182, 95, 1, 29, "Text"],
Cell[5732, 185, 149, 4, 33, "Input"],

Cell[CellGroupData[{
Cell[5906, 193, 73, 2, 33, "Input"],
Cell[5982, 197, 221, 5, 27, "Print"],
Cell[6206, 204, 335, 6, 74, "Output"]
}, Open  ]],
Cell[6556, 213, 315, 5, 54, "Text"],
Cell[6874, 220, 342, 12, 29, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

