(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12874,        448]*)
(*NotebookOutlinePosition[     16365,        557]*)
(*  CellTagsIndexPosition[     16294,        551]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["DefineTensor",
  FontFamily->"Courier New"]], "Subsection",
  CellTags->"b:0.8"],

Cell[TextData[{
  StyleBox["DefineTensor[",
    FontFamily->"Courier New"],
  StyleBox["array ",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  " ",
  StyleBox["list ",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  " ",
  StyleBox["basis",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  returns a Tens3D tensor.\n\n",
  StyleBox["array",
    FontSlant->"Italic"],
  " is the array of components values,\n\n",
  StyleBox["list ",
    FontSlant->"Italic"],
  " is the list of the variances of the indicies (contravariant = ",
  StyleBox["1",
    FontFamily->"Courier New"],
  ",covariant = ",
  StyleBox["-1",
    FontFamily->"Courier New"],
  "),\n\n",
  StyleBox["basis",
    FontSlant->"Italic"],
  " is the basis where these components are valid."
}], "DefinitionBox",
  CellTags->"b:0.8"],

Cell[TextData[{
  "The depth of ",
  StyleBox["array",
    FontSlant->"Italic"],
  " is the rank of the tensor."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.8"],

Cell[TextData[{
  "If the values of ",
  StyleBox["array",
    FontSlant->"Italic"],
  " are functions of variables, the tensor is variable. It can be derived \
(see ",
  StyleBox[ButtonBox["Derivative",
    ButtonData:>{"Derivative", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ").\nIf these variables are coordinates, ",
  StyleBox["DefineTensor",
    FontFamily->"Courier New"],
  " defines a tensor field (see ",
  StyleBox[ButtonBox["Analysis Calculations",
    ButtonData:>{"Analysis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Times New Roman"],
  ")."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.8"],

Cell[TextData[{
  StyleBox["list",
    FontSlant->"Italic"],
  " contains only ",
  StyleBox["1",
    FontFamily->"Courier New"],
  " or ",
  StyleBox["-1",
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.8"],

Cell[TextData[{
  "The length of ",
  StyleBox["list",
    FontSlant->"Italic"],
  " must be equal to the rank (each indice has its variance)."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.8"],

Cell[TextData[{
  StyleBox["basis",
    FontSlant->"Italic"],
  " is a valid previously defined Tens3D basis (",
  StyleBox[ButtonBox["CanonicalBasis",
    ButtonData:>{"Predef", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or defined with ",
  StyleBox[ButtonBox["DefineBasis",
    ButtonData:>{"DefineBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["DefineCoordinateSysytem",
    ButtonData:>{"DefineCoordinateSystem", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or ",
  StyleBox[ButtonBox["NormalizedBasis",
    ButtonData:>{"NormalizedBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ")."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.8"],

Cell[TextData[{
  "If  the depth of ",
  StyleBox["array",
    FontSlant->"Italic"],
  " is 1 (a list of components), the tensor is rank 1 (a vector) and list is \
",
  StyleBox["{1}",
    FontFamily->"Courier New"],
  " or ",
  StyleBox["{-1}",
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[GraySquare]",
  CellTags->"b:0.8"],

Cell[BoxData[{
    \(\(Needs["\<Tens3D`\>"];\)\), "\[IndentingNewLine]", 
    \(\(B0 = CanonicalBasis;\)\)}], "Input",
  CellLabel->"In[1]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.8"],

Cell["\<\
Definition of a Tens3D vector by its contravariant components (ordinary \
components) on canonical basis:\
\>", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.8"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vec1 = DefineTensor[{a, b, c}, {1}, B0]\)], "Input",
  CellLabel->"In[3]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    \(Tens3D`Private`Tensor$16\)], "Output",
  CellLabel->"Out[3]=",
  CellTags->"b:0.8"]
}, Open  ]],

Cell[TextData[StyleBox["The integers following Tens3D`Private`Tensor$ are \
meaningless. They may vary in different sessions. If you don't want to see \
the output, put a semi colon (;) at the end of the command line.",
  FontSize->10,
  FontColor->RGBColor[0, 0, 1]]], "Text",
  CellTags->"b:0.8"],

Cell["Another way to define the same vector :", "Text",
  CellTags->"b:0.8"],

Cell[BoxData[{
    \(\({e1, e2, e3} = BasisVectors[B0];\)\), "\[IndentingNewLine]", 
    \(\(vec2\  = \ 
        a\[SmallCircle]e1\ \[CirclePlus]\ b\[SmallCircle]e2\ \[CirclePlus]\ 
          c\[SmallCircle]e3;\)\)}], "Input",
  CellLabel->"In[4]:=",
  CellTags->"b:0.8"],

Cell[TextData[{
  StyleBox["We verify that ", "Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  StyleBox["vec1", "Input"],
  " and ",
  StyleBox["vec2", "Input"],
  " are equal :"
}], "Text",
  CellTags->"b:0.8"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vec1\ \[CircleMinus]\ vec2\  // Components\)], "Input",
  CellLabel->"In[6]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[6]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output",
  CellLabel->"Out[6]=",
  CellTags->"b:0.8"]
}, Open  ]],

Cell["\<\
Definition of a rank 2 Tens3D tensor by its contravariant-covariant \
components on canonical basis :\
\>", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.8"],

Cell[BoxData[
    \(\(T1 = 
        DefineTensor[{{t11, t12, t13}, {t21, t22, t23}, {t31, t32, 
              t33}}, {1, \(-1\)}, B0];\)\)], "Input",
  CellLabel->"In[7]:=",
  CellTags->"b:0.8"],

Cell["A very complicate way to define the same tensor :", "Text",
  CellTags->"b:0.8"],

Cell[BoxData[{
    \(\({E1, E2, E3} = \ DualBasisVectors[B0];\)\), "\[IndentingNewLine]", 
    \(\(T2 = \ 
        t11\[SmallCircle]e1\[CircleTimes]E1\ \[CirclePlus]\ 
          t12\[SmallCircle]e1\[CircleTimes]E2\ \[CirclePlus]\ 
          t13\[SmallCircle]
              e1\[CircleTimes]E3\ \[CirclePlus]\ \[IndentingNewLine]t21\
\[SmallCircle]e2\[CircleTimes]E1\ \[CirclePlus]\ 
          t22\[SmallCircle]e2\[CircleTimes]E2\ \[CirclePlus]\ 
          t23\[SmallCircle]
              e2\[CircleTimes]E3\ \[CirclePlus]\ \[IndentingNewLine]t31\
\[SmallCircle]e3\[CircleTimes]E1\ \[CirclePlus]\ 
          t32\[SmallCircle]e3\[CircleTimes]E2\ \[CirclePlus]\ 
          t33\[SmallCircle]e3\[CircleTimes]E3;\)\)}], "Input",
  CellLabel->"In[8]:=",
  CellTags->"b:0.8"],

Cell[TextData[{
  StyleBox["We verify that", "Input",
    FontFamily->"Times New Roman",
    FontWeight->"Plain"],
  " ",
  StyleBox["T1",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["T2",
    FontFamily->"Courier New"],
  " are equal :"
}], "Text",
  CellTags->"b:0.8"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T2\ \[CircleMinus]\ T1\  // \ Components\)], "Input",
  CellLabel->"In[10]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[10]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[10]=",
  CellTags->"b:0.8"]
}, Open  ]],

Cell["A very simple way to define the same tensor :", "Text",
  CellTags->"b:0.8"],

Cell[BoxData[
    \(\(T3\  = \ DefineGeneralTensor[t, {1, \(-1\)}, B0];\)\)], "Input",
  CellLabel->"In[11]:=",
  CellTags->"b:0.8"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T3, {1, \(-1\)}, B0]\)], "Input",
  CellLabel->"In[12]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    \({{t11, t12, t13}, {t21, t22, t23}, {t31, t32, t33}}\)], "Output",
  CellLabel->"Out[12]=",
  CellTags->"b:0.8"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(T1\ \[CircleMinus]\ T3\  // \ Components\)], "Input",
  CellLabel->"In[13]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[13]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[13]=",
  CellTags->"b:0.8"]
}, Open  ]],

Cell["\<\
Definition of a rank 3 random  Tens3D tensor by its contravariant components \
on canonical basis :\
\>", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.8"],

Cell[CellGroupData[{

Cell[BoxData[
    \(componentsArray = Array[Random[] &, {3, 3, 3}]\)], "Input",
  CellLabel->"In[14]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    \({{{0.8565976148320132`, 0.6221373259601528`, 
          0.0957388495861267`}, {0.9146696967106717`, 0.3852407423275243`, 
          0.09808540724441506`}, {0.7694054227294285`, 0.19038606351993667`, 
          0.012313785624427849`}}, {{0.2678577106274627`, 
          0.6881738347326889`, 0.3434671176996701`}, {0.3915150065736705`, 
          0.2861099029138318`, 0.012164979099515305`}, {0.8281439169359114`, 
          0.3067786215424137`, 0.19720629399233822`}}, {{0.6258839618563218`, 
          0.1446301762154669`, 0.007506383679892089`}, {0.7782767172452385`, 
          0.5277765910981764`, 0.9056954836291885`}, {0.15090876884787882`, 
          0.15613939128508578`, 0.4320377415120497`}}}\)], "Output",
  CellLabel->"Out[14]=",
  CellTags->"b:0.8"]
}, Open  ]],

Cell[BoxData[
    \(\(T4 = DefineTensor[componentsArray, {1, 1, 1}, B0];\)\)], "Input",
  CellLabel->"In[15]:=",
  CellTags->"b:0.8"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T4 // \ Components\)], "Input",
  CellLabel->"In[16]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[16]:=",
  CellTags->"b:0.8"],

Cell[BoxData[
    \({{{0.8565976148320132`, 0.6221373259601528`, 
          0.0957388495861267`}, {0.9146696967106717`, 0.3852407423275243`, 
          0.09808540724441506`}, {0.7694054227294285`, 0.19038606351993667`, 
          0.012313785624427849`}}, {{0.2678577106274627`, 
          0.6881738347326889`, 0.3434671176996701`}, {0.3915150065736705`, 
          0.2861099029138318`, 0.012164979099515305`}, {0.8281439169359114`, 
          0.3067786215424137`, 0.19720629399233822`}}, {{0.6258839618563218`, 
          0.1446301762154669`, 0.007506383679892089`}, {0.7782767172452385`, 
          0.5277765910981764`, 0.9056954836291885`}, {0.15090876884787882`, 
          0.15613939128508578`, 0.4320377415120497`}}}\)], "Output",
  CellLabel->"Out[16]=",
  CellFrame->{{0, 0}, {0.5, 0}},
  CellTags->"b:0.8"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{697, 740},
WindowMargins->{{262, Automatic}, {Automatic, 93}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.8"->{
    Cell[1776, 53, 104, 2, 47, "Subsection",
      CellTags->"b:0.8"],
    Cell[1883, 57, 932, 36, 165, "DefinitionBox",
      CellTags->"b:0.8"],
    Cell[2818, 95, 179, 7, 29, "Text",
      CellTags->"b:0.8"],
    Cell[3000, 104, 669, 21, 75, "Text",
      CellTags->"b:0.8"],
    Cell[3672, 127, 261, 12, 29, "Text",
      CellTags->"b:0.8"],
    Cell[3936, 141, 210, 7, 29, "Text",
      CellTags->"b:0.8"],
    Cell[4149, 150, 814, 26, 48, "Text",
      CellTags->"b:0.8"],
    Cell[4966, 178, 348, 14, 29, "Text",
      CellTags->"b:0.8"],
    Cell[5317, 194, 196, 5, 65, "Input",
      CellTags->"b:0.8"],
    Cell[5516, 201, 184, 5, 48, "Text",
      CellTags->"b:0.8"],
    Cell[5725, 210, 117, 3, 33, "Input",
      CellTags->"b:0.8"],
    Cell[5845, 215, 103, 3, 32, "Output",
      CellTags->"b:0.8"],
    Cell[5963, 221, 298, 5, 44, "Text",
      CellTags->"b:0.8"],
    Cell[6264, 228, 76, 1, 29, "Text",
      CellTags->"b:0.8"],
    Cell[6343, 231, 271, 6, 54, "Input",
      CellTags->"b:0.8"],
    Cell[6617, 239, 234, 9, 34, "Text",
      CellTags->"b:0.8"],
    Cell[6876, 252, 120, 3, 33, "Input",
      CellTags->"b:0.8"],
    Cell[6999, 257, 241, 6, 27, "Print",
      CellTags->"b:0.8"],
    Cell[7243, 265, 88, 3, 32, "Output",
      CellTags->"b:0.8"],
    Cell[7346, 271, 180, 5, 29, "Text",
      CellTags->"b:0.8"],
    Cell[7529, 278, 194, 5, 54, "Input",
      CellTags->"b:0.8"],
    Cell[7726, 285, 86, 1, 29, "Text",
      CellTags->"b:0.8"],
    Cell[7815, 288, 766, 15, 96, "Input",
      CellTags->"b:0.8"],
    Cell[8584, 305, 280, 12, 33, "Text",
      CellTags->"b:0.8"],
    Cell[8889, 321, 119, 3, 33, "Input",
      CellTags->"b:0.8"],
    Cell[9011, 326, 242, 6, 27, "Print",
      CellTags->"b:0.8"],
    Cell[9256, 334, 113, 3, 32, "Output",
      CellTags->"b:0.8"],
    Cell[9384, 340, 82, 1, 29, "Text",
      CellTags->"b:0.8"],
    Cell[9469, 343, 132, 3, 33, "Input",
      CellTags->"b:0.8"],
    Cell[9626, 350, 110, 3, 33, "Input",
      CellTags->"b:0.8"],
    Cell[9739, 355, 131, 3, 32, "Output",
      CellTags->"b:0.8"],
    Cell[9907, 363, 119, 3, 33, "Input",
      CellTags->"b:0.8"],
    Cell[10029, 368, 242, 6, 27, "Print",
      CellTags->"b:0.8"],
    Cell[10274, 376, 113, 3, 32, "Output",
      CellTags->"b:0.8"],
    Cell[10402, 382, 178, 5, 29, "Text",
      CellTags->"b:0.8"],
    Cell[10605, 391, 125, 3, 33, "Input",
      CellTags->"b:0.8"],
    Cell[10733, 396, 781, 12, 158, "Output",
      CellTags->"b:0.8"],
    Cell[11529, 411, 133, 3, 33, "Input",
      CellTags->"b:0.8"],
    Cell[11687, 418, 97, 3, 33, "Input",
      CellTags->"b:0.8"],
    Cell[11787, 423, 242, 6, 27, "Print",
      CellTags->"b:0.8"],
    Cell[12032, 431, 814, 13, 169, "Output",
      CellTags->"b:0.8"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.8", 13503, 464}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 104, 2, 47, "Subsection",
  CellTags->"b:0.8"],
Cell[1883, 57, 932, 36, 165, "DefinitionBox",
  CellTags->"b:0.8"],
Cell[2818, 95, 179, 7, 29, "Text",
  CellTags->"b:0.8"],
Cell[3000, 104, 669, 21, 75, "Text",
  CellTags->"b:0.8"],
Cell[3672, 127, 261, 12, 29, "Text",
  CellTags->"b:0.8"],
Cell[3936, 141, 210, 7, 29, "Text",
  CellTags->"b:0.8"],
Cell[4149, 150, 814, 26, 48, "Text",
  CellTags->"b:0.8"],
Cell[4966, 178, 348, 14, 29, "Text",
  CellTags->"b:0.8"],
Cell[5317, 194, 196, 5, 65, "Input",
  CellTags->"b:0.8"],
Cell[5516, 201, 184, 5, 48, "Text",
  CellTags->"b:0.8"],

Cell[CellGroupData[{
Cell[5725, 210, 117, 3, 33, "Input",
  CellTags->"b:0.8"],
Cell[5845, 215, 103, 3, 32, "Output",
  CellTags->"b:0.8"]
}, Open  ]],
Cell[5963, 221, 298, 5, 44, "Text",
  CellTags->"b:0.8"],
Cell[6264, 228, 76, 1, 29, "Text",
  CellTags->"b:0.8"],
Cell[6343, 231, 271, 6, 54, "Input",
  CellTags->"b:0.8"],
Cell[6617, 239, 234, 9, 34, "Text",
  CellTags->"b:0.8"],

Cell[CellGroupData[{
Cell[6876, 252, 120, 3, 33, "Input",
  CellTags->"b:0.8"],
Cell[6999, 257, 241, 6, 27, "Print",
  CellTags->"b:0.8"],
Cell[7243, 265, 88, 3, 32, "Output",
  CellTags->"b:0.8"]
}, Open  ]],
Cell[7346, 271, 180, 5, 29, "Text",
  CellTags->"b:0.8"],
Cell[7529, 278, 194, 5, 54, "Input",
  CellTags->"b:0.8"],
Cell[7726, 285, 86, 1, 29, "Text",
  CellTags->"b:0.8"],
Cell[7815, 288, 766, 15, 96, "Input",
  CellTags->"b:0.8"],
Cell[8584, 305, 280, 12, 33, "Text",
  CellTags->"b:0.8"],

Cell[CellGroupData[{
Cell[8889, 321, 119, 3, 33, "Input",
  CellTags->"b:0.8"],
Cell[9011, 326, 242, 6, 27, "Print",
  CellTags->"b:0.8"],
Cell[9256, 334, 113, 3, 32, "Output",
  CellTags->"b:0.8"]
}, Open  ]],
Cell[9384, 340, 82, 1, 29, "Text",
  CellTags->"b:0.8"],
Cell[9469, 343, 132, 3, 33, "Input",
  CellTags->"b:0.8"],

Cell[CellGroupData[{
Cell[9626, 350, 110, 3, 33, "Input",
  CellTags->"b:0.8"],
Cell[9739, 355, 131, 3, 32, "Output",
  CellTags->"b:0.8"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9907, 363, 119, 3, 33, "Input",
  CellTags->"b:0.8"],
Cell[10029, 368, 242, 6, 27, "Print",
  CellTags->"b:0.8"],
Cell[10274, 376, 113, 3, 32, "Output",
  CellTags->"b:0.8"]
}, Open  ]],
Cell[10402, 382, 178, 5, 29, "Text",
  CellTags->"b:0.8"],

Cell[CellGroupData[{
Cell[10605, 391, 125, 3, 33, "Input",
  CellTags->"b:0.8"],
Cell[10733, 396, 781, 12, 158, "Output",
  CellTags->"b:0.8"]
}, Open  ]],
Cell[11529, 411, 133, 3, 33, "Input",
  CellTags->"b:0.8"],

Cell[CellGroupData[{
Cell[11687, 418, 97, 3, 33, "Input",
  CellTags->"b:0.8"],
Cell[11787, 423, 242, 6, 27, "Print",
  CellTags->"b:0.8"],
Cell[12032, 431, 814, 13, 169, "Output",
  CellTags->"b:0.8"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

