(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14178,        493]*)
(*NotebookOutlinePosition[     15093,        526]*)
(*  CellTagsIndexPosition[     14999,        519]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["D ",
    FontFamily->"Courier New"],
  StyleBox["(partial derivative)",
    FontFamily->"Arial"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["D[", "MR"],
  StyleBox["tensor", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["x", "TI"],
  StyleBox["]", "MR"],
  " gives the partial derivative ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[PartialD]", 
            StyleBox["tensor",
              "TI"]}], "/", 
          RowBox[{"\[PartialD]", 
            StyleBox["x",
              "TI"]}]}], TraditionalForm]], "InlineFormula"],
  ". \n",
  StyleBox["D[", "MR"],
  StyleBox["tensor", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["{", "MR"],
  StyleBox["x", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["n", "TI"],
  StyleBox["}]", "MR"],
  " gives the multiple derivative ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["\[PartialD]", 
              StyleBox["n",
                "TI"]], 
            StyleBox["tensor",
              "TI"]}], "/", 
          RowBox[{"\[PartialD]", 
            SuperscriptBox[
              StyleBox["x",
                "TI"], 
              StyleBox["n",
                "TI"]]}]}], TraditionalForm]], "InlineFormula"],
  ". \n",
  StyleBox["D[", "MR"],
  StyleBox["tensor", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["x", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["y", "TI"],
  StyleBox[",", "MR"],
  " \[Ellipsis] ",
  StyleBox["]", "MR"],
  " gives ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[PartialD]", 
              RowBox[{"/", 
                RowBox[{"\[PartialD]", 
                  RowBox[{
                    StyleBox["x",
                      "TI"], " ", 
                    RowBox[{"\[PartialD]", 
                      RowBox[{"/", 
                        RowBox[{"\[PartialD]", 
                          StyleBox["y",
                            "TI"]}]}]}]}]}]}]}], " ", "..."}], " ", 
          StyleBox["tensor",
            "TI"]}], TraditionalForm]], "InlineFormula"],
  ". "
}], "Usage",
  CellDingbat->None,
  CellTags->{"S0.1218", "D"}],

Cell[TextData[{
  StyleBox["D",
    FontFamily->"Courier New"],
  " is an over definition of the classical ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " function. The syntax is exactly th same."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  StyleBox["If ",
    FontFamily->"Times New Roman"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" is not a Tens3D tensor, ",
    FontFamily->"Times New Roman"],
  StyleBox["the classical ",
    FontFamily->"Times New Roman"],
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["D",
    FontFamily->"Courier New"],
  " function",
  StyleBox[" is applied.",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  StyleBox["D[", "MR"],
  StyleBox["tensor", "TI"],
  StyleBox[",", "MR"],
  " ",
  StyleBox["...", "TI"],
  StyleBox["]", "MR"],
  " returns a Tens3D tensor with the same rank."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  StyleBox["D[",
    FontFamily->"Courier New"],
  StyleBox["tensor", "TI"],
  StyleBox[", ",
    FontFamily->"Courier New"],
  StyleBox["var", "TI"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  "can be entered as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[PartialD]", 
            StyleBox["var",
              FontSlant->"Italic"]], " ", 
          StyleBox["tensor",
            FontSlant->"Italic"]}], TraditionalForm]]]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  StyleBox["D[",
    FontFamily->"Courier New"],
  StyleBox["tensor", "TI"],
  StyleBox[", ",
    FontFamily->"Courier New"],
  StyleBox["var", "TI"],
  StyleBox["1, ",
    FontFamily->"Courier New"],
  StyleBox["var", "TI"],
  StyleBox["2,...] ",
    FontFamily->"Courier New"],
  "can be entered as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox["\[PartialD]", 
            RowBox[{
              StyleBox[
                RowBox[{
                  StyleBox["var",
                    "TI",
                    FontSlant->"Italic"], 
                  StyleBox["1",
                    FontFamily->"Courier New",
                    FontSlant->"Italic"]}]], 
              StyleBox[",",
                FontFamily->"Courier New",
                FontSlant->"Italic"], 
              StyleBox["var2",
                "TI"], 
              StyleBox[",",
                "TI"], 
              StyleBox["...",
                "TI"]}]], " ", 
          StyleBox["tensor",
            FontSlant->"Italic"]}], TraditionalForm]]]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[88]:=",
  CellFrame->{{0, 0}, {0, 0.5}}],

Cell[TextData[{
  "We define a rank 2 general tensor ",
  StyleBox["R",
    FontFamily->"Courier New"],
  " function of two parameters ",
  StyleBox["u",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["v",
    FontFamily->"Courier New"],
  " :"
}], "Text"],

Cell[BoxData[{
    \(\(r =. ;\)\), "\[IndentingNewLine]", 
    \(\(R = 
        DefineGeneralTensor[r, {1, 1}, CanonicalBasis, {t, u}];\)\)}], "Input",\

  CellLabel->"In[89]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\  // \ Components\)], "Input",
  CellLabel->"In[91]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[91]:="],

Cell[BoxData[
    \({{r11[t, u], r12[t, u], r13[t, u]}, {r21[t, u], r22[t, u], 
        r23[t, u]}, {r31[t, u], r32[t, u], r33[t, u]}}\)], "Output",
  CellLabel->"Out[91]="]
}, Open  ]],

Cell[BoxData[
    \(\(R\_u = D[R, u];\)\)], "Input",
  CellLabel->"In[93]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rank[R\_u]\)], "Input",
  CellLabel->"In[98]:="],

Cell[BoxData[
    \(2\)], "Output",
  CellLabel->"Out[98]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(R\_u // Components\)], "Input",
  CellLabel->"In[94]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[94]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["r11", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r12", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r13", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}]}], "}"}], ",", 
        
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["r21", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r22", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r23", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}]}], "}"}], ",", 
        
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["r31", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r32", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r33", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}]}], "}"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[94]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[PartialD]\_u\ R // Components\)], "Input",
  CellLabel->"In[95]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[95]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["r11", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r12", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r13", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}]}], "}"}], ",", 
        
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["r21", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r22", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r23", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}]}], "}"}], ",", 
        
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              SuperscriptBox["r31", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r32", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}], ",", 
            RowBox[{
              SuperscriptBox["r33", 
                TagBox[\((0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(t, u\), "]"}]}], "}"}]}], 
      "}"}]], "Output",
  CellLabel->"Out[95]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // CompactDerivativeForm\)], "Input",
  CellLabel->"In[96]:="],

Cell[BoxData[
    \({{\[PartialD]\_u r11, \[PartialD]\_u r12, \[PartialD]\_u 
          r13}, {\[PartialD]\_u r21, \[PartialD]\_u r22, \[PartialD]\_u 
          r23}, {\[PartialD]\_u r31, \[PartialD]\_u r32, \[PartialD]\_u 
          r33}}\)], "Output",
  CellLabel->"Out[96]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\[PartialD]\_\(u, t, t\)\ R // Components\) // 
      CompactDerivativeForm\)], "Input",
  CellLabel->"In[97]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[97]:="],

Cell[BoxData[
    \({{\[PartialD]\_\(t\[InvisibleComma]t\[InvisibleComma]u\)r11, \
\[PartialD]\_\(t\[InvisibleComma]t\[InvisibleComma]u\)r12, \[PartialD]\_\(t\
\[InvisibleComma]t\[InvisibleComma]u\)r13}, \
{\[PartialD]\_\(t\[InvisibleComma]t\[InvisibleComma]u\)r21, \[PartialD]\_\(t\
\[InvisibleComma]t\[InvisibleComma]u\)r22, \[PartialD]\_\(t\[InvisibleComma]t\
\[InvisibleComma]u\)r23}, \
{\[PartialD]\_\(t\[InvisibleComma]t\[InvisibleComma]u\)r31, \[PartialD]\_\(t\
\[InvisibleComma]t\[InvisibleComma]u\)r32, \[PartialD]\_\(t\[InvisibleComma]t\
\[InvisibleComma]u\)r33}}\)], "Output",
  CellLabel->"Out[97]=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{660, 740},
WindowMargins->{{Automatic, 102}, {Automatic, 78}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "S0.1218"->{
    Cell[1921, 60, 2033, 77, 89, "Usage",
      CellTags->{"S0.1218", "D"}]},
  "D"->{
    Cell[1921, 60, 2033, 77, 89, "Usage",
      CellTags->{"S0.1218", "D"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"S0.1218", 14809, 509},
  {"D", 14896, 512}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 142, 5, 49, "Subsection"],
Cell[1921, 60, 2033, 77, 89, "Usage",
  CellTags->{"S0.1218", "D"}],
Cell[3957, 139, 310, 11, 29, "Text"],
Cell[4270, 152, 524, 19, 29, "Text"],
Cell[4797, 173, 240, 9, 29, "Text"],
Cell[5040, 184, 527, 19, 29, "Text"],
Cell[5570, 205, 1113, 38, 29, "Text"],
Cell[6686, 245, 116, 3, 44, "Input"],
Cell[6805, 250, 263, 11, 29, "Text"],
Cell[7071, 263, 178, 5, 54, "Input"],

Cell[CellGroupData[{
Cell[7274, 272, 77, 2, 33, "Input"],
Cell[7354, 276, 221, 5, 27, "Print"],
Cell[7578, 283, 173, 3, 74, "Output"]
}, Open  ]],
Cell[7766, 289, 77, 2, 33, "Input"],

Cell[CellGroupData[{
Cell[7868, 295, 68, 2, 33, "Input"],
Cell[7939, 299, 60, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8036, 306, 76, 2, 33, "Input"],
Cell[8115, 310, 221, 5, 27, "Print"],
Cell[8339, 317, 2006, 57, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10382, 379, 89, 2, 33, "Input"],
Cell[10474, 383, 221, 5, 27, "Print"],
Cell[10698, 390, 2006, 57, 74, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12741, 452, 84, 2, 33, "Input"],
Cell[12828, 456, 278, 5, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13143, 466, 135, 3, 33, "Input"],
Cell[13281, 471, 221, 5, 27, "Print"],
Cell[13505, 478, 645, 11, 64, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

