(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      9222,        353]*)
(*NotebookOutlinePosition[     10014,        382]*)
(*  CellTagsIndexPosition[      9944,        376]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Eigensystem\nEigenvalues \nEigentensors",
  FontFamily->"Courier New"]], "Subsection"],

Cell[TextData[{
  StyleBox["Eigensystem[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " returns a list of two lists. The first one is the list of the eigenvalues \
and the second one is the list of the eigenvtensors. The rank of ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  " must be even.\n\n",
  StyleBox["Eigenvalues[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " returns the list of the eigenvalues. The rank of ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  " must be even.\n\n",
  StyleBox["Eigentensors[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " returns the list of the eigentensors. The rank of ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  " must be even.\n"
}], "DefinitionBox"],

Cell[TextData[{
  "If ",
  StyleBox["Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]=2",
    FontFamily->"Courier New"],
  " then the eigentensors are vectors and there exists 3 eigenvalues \
(eventually non distinct)."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "If ",
  StyleBox["Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]= 2",
    FontFamily->"Courier New"],
  StyleBox["p",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " then the eigentensors are rank ",
  StyleBox["p",
    FontSlant->"Italic"],
  " tensors and there exists ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["3", 
          StyleBox["p",
            FontSlant->"Italic"]], TraditionalForm]]],
  " eigenvalues (eventually non distinct)."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[1]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.3"],

Cell["Definition of a non symmetric rank 2 tensor :", "Text"],

Cell["\<\
T=DefineTensor[
{{(b + c)/2, (-a + c)/2, (-a + b)/2}, 
 {(-b + c)/2, (a + c)/2, (a - b)/2}, 
 {(b - c)/2, (a - c)/2, (a + b)/2}},{1,-1},CanonicalBasis];\
\>", "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(T // Components\) // MatrixForm\)], "Input",
  CellLabel->"In[3]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[3]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(b + c\)\/2\), \(1\/2\ \((\(-a\) + 
                    c)\)\), \(1\/2\ \((\(-a\) + b)\)\)},
            {\(1\/2\ \((\(-b\) + c)\)\), \(\(a + c\)\/2\), \(\(a - b\)\/2\)},
            {\(\(b - c\)\/2\), \(\(a - c\)\/2\), \(\(a + b\)\/2\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[3]//MatrixForm="]
}, Open  ]],

Cell[BoxData[
    \(\({vals, vecs} = Eigensystem[T];\)\)], "Input",
  CellLabel->"In[4]:="],

Cell[TextData[{
  "Eigenvalues of ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " are :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(vals\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    \({a, b, c}\)], "Output",
  CellLabel->"Out[5]="]
}, Open  ]],

Cell[TextData[{
  "Eigenvectors of ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " are three vectors:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \({Rank[vecs[\([1]\)]\ ], Rank[vecs[\([2]\)]\ ], 
      Rank[vecs[\([3]\)]\ ]}\)], "Input",
  CellLabel->"In[6]:="],

Cell[BoxData[
    \({1, 1, 1}\)], "Output",
  CellLabel->"Out[6]="]
}, Open  ]],

Cell["We can define a basis with the eigenvectors :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(B = DefineBasis[Apply[Sequence, vecs]]\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \("Indirect basis."\)], "Print",
  CellLabel->"From In[7]:="],

Cell[BoxData[
    \(Tens3D`Private`Basis$29\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
  "Basis ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " is not orthonormal :"
}], "Text"],

Cell[BoxData[
    \(\(\(\ \)\({e\_1, e\_2, e\_3} = BasisVectors[B];\)\)\)], "Input",
  CellLabel->"In[8]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \({e\_1 . e\_1, e\_2 . e\_2, e\_3 . e\_3, e\_1 . e\_2, e\_1 . e\_3, 
      e\_2 . e\_3}\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    \({3, 3, 3, \(-1\), 1, 1}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  "The components contravariant-covariant of ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " on basis ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " are :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {1, \(-1\)}, B] // MatrixForm\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"a", "0", "0"},
            {"0", "b", "0"},
            {"0", "0", "c"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[10]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The components covariant-covariant of ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " on the non orthonormal basis ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " are :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {\(-1\), \(-1\)}, B] // MatrixForm\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(3\ a\), \(-b\), "c"},
            {\(-a\), \(3\ b\), "c"},
            {"a", "b", \(3\ c\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[11]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "The components contravariant-contravariant of ",
  StyleBox["T",
    FontFamily->"Courier New"],
  " on basis ",
  StyleBox["B",
    FontFamily->"Courier New"],
  " are :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {1, 1}, B] // MatrixForm\)], "Input",
  CellLabel->"In[12]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(a\/2\), \(a\/4\), \(-\(a\/4\)\)},
            {\(b\/4\), \(b\/2\), \(-\(b\/4\)\)},
            {\(-\(c\/4\)\), \(-\(c\/4\)\), \(c\/2\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[12]//MatrixForm=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{687, 740},
WindowMargins->{{Automatic, 237}, {Automatic, 90}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.3"->{
    Cell[3953, 132, 136, 4, 44, "Input",
      CellTags->"b:0.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.3", 9851, 369}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 110, 1, 97, "Subsection"],
Cell[1889, 56, 1075, 35, 164, "DefinitionBox"],
Cell[2967, 93, 353, 12, 48, "Text"],
Cell[3323, 107, 627, 23, 48, "Text"],
Cell[3953, 132, 136, 4, 44, "Input",
  CellTags->"b:0.3"],
Cell[4092, 138, 61, 0, 29, "Text"],
Cell[4156, 140, 201, 6, 105, "Input"],

Cell[CellGroupData[{
Cell[4382, 150, 90, 2, 33, "Input"],
Cell[4475, 154, 220, 5, 27, "Print"],
Cell[4698, 161, 561, 13, 111, "Output"]
}, Open  ]],
Cell[5274, 177, 91, 2, 33, "Input"],
Cell[5368, 181, 107, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[5500, 190, 61, 2, 33, "Input"],
Cell[5564, 194, 67, 2, 32, "Output"]
}, Open  ]],
Cell[5646, 199, 121, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[5792, 208, 133, 3, 33, "Input"],
Cell[5928, 213, 67, 2, 32, "Output"]
}, Open  ]],
Cell[6010, 218, 61, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[6096, 222, 95, 2, 33, "Input"],
Cell[6194, 226, 79, 2, 27, "Print"],
Cell[6276, 230, 81, 2, 32, "Output"]
}, Open  ]],
Cell[6372, 235, 113, 5, 29, "Text"],
Cell[6488, 242, 108, 2, 33, "Input"],

Cell[CellGroupData[{
Cell[6621, 248, 142, 3, 33, "Input"],
Cell[6766, 253, 81, 2, 32, "Output"]
}, Open  ]],
Cell[6862, 258, 198, 8, 29, "Text"],

Cell[CellGroupData[{
Cell[7085, 270, 101, 2, 33, "Input"],
Cell[7189, 274, 394, 12, 81, "Output"]
}, Open  ]],
Cell[7598, 289, 214, 8, 29, "Text"],

Cell[CellGroupData[{
Cell[7837, 301, 106, 2, 33, "Input"],
Cell[7946, 305, 415, 12, 81, "Output"]
}, Open  ]],
Cell[8376, 320, 202, 8, 29, "Text"],

Cell[CellGroupData[{
Cell[8603, 332, 96, 2, 33, "Input"],
Cell[8702, 336, 492, 13, 118, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

