(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     10930,        421]*)
(*NotebookOutlinePosition[     11722,        450]*)
(*  CellTagsIndexPosition[     11651,        444]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Invariants of rank 2 tensors", "Subsection"],

Cell[TextData[{
  StyleBox["FirstInvariant[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  "or ",
  StyleBox["I1[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " or",
  StyleBox[" J1[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  or ",
  StyleBox[ButtonBox["AutoContract",
    ButtonData:>{"AutoContract", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  StyleBox["[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " returns the trace of the rank 2 Tens3D tensor.\n\n",
  StyleBox["SecondInvariant[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  "or ",
  StyleBox["I2[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  returns the second invariant of the rank 2 Tens3D tensor.\n\n",
  StyleBox["J2[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  returns the trace of  ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  StyleBox[".",
    FontFamily->"Courier New"],
  StyleBox["tensor ",
    FontSlant->"Italic"],
  "(",
  StyleBox[ButtonBox["AutoContract",
    ButtonData:>{"AutoContract", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  StyleBox["[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[".",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["1,2]",
    FontFamily->"Courier New"],
  ")",
  StyleBox[".\n\n",
    FontSlant->"Italic"],
  StyleBox["ThirdInvariant[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["] ",
    FontFamily->"Courier New"],
  "or ",
  StyleBox["I3[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " or",
  StyleBox[" Det[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "   returns the determinant of the rank 2 Tens3D tensor.\n\n",
  StyleBox["J3[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  returns the trace of  ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  StyleBox[".",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontSlant->"Italic"],
  StyleBox[".",
    FontFamily->"Courier New"],
  StyleBox["tensor ",
    FontSlant->"Italic"],
  "(",
  StyleBox[ButtonBox["AutoContract",
    ButtonData:>{"AutoContract", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  StyleBox["[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[".",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontSlant->"Italic"],
  StyleBox[".",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["1,2]",
    FontFamily->"Courier New"],
  ")",
  StyleBox[".",
    FontSlant->"Italic"]
}], "DefinitionBox"],

Cell[TextData[{
  "These functions acts only on rank 2 tensors except the more general \
functions ",
  StyleBox[ButtonBox["Tr",
    ButtonData:>{"Trace.nb", None},
    ButtonStyle->"Hyperlink"],
    FontFamily->"Courier New"],
  " and ",
  StyleBox[ButtonBox["Det",
    ButtonData:>{"Det", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  StyleBox["SecondInvariant",
    FontFamily->"Courier New"],
  StyleBox[" or  ",
    FontFamily->"Times New Roman"],
  StyleBox["I2 ",
    FontFamily->"Courier New"],
  StyleBox["is the sum of the three diagonal 2\[Times]2 determinants of the \
contravariant-covariant components in a basis.",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[16]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.3"],

Cell["We define a non orthonormal basis B", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(v1 = 
        DefineTensor[{0, 1, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v2 = 
        DefineTensor[{1, 0, 1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v3 = 
        DefineTensor[{1, 1, 0}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(B = DefineBasis[v1, v2, v3];\)\)}], "Input",
  CellLabel->"In[17]:="],

Cell[BoxData[
    \("Direct basis."\)], "Print",
  CellLabel->"From In[17]:="]
}, Open  ]],

Cell[BoxData[{
    \(\(T =. ;\)\), "\[IndentingNewLine]", 
    \(\(T = DefineGeneralTensor[T, {1, \(-1\)}, B];\)\)}], "Input",
  CellLabel->"In[21]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \({FirstInvariant[T], I1[T], J1[T], AutoContract[T]} // 
      TableForm\)], "Input",
  CellLabel->"In[23]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(T11 + T22 + T33\)},
          {\(T11 + T22 + T33\)},
          {\(T11 + T22 + T33\)},
          {\(T11 + T22 + T33\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Plus[ T11, T22, T33], 
        Plus[ T11, T22, T33], 
        Plus[ T11, T22, T33], 
        Plus[ T11, T22, T33]}]]], "Output",
  CellLabel->"Out[23]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({SecondInvariant[T], I2[T]} // TableForm\)], "Input",
  CellLabel->"In[24]:="],

Cell[BoxData[
    InterpretationBox[GridBox[{
          {\(\(-T12\)\ T21 + T11\ T22 - T13\ T31 - T23\ T32 + T11\ T33 + 
              T22\ T33\)},
          {\(\(-T12\)\ T21 + T11\ T22 - T13\ T31 - T23\ T32 + T11\ T33 + 
              T22\ T33\)}
          },
        RowSpacings->1,
        ColumnSpacings->3,
        RowAlignments->Baseline,
        ColumnAlignments->{Left}],
      TableForm[ {
        Plus[ 
          Times[ -1, T12, T21], 
          Times[ T11, T22], 
          Times[ -1, T13, T31], 
          Times[ -1, T23, T32], 
          Times[ T11, T33], 
          Times[ T22, T33]], 
        Plus[ 
          Times[ -1, T12, T21], 
          Times[ T11, T22], 
          Times[ -1, T13, T31], 
          Times[ -1, T23, T32], 
          Times[ T11, T33], 
          Times[ T22, T33]]}]]], "Output",
  CellLabel->"Out[24]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ThirdInvariant[T]\  \[Equal] \ \ I3[T] \[Equal] \ \ Det[T]\)], "Input",
  CellLabel->"In[25]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[25]="]
}, Open  ]],

Cell[TextData[{
  "We can verify some classical relations between the two systems of \
invariants ",
  StyleBox["{I1,I2,I3}",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["{J1,J2,J3}",
    FontFamily->"Courier New"],
  " :"
}], "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(J1[T]\  \[Equal] \ I1[T]\)], "Input",
  CellLabel->"In[26]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[26]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(J2[T]\  \[Equal] \ \ \ I1[T]^2\  - \ 2\ I2[T]\  // Simplify\)], "Input",\

  CellLabel->"In[27]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(J3[T]\  \[Equal] \ 3\ I3[T] - 3\ I1[T]\ I2[T]\  + \ I1[T]^3\  // 
      Simplify\)], "Input",
  CellLabel->"In[28]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[28]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(I2[T] \[Equal] \ \((J1[T]^2\  - \ J2[T])\)/2\  // \ Simplify\)], "Input",\

  CellLabel->"In[29]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(I3[T]\  \[Equal] \ \((J3[T] - 3/2\ J1[T]\ J2[T] + \ 1/2\ J1[T]^3)\)/3 // 
      Simplify\)], "Input",
  CellLabel->"In[30]:="],

Cell[BoxData[
    \(True\)], "Output",
  CellLabel->"Out[30]=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{665, 740},
WindowMargins->{{Automatic, 82}, {69, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.3"->{
    Cell[6726, 243, 137, 4, 44, "Input",
      CellTags->"b:0.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.3", 11558, 437}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 50, 0, 48, "Subsection"],
Cell[1829, 55, 4084, 157, 278, "DefinitionBox"],
Cell[5916, 214, 413, 14, 29, "Text"],
Cell[6332, 230, 391, 11, 48, "Text"],
Cell[6726, 243, 137, 4, 44, "Input",
  CellTags->"b:0.3"],
Cell[6866, 249, 51, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[6942, 253, 416, 11, 96, "Input"],
Cell[7361, 266, 78, 2, 27, "Print"]
}, Open  ]],
Cell[7454, 271, 151, 3, 54, "Input"],

Cell[CellGroupData[{
Cell[7630, 278, 128, 3, 54, "Input"],
Cell[7761, 283, 500, 16, 99, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8298, 304, 98, 2, 33, "Input"],
Cell[8399, 308, 850, 26, 63, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9286, 339, 116, 2, 33, "Input"],
Cell[9405, 343, 63, 2, 32, "Output"]
}, Open  ]],
Cell[9483, 348, 278, 10, 48, "Text"],

Cell[CellGroupData[{
Cell[9786, 362, 82, 2, 33, "Input"],
Cell[9871, 366, 63, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9971, 373, 119, 3, 33, "Input"],
Cell[10093, 378, 63, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10193, 385, 138, 3, 33, "Input"],
Cell[10334, 390, 63, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10434, 397, 120, 3, 33, "Input"],
Cell[10557, 402, 63, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10657, 409, 146, 3, 33, "Input"],
Cell[10806, 414, 96, 3, 43, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

