(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     18337,        579]*)
(*NotebookOutlinePosition[     19130,        608]*)
(*  CellTagsIndexPosition[     19059,        602]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Laplacian",
  FontFamily->"Courier New"]], "Subsection"],

Cell[TextData[{
  StyleBox["Laplacian[",
    FontFamily->"Courier New"],
  StyleBox["tensorfield",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["coordinatesystem",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " returns the tensorial field laplacian of the given tensorial field ",
  StyleBox["tensorfield",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[".\n\n",
    FontSlant->"Italic"],
  StyleBox["tensorfield",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is a rank \[GreaterEqual]0 Tens3D tensorial field prevoiusly defined with \
",
  StyleBox[ButtonBox["DefineTensor",
    ButtonData:>{"DefineTensor", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["DefineGeneralTensor",
    ButtonData:>{"DefineGeneralTensor", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  " or any algebraic function returning a Tens3D tensor or any scalar field.\n\
\n",
  StyleBox["coordinatesystem",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is a Tens3D coordinates system prevoiusly defined with ",
  StyleBox[ButtonBox["DefineCoordinateSystem",
    ButtonData:>{"DefineCoordinateSystem", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "."
}], "DefinitionBox"],

Cell[TextData[{
  StyleBox["Laplacian[",
    FontFamily->"Courier New"],
  StyleBox["tensorfield",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["coordinatesystem",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier New"],
  StyleBox["is defined by :  \n",
    FontFamily->"Times New Roman"],
  StyleBox["Divergence[Gradient[",
    FontFamily->"Courier New"],
  StyleBox["tensorfield",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["coordinatesystem",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier New"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  StyleBox["Rank[",
    FontFamily->"Courier New"],
  StyleBox["Divergence",
    FontFamily->"Courier New"],
  StyleBox["[",
    FontFamily->"Courier New"],
  StyleBox["tensorfield",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New",
    FontSlant->"Italic"],
  StyleBox["coordinatesystem",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]]",
    FontFamily->"Courier New"],
  "= ",
  StyleBox["Rank[",
    FontFamily->"Courier New"],
  StyleBox["tensorfield",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[39]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.7"],

Cell[TextData[{
  "We define the classical cylindrical coordinates system :\na point M is \
function of coordinates ",
  StyleBox["{r,\[Theta],z}",
    FontFamily->"Courier New"],
  " :"
}], "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(r =. ; \[Theta] =. ; z =. ;\ \), "\[IndentingNewLine]", 
    \(\($Assumptions = $Assumptions\  && \ 
          r > 0;\)\), "\[IndentingNewLine]", 
    \(\(coords = {r, \[Theta], z};\)\), "\[IndentingNewLine]", 
    \(\(OM = 
        DefineTensor[{r\ Cos[\[Theta]], r\ Sin[\[Theta]], z}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(cyl = DefineCoordinateSystem[OM, coords];\)\)}], "Input",
  CellLabel->"In[40]:="],

Cell[BoxData[
    \("Direct orthogonal natural basis."\)], "Print",
  CellLabel->"From In[40]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(cylnorm = NormalizedBasis[cyl];\)\)], "Input",
  CellLabel->"In[45]:="],

Cell[BoxData[
    \("Direct normalized orthogonal basis."\)], "Print",
  CellLabel->"From In[45]:="]
}, Open  ]],

Cell[TextData[{
  StyleBox["f[r,\[Theta],z] ",
    FontFamily->"Courier New"],
  "is a general scalar field. The laplacian is a scalar field :"
}], "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Lf = Laplacian[f[r, \[Theta], z], cyl]\)], "Input",
  CellLabel->"In[46]:="],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["f", 
          TagBox[\((0, 0, 2)\),
            Derivative],
          MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], "+", 
      FractionBox[
        RowBox[{
          RowBox[{
            SuperscriptBox["f", 
              TagBox[\((0, 2, 0)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], "+", 
          RowBox[{"r", " ", 
            RowBox[{
              SuperscriptBox["f", 
                TagBox[\((1, 0, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(r, \[Theta], z\), 
              "]"}]}]}], \(r\^2\)], "+", 
      RowBox[{
        SuperscriptBox["f", 
          TagBox[\((2, 0, 0)\),
            Derivative],
          MultilineFunction->None], "[", \(r, \[Theta], z\), 
        "]"}]}]], "Output",
  CellLabel->"Out[46]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% // CompactDerivativeForm\)], "Input",
  CellLabel->"In[47]:="],

Cell[BoxData[
    \(\[PartialD]\_\(z\[InvisibleComma]z\)f + \(\[PartialD]\_\(\[Theta]\
\[InvisibleComma]\[Theta]\)f + r\ \[PartialD]\_r f\)\/r\^2 + \[PartialD]\_\(r\
\[InvisibleComma]r\)f\)], "Output",
  CellLabel->"Out[47]="]
}, Open  ]],

Cell["\<\
We define a general vectorial field by its components on the normalized basis \
:\
\>", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[BoxData[{
    \(\(v =. ;\)\), "\[IndentingNewLine]", 
    \(\(V = DefineGeneralTensor[v, {1}, cylnorm, coords];\)\)}], "Input",
  CellLabel->"In[48]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[V, {1}, cylnorm]\)], "Input",
  CellLabel->"In[50]:="],

Cell[BoxData[
    \({v1[r, \[Theta], z], v2[r, \[Theta], z], 
      v3[r, \[Theta], z]}\)], "Output",
  CellLabel->"Out[50]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[V, {1}, cyl]\)], "Input",
  CellLabel->"In[51]:="],

Cell[BoxData[
    \({v1[r, \[Theta], z], v2[r, \[Theta], z]\/r, 
      v3[r, \[Theta], z]}\)], "Output",
  CellLabel->"Out[51]="]
}, Open  ]],

Cell[BoxData[
    \(\(LV = Laplacian[V, cyl];\)\)], "Input",
  CellLabel->"In[52]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Rank[LV]\)], "Input",
  CellLabel->"In[53]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[53]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[LV, {1}, cyl]\)], "Input",
  CellLabel->"In[54]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["v1", 
              TagBox[\((0, 0, 2)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], "+", 
          RowBox[{\(1\/r\^2\), 
            RowBox[{"(", 
              RowBox[{\(-v1[r, \[Theta], z]\), "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["v2", 
                      TagBox[\((0, 1, 0)\),
                        Derivative],
                      MultilineFunction->None], "[", \(r, \[Theta], z\), 
                    "]"}]}], "+", 
                RowBox[{
                  SuperscriptBox["v1", 
                    TagBox[\((0, 2, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], 
                "+", 
                RowBox[{"r", " ", 
                  RowBox[{
                    SuperscriptBox["v1", 
                      TagBox[\((1, 0, 0)\),
                        Derivative],
                      MultilineFunction->None], "[", \(r, \[Theta], z\), 
                    "]"}]}]}], ")"}]}], "+", 
          RowBox[{
            SuperscriptBox["v1", 
              TagBox[\((2, 0, 0)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}]}], ",",
         
        RowBox[{\(1\/r\^3\), 
          RowBox[{"(", 
            RowBox[{\(-v2[r, \[Theta], z]\), "+", 
              RowBox[{\(r\^2\), " ", 
                RowBox[{
                  SuperscriptBox["v2", 
                    TagBox[\((0, 0, 2)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}], "+", 
              RowBox[{"2", " ", 
                RowBox[{
                  SuperscriptBox["v1", 
                    TagBox[\((0, 1, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}], "+", 
              RowBox[{
                SuperscriptBox["v2", 
                  TagBox[\((0, 2, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], 
              "+", 
              RowBox[{"r", " ", 
                RowBox[{
                  SuperscriptBox["v2", 
                    TagBox[\((1, 0, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}], "+", 
              RowBox[{\(r\^2\), " ", 
                RowBox[{
                  SuperscriptBox["v2", 
                    TagBox[\((2, 0, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}]}], ")"}]}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["v3", 
              TagBox[\((0, 0, 2)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], "+", 
          FractionBox[
            RowBox[{
              RowBox[{
                SuperscriptBox["v3", 
                  TagBox[\((0, 2, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], 
              "+", 
              RowBox[{"r", " ", 
                RowBox[{
                  SuperscriptBox["v3", 
                    TagBox[\((1, 0, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}]}], \(r\^2\)], "+", 
          RowBox[{
            SuperscriptBox["v3", 
              TagBox[\((2, 0, 0)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}]}]}], 
      "}"}]], "Output",
  CellLabel->"Out[54]="]
}, Open  ]],

Cell["\<\
Classical formulars give components on the normalized basis :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[LV, {1}, cylnorm]\)], "Input",
  CellLabel->"In[55]:="],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{
          RowBox[{
            SuperscriptBox["v1", 
              TagBox[\((0, 0, 2)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], "+", 
          RowBox[{\(1\/r\^2\), 
            RowBox[{"(", 
              RowBox[{\(-v1[r, \[Theta], z]\), "-", 
                RowBox[{"2", " ", 
                  RowBox[{
                    SuperscriptBox["v2", 
                      TagBox[\((0, 1, 0)\),
                        Derivative],
                      MultilineFunction->None], "[", \(r, \[Theta], z\), 
                    "]"}]}], "+", 
                RowBox[{
                  SuperscriptBox["v1", 
                    TagBox[\((0, 2, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], 
                "+", 
                RowBox[{"r", " ", 
                  RowBox[{
                    SuperscriptBox["v1", 
                      TagBox[\((1, 0, 0)\),
                        Derivative],
                      MultilineFunction->None], "[", \(r, \[Theta], z\), 
                    "]"}]}]}], ")"}]}], "+", 
          RowBox[{
            SuperscriptBox["v1", 
              TagBox[\((2, 0, 0)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}]}], ",",
         
        RowBox[{\(1\/r\^2\), 
          RowBox[{"(", 
            RowBox[{\(-v2[r, \[Theta], z]\), "+", 
              RowBox[{\(r\^2\), " ", 
                RowBox[{
                  SuperscriptBox["v2", 
                    TagBox[\((0, 0, 2)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}], "+", 
              RowBox[{"2", " ", 
                RowBox[{
                  SuperscriptBox["v1", 
                    TagBox[\((0, 1, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}], "+", 
              RowBox[{
                SuperscriptBox["v2", 
                  TagBox[\((0, 2, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], 
              "+", 
              RowBox[{"r", " ", 
                RowBox[{
                  SuperscriptBox["v2", 
                    TagBox[\((1, 0, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}], "+", 
              RowBox[{\(r\^2\), " ", 
                RowBox[{
                  SuperscriptBox["v2", 
                    TagBox[\((2, 0, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}]}], ")"}]}], ",", 
        RowBox[{
          RowBox[{
            SuperscriptBox["v3", 
              TagBox[\((0, 0, 2)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], "+", 
          FractionBox[
            RowBox[{
              RowBox[{
                SuperscriptBox["v3", 
                  TagBox[\((0, 2, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}], 
              "+", 
              RowBox[{"r", " ", 
                RowBox[{
                  SuperscriptBox["v3", 
                    TagBox[\((1, 0, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \(r, \[Theta], z\), 
                  "]"}]}]}], \(r\^2\)], "+", 
          RowBox[{
            SuperscriptBox["v3", 
              TagBox[\((2, 0, 0)\),
                Derivative],
              MultilineFunction->None], "[", \(r, \[Theta], z\), "]"}]}]}], 
      "}"}]], "Output",
  CellLabel->"Out[55]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(% // CompactDerivativeForm\) // MatrixForm\)], "Input",
  CellLabel->"In[56]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(\[PartialD]\_\(z\[InvisibleComma]z\)v1 + \(\(-v1[r, \
\[Theta], z]\) - 2\ \[PartialD]\_\[Theta] v2 + \[PartialD]\_\(\[Theta]\
\[InvisibleComma]\[Theta]\)v1 + r\ \[PartialD]\_r v1\)\/r\^2 + \
\[PartialD]\_\(r\[InvisibleComma]r\)v1\)},
              {\(\(\(-v2[r, \[Theta], z]\) + 
                      r\^2\ \[PartialD]\_\(z\[InvisibleComma]z\)v2 + 
                      2\ \[PartialD]\_\[Theta] 
                          v1 + \[PartialD]\_\(\[Theta]\[InvisibleComma]\
\[Theta]\)v2 + r\ \[PartialD]\_r v2 + 
                      r\^2\ \[PartialD]\_\(r\[InvisibleComma]r\)v2\)\/r\^2\)},\

              {\(\[PartialD]\_\(z\[InvisibleComma]z\)v3 + \(\[PartialD]\_\(\
\[Theta]\[InvisibleComma]\[Theta]\)v3 + r\ \[PartialD]\_r v3\)\/r\^2 + \
\[PartialD]\_\(r\[InvisibleComma]r\)v3\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[56]//MatrixForm=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{610, 740},
WindowMargins->{{Automatic, 170}, {Automatic, 69}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.7"->{
    Cell[4999, 168, 137, 4, 44, "Input",
      CellTags->"b:0.7"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.7", 18966, 595}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 80, 1, 47, "Subsection"],
Cell[1859, 56, 1562, 49, 203, "DefinitionBox"],
Cell[3424, 107, 856, 30, 58, "Text"],
Cell[4283, 139, 713, 27, 30, "Text"],
Cell[4999, 168, 137, 4, 44, "Input",
  CellTags->"b:0.7"],
Cell[5139, 174, 232, 7, 56, "Text"],

Cell[CellGroupData[{
Cell[5396, 185, 460, 9, 138, "Input"],
Cell[5859, 196, 97, 2, 27, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5993, 203, 93, 2, 33, "Input"],
Cell[6089, 207, 100, 2, 27, "Print"]
}, Open  ]],
Cell[6204, 212, 189, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[6418, 221, 96, 2, 33, "Input"],
Cell[6517, 225, 912, 27, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7466, 257, 84, 2, 33, "Input"],
Cell[7553, 261, 226, 4, 46, "Output"]
}, Open  ]],
Cell[7794, 268, 139, 4, 29, "Text"],
Cell[7936, 274, 157, 3, 54, "Input"],

Cell[CellGroupData[{
Cell[8118, 281, 85, 2, 33, "Input"],
Cell[8206, 285, 126, 3, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8369, 293, 81, 2, 33, "Input"],
Cell[8453, 297, 129, 3, 46, "Output"]
}, Open  ]],
Cell[8597, 303, 85, 2, 33, "Input"],

Cell[CellGroupData[{
Cell[8707, 309, 66, 2, 33, "Input"],
Cell[8776, 313, 60, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[8873, 320, 82, 2, 33, "Input"],
Cell[8958, 324, 3921, 102, 232, "Output"]
}, Open  ]],
Cell[12894, 429, 85, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[13004, 435, 86, 2, 33, "Input"],
Cell[13093, 439, 3921, 102, 232, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17051, 546, 102, 2, 33, "Input"],
Cell[17156, 550, 1153, 25, 128, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

