(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8457,        308]*)
(*NotebookOutlinePosition[      9249,        337]*)
(*  CellTagsIndexPosition[      9179,        331]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["DefineOrthogonalTensor",
    FontFamily->"Courier New"],
  " \n",
  StyleBox["IdentifyOrthogonalTensor",
    FontFamily->"Courier New"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["DefineOrthogonalTensor[",
    FontFamily->"Courier New"],
  StyleBox["angle",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["axis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["det",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " returns a Tens3D rank 2 orthogonal tensor.\n\t",
  StyleBox["angle",
    FontSlant->"Italic"],
  " is the angle (in radians) of the orthogonal tensor,\n\t",
  StyleBox["axis",
    FontSlant->"Italic"],
  " is the axis (a previous defined Tens3D vector) of the orthogonal tensor,\n\
\t",
  StyleBox["det",
    FontSlant->"Italic"],
  " is the determinant (1 or -1) of the orthogonal tensor.\n\n",
  StyleBox["IdentifyOrthogonalTensor[",
    FontFamily->"Courier New"],
  StyleBox["orth",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  StyleBox[" makes the reverse operation : it retuns a list ",
    FontFamily->"Times New Roman"],
  StyleBox["{",
    FontFamily->"Courier New"],
  StyleBox["angle",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["axis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["det",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["}.",
    FontFamily->"Courier New"]
}], "DefinitionBox"],

Cell[TextData[{
  "In ",
  StyleBox["DefineOrthogonalTensor",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["angle",
    FontSlant->"Italic"],
  " may have any value and ",
  StyleBox["axis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  "is not necessarely normed."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "With ",
  StyleBox["IdentifyOrthogonalTensor",
    FontFamily->"Courier New"],
  ", the returned angle is always in the range",
  StyleBox[" [0,\[Pi]]",
    FontFamily->"Courier New"],
  StyleBox[" and the vector ",
    FontFamily->"Times New Roman"],
  StyleBox["axis",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[" is a unique unit vector.",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[1]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.3"],

Cell[BoxData[{
    \(\($Assumptions = \[Theta] \[Element] 
          Reals\ ;\)\), "\[IndentingNewLine]", 
    \(\(ax = 
        DefineTensor[{1, 2, 3}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(Q = DefineOrthogonalTensor[\[Theta], ax, 1];\)\)}], "Input",
  CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Q // Components\) // MatrixForm\)], "Input",
  CellLabel->"In[5]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[5]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(1\/14\ \((1 + 13\ Cos[\[Theta]])\)\), \(1\/14\ \((2 - 
                    2\ Cos[\[Theta]] - 
                    3\ \@14\ Sin[\[Theta]])\)\), \(1\/14\ \((3 - 
                    3\ Cos[\[Theta]] + 2\ \@14\ Sin[\[Theta]])\)\)},
            {\(1\/14\ \((2 - 2\ Cos[\[Theta]] + 
                    3\ \@14\ Sin[\[Theta]])\)\), \(1\/7\ \((2 + 
                    5\ Cos[\[Theta]])\)\), \(1\/14\ \((6 - 
                    6\ Cos[\[Theta]] - \@14\ Sin[\[Theta]])\)\)},
            {\(1\/14\ \((3 - 3\ Cos[\[Theta]] - 
                    2\ \@14\ Sin[\[Theta]])\)\), \(1\/14\ \((6 - 
                    6\ Cos[\[Theta]] + \@14\ Sin[\[Theta]])\)\), \(1\/14\ \
\((9 + 5\ Cos[\[Theta]])\)\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[5]//MatrixForm="]
}, Open  ]],

Cell["Now we retrieve fow is the orthogonal tensor :", "Text"],

Cell[BoxData[
    \(\({angle, ax1, d} = IdentifyOrthogonalTensor[Q];\)\)], "Input",
  CellLabel->"In[6]:="],

Cell[TextData[{
  "The angle is  in the range",
  StyleBox[" [0,\[Pi]]",
    FontFamily->"Courier New"],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox[":",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(angle\)], "Input",
  CellLabel->"In[7]:="],

Cell[BoxData[
    \(ArcCos[Cos[\[Theta]]]\)], "Output",
  CellLabel->"Out[7]="]
}, Open  ]],

Cell["The axis is a unit vector :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(EuclidianNorm[ax1]\)], "Input",
  CellLabel->"In[8]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[8]="]
}, Open  ]],

Cell["colinear to the previous vector :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(ax1\[Wedge]ax // Components\)], "Input",
  CellLabel->"In[9]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[9]:="],

Cell[BoxData[
    \({0, 0, 0}\)], "Output",
  CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
  StyleBox["ax",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["ax1",
    FontFamily->"Courier New"],
  " are in the same direction if \[Theta] \[Element]",
  StyleBox["[0,\[Pi]],",
    FontFamily->"Courier New"],
  StyleBox["and in the opposite direction if ",
    FontFamily->"Times New Roman"],
  "\[Theta] \[Element]",
  StyleBox["[\[Pi],2 \[Pi]]",
    FontFamily->"Courier New"],
  StyleBox[" :",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Simplify[ax1 . ax > 0]\)], "Input",
  CellLabel->"In[10]:="],

Cell[BoxData[
    \(Sin[\[Theta]] > 0\)], "Output",
  CellLabel->"Out[10]="]
}, Open  ]],

Cell["Q is a rotation because the determinant is 1 :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(d\)], "Input",
  CellLabel->"In[11]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[11]=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{682, 740},
WindowMargins->{{Automatic, 202}, {Automatic, 46}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.3"->{
    Cell[4437, 152, 136, 4, 44, "Input",
      CellTags->"b:0.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.3", 9086, 324}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 181, 6, 74, "Subsection"],
Cell[1960, 61, 1621, 55, 164, "DefinitionBox"],
Cell[3584, 118, 376, 15, 29, "Text"],
Cell[3963, 135, 471, 15, 48, "Text"],
Cell[4437, 152, 136, 4, 44, "Input",
  CellTags->"b:0.3"],
Cell[4576, 158, 307, 7, 75, "Input"],

Cell[CellGroupData[{
Cell[4908, 169, 90, 2, 33, "Input"],
Cell[5001, 173, 220, 5, 27, "Print"],
Cell[5224, 180, 1013, 21, 113, "Output"]
}, Open  ]],
Cell[6252, 204, 62, 0, 29, "Text"],
Cell[6317, 206, 107, 2, 33, "Input"],
Cell[6427, 210, 219, 8, 29, "Text"],

Cell[CellGroupData[{
Cell[6671, 222, 62, 2, 33, "Input"],
Cell[6736, 226, 79, 2, 32, "Output"]
}, Open  ]],
Cell[6830, 231, 43, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[6898, 235, 75, 2, 33, "Input"],
Cell[6976, 239, 59, 2, 32, "Output"]
}, Open  ]],
Cell[7050, 244, 49, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[7124, 248, 84, 2, 33, "Input"],
Cell[7211, 252, 220, 5, 27, "Print"],
Cell[7434, 259, 67, 2, 32, "Output"]
}, Open  ]],
Cell[7516, 264, 472, 16, 29, "Text"],

Cell[CellGroupData[{
Cell[8013, 284, 80, 2, 33, "Input"],
Cell[8096, 288, 76, 2, 32, "Output"]
}, Open  ]],
Cell[8187, 293, 62, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[8274, 297, 59, 2, 33, "Input"],
Cell[8336, 301, 93, 3, 43, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

