(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     12837,        516]*)
(*NotebookOutlinePosition[     13630,        545]*)
(*  CellTagsIndexPosition[     13559,        539]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["RightPolarDecomposition",
    FontFamily->"Courier New"],
  "\n",
  StyleBox["LeftPolarDecomposition",
    FontFamily->"Courier New"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["RightPolarDecomposition[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " where ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  " is a rank 2 Tens3D tensor, ",
  "returns a list of two Tens3D tensors ",
  StyleBox["{",
    FontFamily->"Courier New"],
  StyleBox["orth",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["sdpr",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier New"],
  " : \n\t- ",
  StyleBox["orth",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " is a rank 2 orthogonal tensor,\n\t- ",
  StyleBox["sdpr",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " is a rank 2 symmetric definite positive,\nsuch that  ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  " = ",
  StyleBox["orth",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[".",
    FontFamily->"Courier New"],
  StyleBox["sdpr",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  "\t\n\t\n",
  StyleBox["LeftPolarDecomposition[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " where ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  " is a rank 2 Tens3D tensor, ",
  "returns a list of two Tens3D tensors ",
  StyleBox["{",
    FontFamily->"Courier New"],
  StyleBox["sdpl",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["orth",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["}",
    FontFamily->"Courier New"],
  " : \n\t- ",
  StyleBox["sdpl",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " is a rank 2 symmetric definite positive,\n\t- ",
  StyleBox["orth",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " is a rank 2 orthogonal tensor,\nsuch that  ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  " = ",
  StyleBox["sdpl",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[".",
    FontFamily->"Courier New"],
  StyleBox["orth",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  "\t"
}], "DefinitionBox"],

Cell[TextData[{
  "The orthogonal tensors ",
  StyleBox["orth",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " are the same for the two functions, but ",
  StyleBox["sdpr",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " and ",
  StyleBox["sdpl",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " are different."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "If ",
  StyleBox["Det[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]>0",
    FontFamily->"Courier New"],
  ", then ",
  StyleBox["orth",
    FontSlant->"Italic"],
  " is a rotation (",
  StyleBox["Det[orth]=+1",
    FontFamily->"Courier New"],
  "), else it is a mirroring (",
  StyleBox["Det[orth]=+1",
    FontFamily->"Courier New"],
  ")"
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  "See also ",
  ": ",
  StyleBox[ButtonBox["DefineOrthogonalTensor",
    ButtonData:>{"Orthogonal", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["IdentifyOrthogonalTensor",
    ButtonData:>{"Orthogonal", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"]
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[66]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.3"],

Cell["We define a non symmetric rank 2 tensor :", "Text"],

Cell["\<\
T=DefineTensor[
{{3/(2*Sqrt[2]),-1/(2*Sqrt[2]),3/Sqrt[2]},
{-1/2, 3/2, 0},
{-3/(2*Sqrt[2]), 1/(2*Sqrt[2]),3/Sqrt[2]}},
{-1,1},CanonicalBasis];\
\>", "Input",
  CellLabel->"In[67]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(T // Components\) // MatrixForm\)], "Input",
  CellLabel->"In[68]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[68]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(3\/\(2\ \@2\)\), \(-\(1\/\(2\ \@2\)\)\), \(3\/\@2\)},
            {\(-\(1\/2\)\), \(3\/2\), "0"},
            {\(-\(3\/\(2\ \@2\)\)\), \(1\/\(2\ \@2\)\), \(3\/\@2\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[68]//MatrixForm="]
}, Open  ]],

Cell[BoxData[
    \(\({orth1, sdp1} = RightPolarDecomposition[T];\)\)], "Input",
  CellLabel->"In[69]:="],

Cell[TextData[{
  "The tensor ",
  StyleBox["orth1",
    FontFamily->"Courier New"],
  " is orthogonal :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(orth1 . orth1\[Transpose]  // Components\)], "Input",
  CellLabel->"In[70]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[70]:="],

Cell[BoxData[
    \({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\)], "Output",
  CellLabel->"Out[70]="]
}, Open  ]],

Cell[TextData[{
  "The tensor ",
  StyleBox["orth1",
    FontFamily->"Courier New"],
  " is a rotation :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[orth1]\)], "Input",
  CellLabel->"In[71]:="],

Cell[BoxData[
    \(1\)], "Output",
  CellLabel->"Out[71]="]
}, Open  ]],

Cell[TextData[{
  "The tensor ",
  StyleBox["sdp1",
    FontFamily->"Courier New"],
  " is positive :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[sdp1]\)], "Input",
  CellLabel->"In[72]:="],

Cell[BoxData[
    \(6\)], "Output",
  CellLabel->"Out[72]="]
}, Open  ]],

Cell[TextData[{
  "The tensor ",
  StyleBox["sdp1",
    FontFamily->"Courier New"],
  " is symmetric :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Asym[sdp1] // Components\)], "Input",
  CellLabel->"In[73]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[73]:="],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[73]="]
}, Open  ]],

Cell["We verify the right polar decomposition :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T\ \[CircleMinus]\ orth1 . sdp1\  // \ Components\)], "Input",
  CellLabel->"In[74]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[74]:="],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[74]="]
}, Open  ]],

Cell[BoxData[
    \(\({sdp2, orth2} = LeftPolarDecomposition[T];\)\)], "Input",
  CellLabel->"In[75]:="],

Cell[TextData[{
  "The tensor ",
  StyleBox["sdp2",
    FontFamily->"Courier New"],
  " is positive :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Det[sdp2]\)], "Input",
  CellLabel->"In[76]:="],

Cell[BoxData[
    \(6\)], "Output",
  CellLabel->"Out[76]="]
}, Open  ]],

Cell[TextData[{
  "The tensor ",
  StyleBox["sdp2",
    FontFamily->"Courier New"],
  " is symmetric :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Asym[sdp2] // Components\)], "Input",
  CellLabel->"In[77]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[77]:="],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[77]="]
}, Open  ]],

Cell["We verify the left polar decomposition :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(T\ \[CircleMinus]\ sdp2 . orth2\  // \ Components\)], "Input",
  CellLabel->"In[78]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[78]:="],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[78]="]
}, Open  ]],

Cell[TextData[{
  "tensors ",
  StyleBox["orth1",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["orth2",
    FontFamily->"Courier New"],
  " are identical :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(orth1\ \[CircleMinus]\ orth2\  // Components\)], "Input",
  CellLabel->"In[79]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[79]:="],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[79]="]
}, Open  ]],

Cell[TextData[{
  "but tensors ",
  StyleBox["sdp1",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["sdp2",
    FontFamily->"Courier New"],
  " are not identical :"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sdp1\ \[CircleMinus]\ sdp2\  // Components\)], "Input",
  CellLabel->"In[80]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[80]:="],

Cell[BoxData[
    \({{\(-\(3\/4\)\), 
        1\/4\ \((\(-2\) + \@2)\), \(-\(3\/4\)\)}, {1\/4\ \((\(-2\) + \@2)\), 
        0, \(-\(1\/\(2\ \@2\)\)\)}, {\(-\(3\/4\)\), \(-\(1\/\(2\ \@2\)\)\), 
        3\/4}}\)], "Output",
  CellLabel->"Out[80]="]
}, Open  ]],

Cell[TextData[{
  "We verify the relation : ",
  StyleBox["sdp2 = orth1.sdp1.orth1\[Transpose] ",
    FontFamily->"Courier New"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(sdp2\[CircleMinus]\ orth1 . sdp1 . orth1\[Transpose] \  // 
      Components\)], "Input",
  CellLabel->"In[81]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[81]:="],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output",
  CellLabel->"Out[81]=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{728, 740},
WindowMargins->{{Automatic, 128}, {77, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.3"->{
    Cell[5683, 208, 137, 4, 44, "Input",
      CellTags->"b:0.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.3", 13466, 532}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 179, 6, 72, "Subsection"],
Cell[1958, 61, 2424, 91, 240, "DefinitionBox"],
Cell[4385, 154, 408, 15, 29, "Text"],
Cell[4796, 171, 490, 20, 29, "Text"],
Cell[5289, 193, 391, 13, 29, "Text"],
Cell[5683, 208, 137, 4, 44, "Input",
  CellTags->"b:0.3"],
Cell[5823, 214, 57, 0, 29, "Text"],
Cell[5883, 216, 192, 7, 128, "Input"],

Cell[CellGroupData[{
Cell[6100, 227, 91, 2, 33, "Input"],
Cell[6194, 231, 221, 5, 27, "Print"],
Cell[6418, 238, 489, 12, 117, "Output"]
}, Open  ]],
Cell[6922, 253, 105, 2, 33, "Input"],
Cell[7030, 257, 117, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[7172, 266, 98, 2, 33, "Input"],
Cell[7273, 270, 221, 5, 27, "Print"],
Cell[7497, 277, 92, 2, 32, "Output"]
}, Open  ]],
Cell[7604, 282, 117, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[7746, 291, 68, 2, 33, "Input"],
Cell[7817, 295, 60, 2, 32, "Output"]
}, Open  ]],
Cell[7892, 300, 114, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[8031, 309, 67, 2, 33, "Input"],
Cell[8101, 313, 60, 2, 32, "Output"]
}, Open  ]],
Cell[8176, 318, 115, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[8316, 327, 82, 2, 33, "Input"],
Cell[8401, 331, 221, 5, 27, "Print"],
Cell[8625, 338, 92, 2, 32, "Output"]
}, Open  ]],
Cell[8732, 343, 57, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[8814, 347, 107, 2, 33, "Input"],
Cell[8924, 351, 221, 5, 27, "Print"],
Cell[9148, 358, 92, 2, 32, "Output"]
}, Open  ]],
Cell[9255, 363, 104, 2, 33, "Input"],
Cell[9362, 367, 114, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[9501, 376, 67, 2, 33, "Input"],
Cell[9571, 380, 60, 2, 32, "Output"]
}, Open  ]],
Cell[9646, 385, 115, 5, 29, "Text"],

Cell[CellGroupData[{
Cell[9786, 394, 82, 2, 33, "Input"],
Cell[9871, 398, 221, 5, 27, "Print"],
Cell[10095, 405, 92, 2, 32, "Output"]
}, Open  ]],
Cell[10202, 410, 56, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[10283, 414, 107, 2, 33, "Input"],
Cell[10393, 418, 221, 5, 27, "Print"],
Cell[10617, 425, 92, 2, 32, "Output"]
}, Open  ]],
Cell[10724, 430, 177, 8, 29, "Text"],

Cell[CellGroupData[{
Cell[10926, 442, 102, 2, 33, "Input"],
Cell[11031, 446, 221, 5, 27, "Print"],
Cell[11255, 453, 92, 2, 32, "Output"]
}, Open  ]],
Cell[11362, 458, 183, 8, 29, "Text"],

Cell[CellGroupData[{
Cell[11570, 470, 100, 2, 33, "Input"],
Cell[11673, 474, 221, 5, 27, "Print"],
Cell[11897, 481, 246, 5, 92, "Output"]
}, Open  ]],
Cell[12158, 489, 140, 4, 29, "Text"],

Cell[CellGroupData[{
Cell[12323, 497, 134, 3, 33, "Input"],
Cell[12460, 502, 221, 5, 27, "Print"],
Cell[12684, 509, 125, 3, 43, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

