(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      5512,        179]*)
(*NotebookOutlinePosition[      6197,        202]*)
(*  CellTagsIndexPosition[      6153,        198]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Predefined objects", "Section"]], "Section"],

Cell[TextData[{
  "The package Tens3D defines three predifined objects :\n\n\t- An \
orthonormal basis of the vectorial three dimensional space named ",
  StyleBox["CanonicalBasis",
    FontFamily->"Courier New"],
  ".\n\tNote that in any orthonormal basis the components ot a tensor in any \
variances are the same.\n\t\n\t- A rank 2 tensor named ",
  StyleBox["MetricTensor",
    FontFamily->"Courier New"],
  ".\n\t The components in ",
  StyleBox["CanonicalBasis",
    FontFamily->"Courier New"],
  " are stored in the identiy 3\[Times]3 matrix.\n\t\n\t- A rank 3 tensor \
named ",
  StyleBox["OrientationTensor",
    FontFamily->"Courier New"],
  ". \n\tThe components in ",
  StyleBox["CanonicalBasis",
    FontFamily->"Courier New"],
  " are stored in a 3\[Times]3\[Times]3 array :\n\t\t- value is 0 if two \
indicies are equal\n\t\t- value is 1 if the three indicies are in even \
permutation\n\t\t- value is -1 if the three indicies are in odd permuation."
}], "Text"],

Cell["\<\
For your convenience, you may easily rename these objects with more compact \
notations :\
\>", "Text",
  CellFrame->{{0, 0}, {0, 0.5}}],

Cell[BoxData[{
    \(\(Needs["\<Tens3D`\>"];\)\), "\[IndentingNewLine]", 
    \(\(G = MetricTensor;\)\), "\[IndentingNewLine]", 
    \(\(H = OrientationTensor;\)\), "\[IndentingNewLine]", 
    \(\(B0 = CanonicalBasis;\)\)}], "Input",
  CellLabel->"In[599]:="],

Cell["\<\
The contravariant-covariant components of the metric tensor are :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[G, {1, \(-1\)}, B0] // MatrixForm\)], "Input",
  CellLabel->"In[603]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"1", "0", "0"},
            {"0", "1", "0"},
            {"0", "0", "1"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[603]//MatrixForm="]
}, Open  ]],

Cell["\<\
The completely contravariant components of the orientation tensor are :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(compH = Components[H, {1, 1, 1}, B0]\)], "Input",
  CellLabel->"In[604]:="],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 0, 1}, {0, \(-1\), 0}}, {{0, 0, \(-1\)}, {0, 0, 
          0}, {1, 0, 0}}, {{0, 1, 0}, {\(-1\), 0, 0}, {0, 0, 0}}}\)], "Output",\

  CellLabel->"Out[604]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \({compH[\([1, 1, 3]\)], compH[\([1, 2, 3]\)], 
      compH[\([1, 3, 2]\)]}\)], "Input",
  CellLabel->"In[605]:="],

Cell[BoxData[
    \({0, 1, \(-1\)}\)], "Output",
  CellLabel->"Out[605]="]
}, Open  ]],

Cell[TextData[{
  "Note that because the canonical basis is orthonormal, the components in \
any variances are the same.\nIf you have previously defined another basis \
(see ",
  StyleBox[ButtonBox["DefineBasis",
    ButtonData:>{"DefineBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["DefineCoordinateSystem",
    ButtonData:>{"DefineCoordinateSystem", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  ", ",
  StyleBox[ButtonBox["NormalizedBasis",
    ButtonData:>{"NormalizedBasis", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "), you can ask the components of these tensors in any variance on this \
basis."
}], "Text",
  CellFrame->{{0, 0}, {0.5, 0}}],

Cell[TextData[{
  "See also ",
  StyleBox[ButtonBox["Components",
    ButtonData:>{"Components", None},
    ButtonStyle->"AddOnsLink"],
    FontFamily->"Courier New"],
  "."
}], "Text"]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{737, 740},
WindowMargins->{{319, Automatic}, {118, Automatic}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 68, 0, 80, "Section"],
Cell[1847, 55, 977, 22, 353, "Text"],
Cell[2827, 79, 146, 4, 39, "Text"],
Cell[2976, 85, 259, 5, 96, "Input"],
Cell[3238, 92, 89, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[3352, 98, 103, 2, 33, "Input"],
Cell[3458, 102, 395, 12, 81, "Output"]
}, Open  ]],
Cell[3868, 117, 95, 2, 29, "Text"],

Cell[CellGroupData[{
Cell[3988, 123, 95, 2, 33, "Input"],
Cell[4086, 127, 193, 4, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4316, 136, 132, 3, 33, "Input"],
Cell[4451, 141, 74, 2, 32, "Output"]
}, Open  ]],
Cell[4540, 146, 768, 21, 85, "Text"],
Cell[5311, 169, 185, 7, 29, "Text"]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

