(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     52852,       1883]*)
(*NotebookOutlinePosition[     53548,       1907]*)
(*  CellTagsIndexPosition[     53504,       1903]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Some examples", "Title"],

Cell[CellGroupData[{

Cell[TextData[{
  "Shortcuts ",
  StyleBox["(initialization cells)", "Text",
    FontSize->12,
    FontWeight->"Plain"]
}], "Section"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  InitializationCell->True],

Cell["We define short notations for the predefined objects", "Text",
  InitializationCell->True],

Cell[BoxData[{
    \(\(B0 = CanonicalBasis;\)\), "\[IndentingNewLine]", 
    \(\(G = MetricTensor;\)\), "\[IndentingNewLine]", 
    \(\(H = OrientationTensor;\)\)}], "Input",
  InitializationCell->True],

Cell["and names for the basis vectors of the canonical basis :", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\({e1, e2, e3} = BasisVectors[B0];\)\)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Definition of a coordinate system ",
  StyleBox["(initialization cells)", "Text",
    FontSize->12,
    FontWeight->"Plain"]
}], "Section",
  InitializationCell->True],

Cell["\<\
Uncomment one of the following coordinates systems or create four own \
coordinate system with the following conventions :
\t- coords is the list of the name of the coordinates,
\t- OM is the tens3D vector giving the point M function of the coordinates,
\t- CS is the name of the natural basis of the coordinate system,
\t- B1 is the name of the normalized basis.
With these conventions, all the further commands will run without editing.
\t\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
  "Example 1 : cylindrical coordinates system ",
  StyleBox["(uncommented cells)", "Text",
    FontSize->12,
    FontWeight->"Plain"]
}], "Subsection",
  InitializationCell->True],

Cell[TextData[{
  "Following assumptions are useful to help the ",
  StyleBox["Simplify",
    FontFamily->"Courier New"],
  " function :"
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\($Assumptions = \ $Assumptions\  && \ 
          r > 0\  && \ \[Theta] > 0\  && \ \[Theta] < 2\ Pi;\)\)], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["u ",
    FontFamily->"Courier New"],
  "is the polar unit vector in the plane ",
  StyleBox["(e1,e2)",
    FontFamily->"Courier New"],
  " :"
}], "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(u = \((Cos[\[Theta]]\[SmallCircle]
              e1)\)\ \[CirclePlus]\ \((Sin[\[Theta]]\[SmallCircle]\ 
              e2)\);\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Note : the vector is a function of \[Theta] :\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[PartialD]\_\[Theta]\ u // Components\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({\(-Sin[\[Theta]]\), Cos[\[Theta]], 0}\)], "Output"]
}, Open  ]],

Cell["\<\
In a cylindrical coordinate system, any point M is defined by :\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(OM = \ \((r\[SmallCircle]u\ )\)\ \[CirclePlus]\ \((z\[SmallCircle]
            e3)\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \(Tens3D`Private`Tensor$214\)], "Output"]
}, Open  ]],

Cell["\<\
Here is a shortcut for the list of the names of the coordinates :\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \(\(coords = {r, \[Theta], z};\)\)], "Input",
  InitializationCell->True],

Cell["\<\
Now we define the coordinates system. The result is the natural basis of the \
coordinates system.
Note that previous assumptions are necessary to find the orientation of the \
natural basis.\
\>", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(CS = DefineCoordinateSystem[OM, coords]\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \("Direct orthogonal natural basis."\)], "Print"],

Cell[BoxData[
    \(Tens3D`Private`Basis$220\)], "Output"]
}, Open  ]],

Cell["B1 is the normalized basis colinear to the natural basis :", "Text",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(B1 = NormalizedBasis[CS];\)\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    \("Direct normalized orthogonal basis."\)], "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Example 2 : cartesian coordinates system ",
  StyleBox["(commented cells)", "Text",
    FontSize->12,
    FontWeight->"Plain"]
}], "Subsection",
  InitializationCell->True],

Cell["\<\
If fou want use it in the following demonstrations, uncomment theses commands \
:\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \( (*\[IndentingNewLine]coords = {x, y, z}; \[IndentingNewLine]OM = 
        DefineTensor[coords, {1}, B0]; \[IndentingNewLine]CS = 
        DefineCoordinateSystem[OM, coords]; \[IndentingNewLine]B1 = 
        CS;\ \[IndentingNewLine]*) \)], "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Example 3: toro\[IHat]dal coordinate system ",
  StyleBox["(commented cells)", "Text",
    FontSize->12,
    FontWeight->"Plain"]
}], "Subsection",
  InitializationCell->True],

Cell["\<\
If fou want use it in the following demonstrations, uncomment theses commands \
:\
\>", "Text",
  InitializationCell->True],

Cell[BoxData[
    \( (*\[IndentingNewLine]coords = {r, \[Theta], \[Phi]}; \
\[IndentingNewLine]$Assumptions = 
        R > 0\  && \  && \ r > 0\  && \ 
          r < R\  && \ \[Theta] \[Element] Reals\  && \ \[Phi] \[Element] 
            Reals; \[IndentingNewLine]OM = 
        DefineTensor[{\[IndentingNewLine]\((R + r\ Cos[\[Phi]])\)\ Cos[
                theta], \[IndentingNewLine]\((R + r\ Cos[\[Phi]])\)\ Sin[
                theta], \[IndentingNewLine]r\ \
Sin[\[Phi]]\[IndentingNewLine]}, {1}, B0]; \[IndentingNewLine]CS = 
        DefineCoordinateSystem[OM, coords]; \[IndentingNewLine]B1 = 
        NormalizedBasis[CS];\[IndentingNewLine]*) \)], "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "Definition of some tensorial fields ",
  StyleBox["(initialization cells)", "Text",
    FontSize->12,
    FontWeight->"Plain"]
}], "Section",
  InitializationCell->True],

Cell["F1 and F2 are two scalar fields :", "Text",
  CellDingbat->"\[FilledCircle]",
  InitializationCell->True],

Cell[BoxData[{
    \(\(F1 = f1[Apply[Sequence, coords]];\)\), "\[IndentingNewLine]", 
    \(\(F2 = f2[Apply[Sequence, coords]];\)\)}], "Input",
  InitializationCell->True],

Cell[TextData[{
  StyleBox["V",
    FontFamily->"Courier"],
  " and ",
  StyleBox["W",
    FontFamily->"Courier New"],
  " are two vector fields :\n(note that they are defined by their components \
on the orthonormal basis ",
  StyleBox["B1",
    FontFamily->"Courier New"],
  StyleBox[")",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledCircle]",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[{
    \(V = DefineGeneralTensor[v, {1}, B1, coords]; 
    W = DefineGeneralTensor[w, {1}, B1, coords];\), "\[IndentingNewLine]", 
    \(Components[V, {1}, B1]\)}], "Input",
  InitializationCell->True],

Cell[BoxData[
    \({v1[r, \[Theta], z], v2[r, \[Theta], z], 
      v3[r, \[Theta], z]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[W, {1}, B0] // MatrixForm\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(Cos[\[Theta]]\ w1[r, \[Theta], z] - 
                  Sin[\[Theta]]\ w2[r, \[Theta], z]\)},
              {\(Sin[\[Theta]]\ w1[r, \[Theta], z] + 
                  Cos[\[Theta]]\ w2[r, \[Theta], z]\)},
              {\(w3[r, \[Theta], z]\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["T",
    FontFamily->"Courier"],
  " and ",
  StyleBox["S",
    FontFamily->"Courier New"],
  " are two vector fields :\n(note that they are defined by their components \
on the orthonormal basis ",
  StyleBox["B1",
    FontFamily->"Courier New"],
  StyleBox[")",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[FilledCircle]",
  InitializationCell->True],

Cell[BoxData[{
    \(\(T = 
        DefineGeneralTensor[t, {1, \(-1\)}, B1, 
          coords];\)\), "\[IndentingNewLine]", 
    \(\(S = DefineGeneralTensor[s, {1, \(-1\)}, B1, coords];\)\)}], "Input",
  InitializationCell->True],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[T, {1, \(-1\)}, B1] // MatrixForm\)], "Input",
  InitializationCell->True],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(t11[r, \[Theta], z]\), \(t12[r, \[Theta], z]\), \(t13[
                r, \[Theta], z]\)},
            {\(t21[r, \[Theta], z]\), \(t22[r, \[Theta], z]\), \(t23[
                r, \[Theta], z]\)},
            {\(t31[r, \[Theta], z]\), \(t32[r, \[Theta], z]\), \(t33[
                r, \[Theta], z]\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Using differential operators ", "Section"],

Cell["\<\
The results in this section will change with the choosen coordinates \
system.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Gradient of tensorial fields", "Subsection"],

Cell["The gradient of a scalar field is a vector :", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gradF1 = Gradient[F1, CS];\)\), "\[IndentingNewLine]", 
    \(Rank[gradF1]\)}], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[gradF1, {\(-1\)}, B1] // CompactDerivativeForm\)], "Input"],

Cell[BoxData[
    \({\[PartialD]\_r f1, \[PartialD]\_\[Theta] f1\/r, \[PartialD]\_z 
        f1}\)], "Output"]
}, Open  ]],

Cell["The gradient of a vector field is a rank 2 tensor", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(gradV = Gradient[V, CS];\)\), "\[IndentingNewLine]", 
    \(Rank[gradV]\)}], "Input"],

Cell[BoxData[
    \(2\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Components[gradV, {1, \(-1\)}, B1] // CompactDerivativeForm\) // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\[PartialD]\_r 
                v1\), \(\(\(-v2[r, \[Theta], z]\) + \[PartialD]\_\[Theta] 
                      v1\)\/r\), \(\[PartialD]\_z v1\)},
            {\(\[PartialD]\_r 
                v2\), \(\(v1[r, \[Theta], z] + \[PartialD]\_\[Theta] 
                      v2\)\/r\), \(\[PartialD]\_z v2\)},
            {\(\[PartialD]\_r 
                v3\), \(\[PartialD]\_\[Theta] v3\/r\), \(\[PartialD]\_z v3\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Divergence of tensorial fields", "Subsection"],

Cell["The divergence of a vector field is a scalar ", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[V, CS] // CompactDerivativeForm\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_z 
        v3 + \(v1[r, \[Theta], z] + \[PartialD]\_\[Theta] v2\)\/r + \
\[PartialD]\_r v1\)], "Output"]
}, Open  ]],

Cell["The divergence of a rank 2 tensorial field is a vector ", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(divT = Divergence[T, CS];\)\), "\[IndentingNewLine]", 
    \(Rank[divT]\)}], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Components[divT, {1}, B1] // CompactDerivativeForm\) // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(\[PartialD]\_z 
                    t13 + \(t11[r, \[Theta], z] - t22[r, \[Theta], z] + \
\[PartialD]\_\[Theta] t12\)\/r + \[PartialD]\_r t11\)},
              {\(\(t12[r, \[Theta], z] + t21[r, \[Theta], z] + 
                      r\ \[PartialD]\_z t23 + \[PartialD]\_\[Theta] t22 + 
                      r\ \[PartialD]\_r t21\)\/r\)},
              {\(\[PartialD]\_z 
                    t33 + \(t31[r, \[Theta], z] + \[PartialD]\_\[Theta] t32\)\
\/r + \[PartialD]\_r t31\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Curl of tensorial fields", "Subsection"],

Cell["The curl of a vector field is a vector field : ", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cuV = Curl[V, CS];\)\), "\[IndentingNewLine]", 
    \(Rank[cuV]\)}], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Components[cuV, {1}, B1] // \ CompactDerivativeForm\)\  // \ 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(\(-\[PartialD]\_z v2\) + \[PartialD]\_\[Theta] v3\/r\)},
              {\(\[PartialD]\_z v1 - \[PartialD]\_r v3\)},
              {\(\(v2[r, \[Theta], z] - \[PartialD]\_\[Theta] v1 + 
                      r\ \[PartialD]\_r v2\)\/r\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Laplacian of tensorial fields", "Subsection"],

Cell["The laplacian of a scalar field is a scalar field :", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[F1, CS] // CompactDerivativeForm\)], "Input"],

Cell[BoxData[
    \(\[PartialD]\_\(z\[InvisibleComma]z\)f1 + \(\[PartialD]\_\(\[Theta]\
\[InvisibleComma]\[Theta]\)f1 + r\ \[PartialD]\_r f1\)\/r\^2 + \
\[PartialD]\_\(r\[InvisibleComma]r\)f1\)], "Output"],

Cell["The laplacian of a vector field is a vector field :", "Text",
  CellDingbat->"\[FilledCircle]"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Components[Laplacian[V, CS], {1}, CS] // CompactDerivativeForm\) // 
      MatrixForm\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", 
        TagBox[GridBox[{
              {\(\[PartialD]\_\(z\[InvisibleComma]z\)v1 + \(\(-v1[r, \
\[Theta], z]\) - 2\ \[PartialD]\_\[Theta] v2 + \[PartialD]\_\(\[Theta]\
\[InvisibleComma]\[Theta]\)v1 + r\ \[PartialD]\_r v1\)\/r\^2 + \
\[PartialD]\_\(r\[InvisibleComma]r\)v1\)},
              {\(\(\(-v2[r, \[Theta], z]\) + 
                      r\^2\ \[PartialD]\_\(z\[InvisibleComma]z\)v2 + 
                      2\ \[PartialD]\_\[Theta] 
                          v1 + \[PartialD]\_\(\[Theta]\[InvisibleComma]\
\[Theta]\)v2 + r\ \[PartialD]\_r v2 + 
                      r\^2\ \[PartialD]\_\(r\[InvisibleComma]r\)v2\)\/r\^3\)},\

              {\(\[PartialD]\_\(z\[InvisibleComma]z\)v3 + \(\[PartialD]\_\(\
\[Theta]\[InvisibleComma]\[Theta]\)v3 + r\ \[PartialD]\_r v3\)\/r\^2 + \
\[PartialD]\_\(r\[InvisibleComma]r\)v3\)}
              },
            RowSpacings->1,
            ColumnAlignments->{Left}],
          Column], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Demonstration of some identities ", "Section"],

Cell["\<\
The results in this section do not vary with the choosen coordinates system. \
They are identities.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(H . V\ \[CircleMinus]\ \[IndentingNewLine]V . \ H // 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((H \[Colon] T)\)\ \[CircleMinus]\ \[IndentingNewLine]\((T \[Colon] \ 
            H)\)\  // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[OM, CS]\ \[CircleMinus]\ \[IndentingNewLine]G\  // 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[G, CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[H, CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
            0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}, {{{0, 0, 0}, {0, 0, 
            0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 
            0}, {0, 0, 0}, {0, 0, 0}}}, {{{0, 0, 0}, {0, 0, 0}, {0, 0, 
            0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 
            0}, {0, 0, 0}}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[F1\ F2, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          F1\ \[SmallCircle]Gradient[F2, CS]\ \[CirclePlus]\ 
            F2\[SmallCircle]Gradient[F1, CS]\ )\) // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[F1\[SmallCircle]V, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          F1\[SmallCircle]Gradient[V, CS]\ \[CirclePlus]\ 
            V\ \[CircleTimes]Gradient[F1, CS]\ )\) // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[F1\[SmallCircle]T, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          F1\[SmallCircle]Gradient[T, CS]\ \[CirclePlus]\ 
            T\ \[CircleTimes]Gradient[F1, CS]\ )\) // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell["\<\
grad grad of a scalar field  is a rank 2 symmetrical tensor :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Asym[Gradient[Gradient[F1, CS], CS]] // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["\<\
grad grad of a vectoriel field  is a rank 3 tensor, with symmetry on the two \
last indices :\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[Gradient[V, CS], CS] \[Colon] H\  // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[V . W, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          V\  . \ Gradient[W, CS]\ \[CirclePlus]\ 
            W . \ Gradient[V, CS]\ )\)\  // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
The following identity is true but the calculation is a little bit long:\
\>", "Text"],

Cell[BoxData[
    \( (*\[IndentingNewLine]Gradient[V\ \[Wedge]\ W, 
            CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
            H\  \[Colon] \((V\[CircleTimes]Gradient[W, CS]\ \[CircleMinus]\ 
                  W\ \[CircleTimes]\ Gradient[V, CS])\)\ )\) // \ 
        Components\[IndentingNewLine]*) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[T\  \[Colon] S, 
          CS]\ \[CircleMinus]\[IndentingNewLine]\((\ \((T \[Colon] 
                Gradient[S, CS])\)\ \[CirclePlus]\ \((S\  \[Colon] 
                Gradient[T, CS])\)\ )\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(Gradient[T\  \[Colon] G, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          G\  \[Colon] Gradient[T, CS])\)\ \  // \ 
      Components\)\(\[IndentingNewLine]\)
    \)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[T\  \[Colon] H, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          H\  \[Colon] Gradient[T, CS])\)\ \  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[T . V, CS]\[CircleMinus]\[IndentingNewLine]\((\ 
          V . Gradient[Transpose[T], CS]\ \[CirclePlus]\ 
            T . Gradient[V, CS])\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[V . T, CS]\[CircleMinus]\[IndentingNewLine]\((\ 
          V . Gradient[T, CS]\ \[CirclePlus]\ 
            Transpose[T] . Gradient[V, CS])\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[T\  \[Colon] S, 
          CS]\ \[CircleMinus]\[IndentingNewLine]\((\ \((S\  \[Colon] 
                Gradient[T, CS])\)\ \[CirclePlus]\ \((T\  \[Colon] \ 
                Gradient[S, CS])\)\ )\) // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[F1\[SmallCircle]V, CS]\  - \[IndentingNewLine]\((\ 
          F1\ \ Divergence[V, CS]\  + \ V\  . \ Gradient[F1, CS]\ )\)\  // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[F1\[SmallCircle]T, 
          CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          F1\ \[SmallCircle]Divergence[T, CS]\ \[CirclePlus]\ 
            T\  . \ Gradient[F1, CS]\ )\) // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[F1\[SmallCircle]G, 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]Gradient[F1, CS] // 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[F1\[SmallCircle]H, 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]H . Gradient[F1, CS] // 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[V\[CircleTimes]W, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          Gradient[V, CS] . W\ \[CirclePlus]\ 
            V\[SmallCircle]Divergence[W, CS]\ )\)\  // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[T . V, CS]\  - \[IndentingNewLine]\((\ 
          Divergence[Transpose[T], CS] . \ 
              V\  + \ \((Transpose[T]\  \[Colon] 
                Gradient[V, CS])\)\ )\)\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[V . T, 
          CS]\  - \[IndentingNewLine]\((V . \ 
              Divergence[T, CS]\  + \ \((Gradient[V, CS] \[Colon] 
                T)\)\ )\)\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[T . S, 
          CS]\ \[CircleMinus]\[IndentingNewLine]\((\ \((Gradient[T, 
                  CS] \[Colon] S)\)\ \[CirclePlus]\ 
            T\  . \ Divergence[S, CS])\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[V\  . \ H, CS]\ \[CircleMinus]\ \[IndentingNewLine]Curl[V, 
          CS]\  // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[H . \ V, CS]\ \[CircleMinus]\ \[IndentingNewLine]Curl[V, 
          CS]\  // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[T\  . \ H, CS]\ \[CircleMinus]\ \[IndentingNewLine]Curl[T, 
          CS]\  // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[H . \ T, CS]\ \[CircleMinus]\ \[IndentingNewLine]H . 
          Divergence[T, CS]\  // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[T\  \[Colon] H, CS]\  - \ \[IndentingNewLine]AutoContract[
          Gradient[T, CS] \[Colon] H] // Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[H\  \[Colon] T, CS]\  - \ \[IndentingNewLine]AutoContract[
          Gradient[T, CS] \[Colon] H] // Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[V\ \[Wedge]W, CS]\  - \[IndentingNewLine]\((\ 
          W . Curl[V, CS]\  - \ V . Curl[W, CS]\ )\) // Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[F1\[SmallCircle]V, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          F1\[SmallCircle]Curl[V, 
                CS]\ \[CirclePlus]\ \((Gradient[F1, CS]\[Wedge]\ V)\))\) // 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[F1\[SmallCircle]T, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          F1\[SmallCircle]Curl[T, CS]\ \[CircleMinus]\ \((\ 
              T\[CircleTimes]Gradient[F1, CS]\  \[Colon] H)\)\ )\) // 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[F1\[SmallCircle]G, 
          CS]\ \[CircleMinus]\ \ \[IndentingNewLine]Gradient[F1, CS] . 
          H\ \  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[V\  . \ H, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          Transpose[Gradient[V, CS]]\ \[CircleMinus]\ 
            Divergence[V, CS]\[SmallCircle]G\ )\) // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[H\  . \ V, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          Transpose[Gradient[V, CS]]\ \[CircleMinus]\ 
            Divergence[V, CS]\[SmallCircle]G\ )\) // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[T\  \[Colon] \ H, 
          CS]\ \[CircleMinus]\[IndentingNewLine]\((\ \ Divergence[T, 
              CS]\ \[CircleMinus]\ \ \ Divergence[Transpose[T], CS])\) // 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[H\  \[Colon] \ T, 
          CS]\ \[CircleMinus]\[IndentingNewLine]\((\ \ Divergence[T, 
              CS]\ \[CircleMinus]\ \ \ Divergence[Transpose[T], CS])\) // 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[V\ \[Wedge]\ W, 
          CS]\ \[CircleMinus]\[IndentingNewLine]\((\ \(V\[SmallCircle]
                Divergence[W, CS]\ \ \[CircleMinus]\ 
              W\[SmallCircle]Divergence[V, CS]\)\ \[CirclePlus]\ \(Gradient[
                  V, CS] . W\ \[CircleMinus]\ Gradient[W, CS] . V\))\)\  // \ 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[T . V, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          V . \ Curl[Transpose[T], 
                CS]\ \[CircleMinus]\ \((\((T . Gradient[V, CS])\)\  \[Colon] 
                H\ )\)\ )\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[V . T, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          V . \ Curl[T, 
                CS]\ \[CircleMinus]\ \[IndentingNewLine]\((\((Transpose[T] . 
                    Gradient[V, CS])\)\  \[Colon] H\ )\)\ )\)\  // \ 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[Sph[T], 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]\((1/3)\)\[SmallCircle]
            Gradient[AutoContract[T], CS] . \ H\ \  // \ 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[F1\ F2, 
          CS]\  - \ \[IndentingNewLine]\((\ \ F1\ Laplacian[F2, CS]\  + \ 
            F2\ Laplacian[F1, CS]\  + \ 
            2\ \((Gradient[F1, CS] . \ Gradient[F2, CS])\))\)\  // \ 
      Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[F1\[SmallCircle]V, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          F1\[SmallCircle]Laplacian[V, CS]\ \[CirclePlus]\ 
            V\ \[SmallCircle]Laplacian[F1, CS]\ \[CirclePlus]\ 
            2\[SmallCircle]Gradient[V, CS] . Gradient[F1, CS]\ )\)\  // \ 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[F1\[SmallCircle]T, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          F1\[SmallCircle]Laplacian[T, CS]\ \[CirclePlus]\ 
            T\ \[SmallCircle]Laplacian[F1, CS]\ \[CirclePlus]\ 
            2\[SmallCircle]Gradient[T, CS] . Gradient[F1, CS]\ )\)\  // \ 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[F1\[SmallCircle]G, 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]Laplacian[F1, 
            CS]\[SmallCircle]G\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[F1\[SmallCircle]H, 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]Laplacian[F1, 
            CS]\[SmallCircle]H\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[V . H, 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]Laplacian[V, CS] . \ 
          H\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[T . H, 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]Laplacian[T, CS] . \ 
          H\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[H . \ T, CS]\ \[CircleMinus]\ \[IndentingNewLine]H . 
          Laplacian[T, CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[H \[Colon] \ T, 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]\((H \[Colon] 
            Laplacian[T, CS])\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[\ T \[Colon] H, 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]\((Laplacian[T, 
              CS] \[Colon] H)\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[V . W, CS]\  - \ \[IndentingNewLine]\((\ 
          Laplacian[V, CS] . W\  + \ V . \ Laplacian[W, CS]\  + \ 
            2\ \((Gradient[V, CS] \[Colon] Gradient[W, CS]\ )\)\ )\)\  // 
      Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[AutoContract[T], CS]\  - \ \[IndentingNewLine]AutoContract[
          Laplacian[T, CS]]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[V, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          Gradient[Divergence[V, CS], CS]\ \ \[CircleMinus]\ 
            Curl[Curl[V, CS], CS]\ )\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell["\<\
The following identity is true but the calculation is a little bit long:\
\>", "Text"],

Cell[BoxData[
    \( (*\[IndentingNewLine]Laplacian[V\[Wedge]W, 
            CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
            Laplacian[V, CS]\[Wedge]W\ \[CirclePlus]\ 
              V\[Wedge]Laplacian[W, CS]\ \[CirclePlus]\ 
              2\[SmallCircle]\((H\  \[Colon] \ \((Gradient[V, CS]\  . 
                        Transpose[\ Gradient[W, CS]])\))\)\ )\)\  // \ 
        Components\[IndentingNewLine]*) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[Curl[V, CS], CS] // \ Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[Curl[T, CS], CS] // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Divergence[Transpose[Curl[T, CS]], 
          CS]\[CircleMinus]\[IndentingNewLine]Curl[
          Divergence[Transpose[T], CS], CS] // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[Gradient[F1, CS], CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[Gradient[V, CS], CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[Curl[V, CS], CS]\ \[CircleMinus]\[IndentingNewLine]Transpose[
          Curl[Transpose[Gradient[V, CS]], CS]]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["\<\
The following identity is true but the calculation is a little bit long:\
\>", "Text"],

Cell[BoxData[
    \( (*\[IndentingNewLine]Gradient[Curl[V, CS], 
            CS]\ \[CircleMinus]\[IndentingNewLine]\((\ \((\(-1\))\)\
\[SmallCircle]\((H \[Colon] Gradient[Gradient[V, CS], CS])\)\ )\)\  // \ 
        Components\[IndentingNewLine]*) \)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[Divergence[V, CS], 
          CS]\ \[CircleMinus]\[IndentingNewLine]Divergence[
          Transpose[Gradient[V, CS]], CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\((Curl[T, CS] \[Colon] \ H)\)\ \[CircleMinus]\[IndentingNewLine]\((\ 
          Gradient[AutoContract[T], 
              CS]\ \[CircleMinus]\ \[IndentingNewLine]Divergence[
              Transpose[T], CS]\ )\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[Curl[V, CS], CS]\ \[CircleMinus]\[IndentingNewLine]Curl[
          Laplacian[V, CS], CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[Curl[T, CS], CS]\ \[CircleMinus]\[IndentingNewLine]Curl[
          Laplacian[T, CS], CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[Divergence[V, CS], CS]\  - \ \[IndentingNewLine]Divergence[
          Laplacian[V, CS], CS]\  // \ Simplify\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[Divergence[T, CS], 
          CS]\ \[CircleMinus]\[IndentingNewLine]Divergence[Laplacian[T, CS], 
          CS]\  // Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[Gradient[F1, CS], 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]Gradient[Laplacian[F1, CS], 
          CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[Gradient[V, CS], 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]Gradient[Laplacian[V, CS], 
          CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Laplacian[Gradient[T, CS], 
          CS]\ \[CircleMinus]\ \[IndentingNewLine]Gradient[Laplacian[T, CS], 
          CS]\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Curl[T . S, CS]\ \[CircleMinus]\[IndentingNewLine]\((\ 
          T . \ Curl[S, 
                CS]\ \[CircleMinus]\ \((Gradient[T, 
                  CS] \[Colon] \((S . H)\))\)\ )\)\  // \ 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(V\[Wedge]Curl[W, 
            CS]\ \[CircleMinus]\ \[IndentingNewLine]\((V . 
              Gradient[W, CS]\ \[CircleMinus]\ Gradient[W, CS] . V)\)\  // \ 
      Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Gradient[V, CS]\  . \ 
          V\ \[CircleMinus]\[IndentingNewLine]\((\ \((1/2)\)\[SmallCircle]
              Gradient[V . V, CS]\ \[CircleMinus]\ 
            V\ \[Wedge]Curl[V, CS]\ )\)\  // \ Components\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print"],

Cell[BoxData[
    \({0, 0, 0}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
AutoGeneratedPackage->None,
CellGrouping->Manual,
WindowSize->{814, 740},
WindowMargins->{{Automatic, 223}, {Automatic, 91}}
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 30, 0, 117, "Title"],

Cell[CellGroupData[{
Cell[1831, 57, 134, 5, 92, "Section"],
Cell[1968, 64, 86, 2, 35, "Input",
  InitializationCell->True],
Cell[2057, 68, 96, 1, 38, "Text",
  InitializationCell->True],
Cell[2156, 71, 202, 4, 77, "Input",
  InitializationCell->True],
Cell[2361, 77, 100, 1, 38, "Text",
  InitializationCell->True],
Cell[2464, 80, 97, 2, 35, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[2598, 87, 186, 6, 54, "Section",
  InitializationCell->True],
Cell[2787, 95, 465, 9, 185, "Text"],

Cell[CellGroupData[{
Cell[3277, 108, 195, 6, 48, "Subsection",
  InitializationCell->True],
Cell[3475, 116, 177, 6, 38, "Text",
  InitializationCell->True],
Cell[3655, 124, 163, 3, 35, "Input",
  InitializationCell->True],
Cell[3821, 129, 209, 8, 38, "Text",
  InitializationCell->True],
Cell[4033, 139, 189, 4, 35, "Input",
  InitializationCell->True],
Cell[4225, 145, 97, 3, 38, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4347, 152, 99, 2, 35, "Input",
  InitializationCell->True],
Cell[4449, 156, 191, 4, 70, "Print"],
Cell[4643, 162, 72, 1, 70, "Output"]
}, Open  ]],
Cell[4730, 166, 115, 3, 38, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[4870, 173, 145, 3, 35, "Input",
  InitializationCell->True],
Cell[5018, 178, 59, 1, 70, "Output"]
}, Open  ]],
Cell[5092, 182, 117, 3, 38, "Text",
  InitializationCell->True],
Cell[5212, 187, 91, 2, 35, "Input",
  InitializationCell->True],
Cell[5306, 191, 243, 6, 59, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[5574, 201, 100, 2, 35, "Input",
  InitializationCell->True],
Cell[5677, 205, 67, 1, 70, "Print"],
Cell[5747, 208, 58, 1, 70, "Output"]
}, Open  ]],
Cell[5820, 212, 102, 1, 38, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[5947, 217, 90, 2, 35, "Input",
  InitializationCell->True],
Cell[6040, 221, 70, 1, 70, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[6159, 228, 191, 6, 37, "Subsection",
  InitializationCell->True],
Cell[6353, 236, 133, 4, 38, "Text",
  InitializationCell->True],
Cell[6489, 242, 296, 5, 140, "Input",
  InitializationCell->True]
}, Closed]],

Cell[CellGroupData[{
Cell[6822, 252, 194, 6, 37, "Subsection",
  InitializationCell->True],
Cell[7019, 260, 133, 4, 38, "Text",
  InitializationCell->True],
Cell[7155, 266, 693, 12, 245, "Input",
  InitializationCell->True]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7897, 284, 188, 6, 54, "Section",
  InitializationCell->True],
Cell[8088, 292, 111, 2, 38, "Text",
  InitializationCell->True],
Cell[8202, 296, 171, 3, 56, "Input",
  InitializationCell->True],
Cell[8376, 301, 399, 14, 59, "Text",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[8800, 319, 213, 4, 77, "Input",
  InitializationCell->True],
Cell[9016, 325, 101, 2, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[9154, 332, 97, 2, 35, "Input",
  InitializationCell->True],
Cell[9254, 336, 542, 14, 70, "Output"]
}, Open  ]],
Cell[9811, 353, 399, 14, 59, "Text",
  InitializationCell->True],
Cell[10213, 369, 229, 5, 56, "Input",
  InitializationCell->True],

Cell[CellGroupData[{
Cell[10467, 378, 105, 2, 35, "Input",
  InitializationCell->True],
Cell[10575, 382, 588, 14, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[11212, 402, 48, 0, 54, "Section"],
Cell[11263, 404, 102, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[11390, 411, 50, 0, 48, "Subsection"],
Cell[11443, 413, 94, 1, 38, "Text"],

Cell[CellGroupData[{
Cell[11562, 418, 111, 2, 56, "Input"],
Cell[11676, 422, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11748, 428, 90, 1, 35, "Input"],
Cell[11841, 431, 110, 2, 70, "Output"]
}, Open  ]],
Cell[11966, 436, 99, 1, 38, "Text"],

Cell[CellGroupData[{
Cell[12090, 441, 108, 2, 56, "Input"],
Cell[12201, 445, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12273, 451, 117, 2, 35, "Input"],
Cell[12393, 455, 701, 16, 70, "Output"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[13143, 477, 52, 0, 48, "Subsection"],
Cell[13198, 479, 95, 1, 38, "Text"],

Cell[CellGroupData[{
Cell[13318, 484, 75, 1, 35, "Input"],
Cell[13396, 487, 137, 3, 70, "Output"]
}, Open  ]],
Cell[13548, 493, 105, 1, 38, "Text"],

Cell[CellGroupData[{
Cell[13678, 498, 108, 2, 56, "Input"],
Cell[13789, 502, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13861, 508, 108, 2, 35, "Input"],
Cell[13972, 512, 778, 18, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[14799, 536, 46, 0, 37, "Subsection"],
Cell[14848, 538, 97, 1, 38, "Text"],

Cell[CellGroupData[{
Cell[14970, 543, 100, 2, 56, "Input"],
Cell[15073, 547, 35, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15145, 553, 113, 2, 35, "Input"],
Cell[15261, 557, 535, 13, 70, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[15845, 576, 51, 0, 37, "Subsection"],
Cell[15899, 578, 101, 1, 38, "Text"],

Cell[CellGroupData[{
Cell[16025, 583, 75, 1, 35, "Input"],
Cell[16103, 586, 205, 3, 70, "Output"],
Cell[16311, 591, 101, 1, 38, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16449, 597, 120, 2, 56, "Input"],
Cell[16572, 601, 1083, 23, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[17716, 631, 52, 0, 54, "Section"],
Cell[17771, 633, 123, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[17919, 640, 103, 2, 56, "Input"],
Cell[18025, 644, 191, 4, 30, "Print"],
Cell[18219, 650, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18323, 656, 137, 2, 56, "Input"],
Cell[18463, 660, 191, 4, 30, "Print"],
Cell[18657, 666, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[18737, 672, 110, 2, 56, "Input"],
Cell[18850, 676, 191, 4, 30, "Print"],
Cell[19044, 682, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19148, 688, 66, 1, 35, "Input"],
Cell[19217, 691, 191, 4, 30, "Print"],
Cell[19411, 697, 150, 2, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[19598, 704, 66, 1, 35, "Input"],
Cell[19667, 707, 191, 4, 30, "Print"],
Cell[19861, 713, 420, 6, 119, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20318, 724, 219, 3, 56, "Input"],
Cell[20540, 729, 191, 4, 30, "Print"],
Cell[20734, 735, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20814, 741, 228, 3, 56, "Input"],
Cell[21045, 746, 191, 4, 30, "Print"],
Cell[21239, 752, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21343, 758, 228, 3, 56, "Input"],
Cell[21574, 763, 191, 4, 30, "Print"],
Cell[21768, 769, 150, 2, 56, "Output"]
}, Open  ]],
Cell[21933, 774, 85, 2, 38, "Text"],

Cell[CellGroupData[{
Cell[22043, 780, 83, 1, 35, "Input"],
Cell[22129, 783, 191, 4, 30, "Print"],
Cell[22323, 789, 67, 1, 35, "Output"]
}, Open  ]],
Cell[22405, 793, 117, 3, 38, "Text"],

Cell[CellGroupData[{
Cell[22547, 800, 89, 1, 35, "Input"],
Cell[22639, 803, 191, 4, 30, "Print"],
Cell[22833, 809, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22937, 815, 198, 3, 56, "Input"],
Cell[23138, 820, 191, 4, 30, "Print"],
Cell[23332, 826, 43, 1, 35, "Output"]
}, Open  ]],
Cell[23390, 830, 96, 2, 38, "Text"],
Cell[23489, 834, 321, 5, 98, "Input"],

Cell[CellGroupData[{
Cell[23835, 843, 252, 4, 56, "Input"],
Cell[24090, 849, 191, 4, 30, "Print"],
Cell[24284, 855, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24364, 861, 206, 4, 77, "Input"],
Cell[24573, 867, 191, 4, 30, "Print"],
Cell[24767, 873, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24847, 879, 163, 2, 56, "Input"],
Cell[25013, 883, 191, 4, 30, "Print"],
Cell[25207, 889, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25311, 895, 201, 3, 56, "Input"],
Cell[25515, 900, 191, 4, 30, "Print"],
Cell[25709, 906, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[25813, 912, 201, 3, 56, "Input"],
Cell[26017, 917, 191, 4, 30, "Print"],
Cell[26211, 923, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26315, 929, 252, 4, 56, "Input"],
Cell[26570, 935, 191, 4, 30, "Print"],
Cell[26764, 941, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26844, 947, 186, 3, 56, "Input"],
Cell[27033, 952, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27105, 958, 236, 4, 56, "Input"],
Cell[27344, 964, 191, 4, 30, "Print"],
Cell[27538, 970, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27618, 976, 151, 3, 56, "Input"],
Cell[27772, 981, 191, 4, 30, "Print"],
Cell[27966, 987, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28046, 993, 155, 3, 56, "Input"],
Cell[28204, 998, 191, 4, 30, "Print"],
Cell[28398, 1004, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28502, 1010, 218, 3, 56, "Input"],
Cell[28723, 1015, 191, 4, 30, "Print"],
Cell[28917, 1021, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[28997, 1027, 233, 4, 77, "Input"],
Cell[29233, 1033, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29305, 1039, 207, 4, 56, "Input"],
Cell[29515, 1045, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29587, 1051, 232, 4, 56, "Input"],
Cell[29822, 1057, 191, 4, 30, "Print"],
Cell[30016, 1063, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30096, 1069, 133, 2, 56, "Input"],
Cell[30232, 1073, 191, 4, 30, "Print"],
Cell[30426, 1079, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30506, 1085, 131, 2, 56, "Input"],
Cell[30640, 1089, 191, 4, 30, "Print"],
Cell[30834, 1095, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[30914, 1101, 133, 2, 56, "Input"],
Cell[31050, 1105, 191, 4, 30, "Print"],
Cell[31244, 1111, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31348, 1117, 141, 2, 56, "Input"],
Cell[31492, 1121, 191, 4, 30, "Print"],
Cell[31686, 1127, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[31790, 1133, 152, 2, 56, "Input"],
Cell[31945, 1137, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32017, 1143, 152, 2, 56, "Input"],
Cell[32172, 1147, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32244, 1153, 155, 2, 56, "Input"],
Cell[32402, 1157, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32474, 1163, 229, 4, 56, "Input"],
Cell[32706, 1169, 191, 4, 30, "Print"],
Cell[32900, 1175, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32980, 1181, 249, 4, 56, "Input"],
Cell[33232, 1187, 191, 4, 30, "Print"],
Cell[33426, 1193, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33530, 1199, 161, 3, 56, "Input"],
Cell[33694, 1204, 191, 4, 30, "Print"],
Cell[33888, 1210, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33992, 1216, 211, 3, 56, "Input"],
Cell[34206, 1221, 191, 4, 30, "Print"],
Cell[34400, 1227, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34504, 1233, 211, 3, 56, "Input"],
Cell[34718, 1238, 191, 4, 30, "Print"],
Cell[34912, 1244, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35016, 1250, 218, 4, 56, "Input"],
Cell[35237, 1256, 191, 4, 30, "Print"],
Cell[35431, 1262, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35511, 1268, 218, 4, 56, "Input"],
Cell[35732, 1274, 191, 4, 30, "Print"],
Cell[35926, 1280, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36006, 1286, 352, 6, 77, "Input"],
Cell[36361, 1294, 191, 4, 30, "Print"],
Cell[36555, 1300, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36635, 1306, 248, 4, 77, "Input"],
Cell[36886, 1312, 191, 4, 30, "Print"],
Cell[37080, 1318, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37160, 1324, 278, 5, 77, "Input"],
Cell[37441, 1331, 191, 4, 30, "Print"],
Cell[37635, 1337, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37715, 1343, 195, 4, 56, "Input"],
Cell[37913, 1349, 191, 4, 30, "Print"],
Cell[38107, 1355, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38211, 1361, 252, 5, 77, "Input"],
Cell[38466, 1368, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38538, 1374, 321, 5, 77, "Input"],
Cell[38862, 1381, 191, 4, 30, "Print"],
Cell[39056, 1387, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39136, 1393, 321, 5, 77, "Input"],
Cell[39460, 1400, 191, 4, 30, "Print"],
Cell[39654, 1406, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[39758, 1412, 176, 3, 56, "Input"],
Cell[39937, 1417, 191, 4, 30, "Print"],
Cell[40131, 1423, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40235, 1429, 176, 3, 56, "Input"],
Cell[40414, 1434, 191, 4, 30, "Print"],
Cell[40608, 1440, 150, 2, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[40795, 1447, 152, 3, 56, "Input"],
Cell[40950, 1452, 191, 4, 30, "Print"],
Cell[41144, 1458, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41248, 1464, 152, 3, 56, "Input"],
Cell[41403, 1469, 191, 4, 30, "Print"],
Cell[41597, 1475, 150, 2, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[41784, 1482, 141, 2, 56, "Input"],
Cell[41928, 1486, 191, 4, 30, "Print"],
Cell[42122, 1492, 150, 2, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42309, 1499, 174, 3, 56, "Input"],
Cell[42486, 1504, 191, 4, 30, "Print"],
Cell[42680, 1510, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[42760, 1516, 176, 3, 56, "Input"],
Cell[42939, 1521, 191, 4, 30, "Print"],
Cell[43133, 1527, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43213, 1533, 241, 4, 77, "Input"],
Cell[43457, 1539, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43529, 1545, 146, 2, 56, "Input"],
Cell[43678, 1549, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[43750, 1555, 208, 3, 77, "Input"],
Cell[43961, 1560, 191, 4, 30, "Print"],
Cell[44155, 1566, 43, 1, 35, "Output"]
}, Open  ]],
Cell[44213, 1570, 96, 2, 38, "Text"],
Cell[44312, 1574, 429, 7, 140, "Input"],

Cell[CellGroupData[{
Cell[44766, 1585, 74, 1, 35, "Input"],
Cell[44843, 1588, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[44915, 1594, 76, 1, 35, "Input"],
Cell[44994, 1597, 191, 4, 30, "Print"],
Cell[45188, 1603, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45268, 1609, 180, 3, 56, "Input"],
Cell[45451, 1614, 191, 4, 30, "Print"],
Cell[45645, 1620, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[45725, 1626, 77, 1, 35, "Input"],
Cell[45805, 1629, 191, 4, 30, "Print"],
Cell[45999, 1635, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46079, 1641, 76, 1, 35, "Input"],
Cell[46158, 1644, 191, 4, 30, "Print"],
Cell[46352, 1650, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[46456, 1656, 169, 2, 56, "Input"],
Cell[46628, 1660, 191, 4, 30, "Print"],
Cell[46822, 1666, 67, 1, 35, "Output"]
}, Open  ]],
Cell[46904, 1670, 96, 2, 38, "Text"],
Cell[47003, 1674, 261, 4, 98, "Input"],

Cell[CellGroupData[{
Cell[47289, 1682, 181, 3, 56, "Input"],
Cell[47473, 1687, 191, 4, 30, "Print"],
Cell[47667, 1693, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[47747, 1699, 261, 4, 77, "Input"],
Cell[48011, 1705, 191, 4, 30, "Print"],
Cell[48205, 1711, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48285, 1717, 149, 2, 56, "Input"],
Cell[48437, 1721, 191, 4, 30, "Print"],
Cell[48631, 1727, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[48711, 1733, 149, 2, 56, "Input"],
Cell[48863, 1737, 191, 4, 30, "Print"],
Cell[49057, 1743, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49161, 1749, 150, 2, 56, "Input"],
Cell[49314, 1753, 35, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49386, 1759, 170, 3, 56, "Input"],
Cell[49559, 1764, 191, 4, 30, "Print"],
Cell[49753, 1770, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[49833, 1776, 172, 3, 56, "Input"],
Cell[50008, 1781, 191, 4, 30, "Print"],
Cell[50202, 1787, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50282, 1793, 170, 3, 56, "Input"],
Cell[50455, 1798, 191, 4, 30, "Print"],
Cell[50649, 1804, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[50753, 1810, 170, 3, 56, "Input"],
Cell[50926, 1815, 191, 4, 30, "Print"],
Cell[51120, 1821, 150, 2, 56, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51307, 1828, 242, 5, 56, "Input"],
Cell[51552, 1835, 191, 4, 30, "Print"],
Cell[51746, 1841, 67, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[51850, 1847, 205, 4, 56, "Input"],
Cell[52058, 1853, 191, 4, 30, "Print"],
Cell[52252, 1859, 43, 1, 35, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[52332, 1865, 240, 4, 56, "Input"],
Cell[52575, 1871, 191, 4, 30, "Print"],
Cell[52769, 1877, 43, 1, 35, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

