(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      7399,        266]*)
(*NotebookOutlinePosition[      9278,        327]*)
(*  CellTagsIndexPosition[      9208,        321]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["SmallCircle",
    FontFamily->"Courier New"],
  " or ",
  StyleBox["\[SmallCircle]",
    FontFamily->"Courier New"]
}], "Subsection",
  CellTags->"b:2.1"],

Cell[TextData[{
  StyleBox["SmallCircle[",
    FontFamily->"Courier New"],
  StyleBox["scalar",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " or \n",
  StyleBox["SmallCircle[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["scalar",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " or \n",
  StyleBox["scalar ",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  "\[SmallCircle] ",
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " or \n",
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  " \[SmallCircle] ",
  StyleBox["scalar",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  "  \nreturns the product of the Tens3D tensor ",
  StyleBox["tensor",
    FontSlant->"Italic"],
  " by the scalar ",
  StyleBox["scalar.",
    FontSlant->"Italic"],
  " "
}], "DefinitionBox",
  CellTags->"b:2.1"],

Cell[TextData[{
  "The precedence of ",
  StyleBox["SmallCircle",
    FontFamily->"Courier New"],
  " being higher than the precedence of ",
  StyleBox["CirclePlus",
    FontFamily->"Courier New"],
  " and ",
  StyleBox["CircleMinus",
    FontFamily->"Courier New"],
  ", ",
  StyleBox["a\[SmallCircle]T1\[CirclePlus]T2",
    FontFamily->"Courier New"],
  " is interpreted as usual ",
  StyleBox["(a\[SmallCircle]T1)\[CirclePlus]T2",
    FontFamily->"Courier New"],
  "."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:2.1"],

Cell[TextData[{
  StyleBox["SmallCircle",
    FontFamily->"Courier New"],
  " remains unevaluated if arguments are not a scalar and a tens3D tensor."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:2.1"],

Cell[TextData[{
  "Symbol \[SmallCircle] may be found in the front end menu \
File/Palettes/CompleteCharacters/Operators or rapidly typed with \
\[EscapeKey]",
  StyleBox["sc\[EscapeKey]",
    FontFamily->"Courier New"]
}], "Text",
  CellDingbat->"\[GraySquare]",
  CellTags->"b:2.1"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[90]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:2.1"],

Cell["T is a rank 2 tensor :", "Text",
  CellTags->"b:2.1"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(T = 
        DefineGeneralTensor[t, {1, \(-1\)}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(T // Components\) // MatrixForm\)}], "Input",
  CellLabel->"In[91]:=",
  CellTags->"b:2.1"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[91]:=",
  CellTags->"b:2.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"t11", "t12", "t13"},
            {"t21", "t22", "t23"},
            {"t31", "t32", "t33"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[92]//MatrixForm=",
  CellTags->"b:2.1"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(3\ \[SmallCircle]\ T\  // Components\) // MatrixForm\)], "Input",
  CellLabel->"In[93]:=",
  CellTags->"b:2.1"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[93]:=",
  CellTags->"b:2.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(3\ t11\), \(3\ t12\), \(3\ t13\)},
            {\(3\ t21\), \(3\ t22\), \(3\ t23\)},
            {\(3\ t31\), \(3\ t32\), \(3\ t33\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[93]//MatrixForm=",
  CellTags->"b:2.1"]
}, Open  ]],

Cell["\<\
Note the necessary parenthesis around  the scalar expressions :\
\>", "Text",
  CellTags->"b:2.1"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\((1/2)\)\ \[SmallCircle]\ T\  // Components\) // 
      MatrixForm\)], "Input",
  CellLabel->"In[94]:=",
  CellTags->"b:2.1"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[94]:=",
  CellTags->"b:2.1"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(t11\/2\), \(t12\/2\), \(t13\/2\)},
            {\(t21\/2\), \(t22\/2\), \(t23\/2\)},
            {\(t31\/2\), \(t32\/2\), \(t33\/2\)}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[94]//MatrixForm=",
  CellFrame->{{0, 0}, {0.5, 0}},
  CellTags->"b:2.1"]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{632, 740},
WindowMargins->{{Automatic, 98}, {68, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:2.1"->{
    Cell[1776, 53, 182, 7, 49, "Subsection",
      CellTags->"b:2.1"],
    Cell[1961, 62, 1276, 50, 126, "DefinitionBox",
      CellTags->"b:2.1"],
    Cell[3240, 114, 538, 19, 48, "Text",
      CellTags->"b:2.1"],
    Cell[3781, 135, 216, 6, 29, "Text",
      CellTags->"b:2.1"],
    Cell[4000, 143, 284, 8, 48, "Text",
      CellTags->"b:2.1"],
    Cell[4287, 153, 137, 4, 44, "Input",
      CellTags->"b:2.1"],
    Cell[4427, 159, 59, 1, 29, "Text",
      CellTags->"b:2.1"],
    Cell[4511, 164, 228, 6, 54, "Input",
      CellTags->"b:2.1"],
    Cell[4742, 172, 242, 6, 27, "Print",
      CellTags->"b:2.1"],
    Cell[4987, 180, 433, 13, 81, "Output",
      CellTags->"b:2.1"],
    Cell[5457, 198, 133, 3, 33, "Input",
      CellTags->"b:2.1"],
    Cell[5593, 203, 242, 6, 27, "Print",
      CellTags->"b:2.1"],
    Cell[5838, 211, 478, 13, 81, "Output",
      CellTags->"b:2.1"],
    Cell[6331, 227, 108, 3, 29, "Text",
      CellTags->"b:2.1"],
    Cell[6464, 234, 148, 4, 33, "Input",
      CellTags->"b:2.1"],
    Cell[6615, 240, 242, 6, 27, "Print",
      CellTags->"b:2.1"],
    Cell[6860, 248, 511, 14, 122, "Output",
      CellTags->"b:2.1"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:2.1", 8027, 282}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 182, 7, 49, "Subsection",
  CellTags->"b:2.1"],
Cell[1961, 62, 1276, 50, 126, "DefinitionBox",
  CellTags->"b:2.1"],
Cell[3240, 114, 538, 19, 48, "Text",
  CellTags->"b:2.1"],
Cell[3781, 135, 216, 6, 29, "Text",
  CellTags->"b:2.1"],
Cell[4000, 143, 284, 8, 48, "Text",
  CellTags->"b:2.1"],
Cell[4287, 153, 137, 4, 44, "Input",
  CellTags->"b:2.1"],
Cell[4427, 159, 59, 1, 29, "Text",
  CellTags->"b:2.1"],

Cell[CellGroupData[{
Cell[4511, 164, 228, 6, 54, "Input",
  CellTags->"b:2.1"],
Cell[4742, 172, 242, 6, 27, "Print",
  CellTags->"b:2.1"],
Cell[4987, 180, 433, 13, 81, "Output",
  CellTags->"b:2.1"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5457, 198, 133, 3, 33, "Input",
  CellTags->"b:2.1"],
Cell[5593, 203, 242, 6, 27, "Print",
  CellTags->"b:2.1"],
Cell[5838, 211, 478, 13, 81, "Output",
  CellTags->"b:2.1"]
}, Open  ]],
Cell[6331, 227, 108, 3, 29, "Text",
  CellTags->"b:2.1"],

Cell[CellGroupData[{
Cell[6464, 234, 148, 4, 33, "Input",
  CellTags->"b:2.1"],
Cell[6615, 240, 242, 6, 27, "Print",
  CellTags->"b:2.1"],
Cell[6860, 248, 511, 14, 122, "Output",
  CellTags->"b:2.1"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

