(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8393,        294]*)
(*NotebookOutlinePosition[      9452,        331]*)
(*  CellTagsIndexPosition[      9382,        325]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[StyleBox["Transpose",
  FontFamily->"Courier New"]], "Subsection"],

Cell[TextData[{
  StyleBox["Transpose[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  " transposes the first two indices of the Tens3D tensor.\n\n",
  StyleBox["Transpose[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",{n1,n2,...}] ",
    FontFamily->"Courier New"],
  " transposes the Tens3D tensor so that the ",
  StyleBox["k", "TI"],
  Cell[BoxData[
      \(TraditionalForm\`\[Null]\^th\)], "InlineFormula"],
  " indice in ",
  StyleBox["list", "TI"],
  " is the ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["n",
            "TI"], 
          StyleBox["k",
            "TI"]], TraditionalForm]], "InlineFormula"],
  Cell[BoxData[
      \(TraditionalForm\`\[Null]\^th\)], "InlineFormula"],
  " indice in the result. "
}], "DefinitionBox"],

Cell[TextData[{
  StyleBox["Transpose",
    FontFamily->"Courier New"],
  " is an over definition of the classical ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Transpose",
    FontFamily->"Courier New"],
  ". The syntax is exactly the same. If the argument is not a Tens3D tensor, \
the classical ",
  StyleBox["Transpose",
    FontFamily->"Courier New"],
  " is applied."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[TextData[{
  StyleBox["You may use the notation ",
    FontFamily->"Times New Roman"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["\[Transpose] (equivalent to  ",
    FontFamily->"Times New Roman"],
  StyleBox["Transpose[",
    FontFamily->"Courier New"],
  StyleBox["tensor",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  StyleBox[")",
    FontFamily->"Times New Roman"],
  ". The keyboard shortcut is \[EscapeKey]",
  StyleBox["tr",
    FontFamily->"Courier New"],
  "\[EscapeKey]."
}], "Text",
  CellDingbat->"\[FilledSquare]"],

Cell[BoxData[
    \(\(Needs["\<Tens3D`\>"];\)\)], "Input",
  CellLabel->"In[37]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.6"],

Cell["We define a rank 2 tensor :", "Text",
  CellDingbat->"\[FilledCircle]",
  CellTags->"b:0.6"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(T = 
        DefineGeneralTensor[t, {1, 1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(Transpose[T]\  // \ Components\)\  // \ MatrixForm\)}], "Input",
  CellLabel->"In[38]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[38]:=",
  CellTags->"b:0.6"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"t11", "t21", "t31"},
            {"t12", "t22", "t32"},
            {"t13", "t23", "t33"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[39]//MatrixForm=",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Transpose[T, {2, 1}]\  // \ Components\)\  // \ MatrixForm\)], "Input",\

  CellLabel->"In[40]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[40]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"t11", "t21", "t31"},
            {"t12", "t22", "t32"},
            {"t13", "t23", "t33"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[40]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
  "He we use the classical ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "'s ",
  StyleBox["Transpose",
    FontFamily->"Courier New"],
  StyleBox[" ",
    FontFamily->"Times New Roman"],
  StyleBox[":",
    FontFamily->"Times New Roman"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[T // \ Components]\ \  // \ MatrixForm\)], "Input",
  CellLabel->"In[41]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[41]:="],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {"t11", "t21", "t31"},
            {"t12", "t22", "t32"},
            {"t13", "t23", "t33"}
            },
          RowSpacings->1,
          ColumnSpacings->1,
          ColumnAlignments->{Left}], "\[NoBreak]", ")"}],
      Function[ BoxForm`e$, 
        MatrixForm[ BoxForm`e$]]]], "Output",
  CellLabel->"Out[41]//MatrixForm="]
}, Open  ]],

Cell["The orientation tensor is antisymmetric :", "Text",
  CellDingbat->"\[FilledCircle]"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[
          OrientationTensor, {1, 3, 2}]\[CirclePlus]OrientationTensor\  // \ 
      Components\)], "Input",
  CellLabel->"In[42]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[42]:="],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\)], "Output",
  CellLabel->"Out[42]="]
}, Open  ]],

Cell["Even permutations leave it invariant :", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Transpose[OrientationTensor, {3, 1, 2}]\[CircleMinus]\ 
        OrientationTensor\  // \ Components\)], "Input",
  CellLabel->"In[43]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[43]:="],

Cell[BoxData[
    \({{{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}, {{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}}\)], "Output",
  CellLabel->"Out[43]=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{758, 740},
WindowMargins->{{Automatic, 74}, {71, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.6"->{
    Cell[3939, 132, 137, 4, 44, "Input",
      CellTags->"b:0.6"],
    Cell[4079, 138, 98, 2, 29, "Text",
      CellTags->"b:0.6"],
    Cell[4202, 144, 242, 6, 54, "Input",
      CellTags->"b:0.6"],
    Cell[4447, 152, 242, 6, 27, "Print",
      CellTags->"b:0.6"],
    Cell[4692, 160, 433, 13, 81, "Output",
      CellTags->"b:0.6"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.6", 9021, 310}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 80, 1, 47, "Subsection"],
Cell[1859, 56, 972, 33, 107, "DefinitionBox"],
Cell[2834, 91, 449, 15, 48, "Text"],
Cell[3286, 108, 650, 22, 29, "Text"],
Cell[3939, 132, 137, 4, 44, "Input",
  CellTags->"b:0.6"],
Cell[4079, 138, 98, 2, 29, "Text",
  CellTags->"b:0.6"],

Cell[CellGroupData[{
Cell[4202, 144, 242, 6, 54, "Input",
  CellTags->"b:0.6"],
Cell[4447, 152, 242, 6, 27, "Print",
  CellTags->"b:0.6"],
Cell[4692, 160, 433, 13, 81, "Output",
  CellTags->"b:0.6"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5162, 178, 120, 3, 33, "Input"],
Cell[5285, 183, 221, 5, 27, "Print"],
Cell[5509, 190, 412, 12, 81, "Output"]
}, Open  ]],
Cell[5936, 205, 277, 11, 29, "Text"],

Cell[CellGroupData[{
Cell[6238, 220, 106, 2, 33, "Input"],
Cell[6347, 224, 221, 5, 27, "Print"],
Cell[6571, 231, 412, 12, 81, "Output"]
}, Open  ]],
Cell[6998, 246, 91, 1, 29, "Text"],

Cell[CellGroupData[{
Cell[7114, 251, 163, 4, 54, "Input"],
Cell[7280, 257, 221, 5, 27, "Print"],
Cell[7504, 264, 175, 3, 53, "Output"]
}, Open  ]],
Cell[7694, 270, 54, 0, 29, "Text"],

Cell[CellGroupData[{
Cell[7773, 274, 157, 3, 54, "Input"],
Cell[7933, 279, 221, 5, 27, "Print"],
Cell[8157, 286, 208, 4, 64, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

