(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.2'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      6039,        215]*)
(*NotebookOutlinePosition[      7095,        252]*)
(*  CellTagsIndexPosition[      7025,        246]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
  StyleBox["Wedge or ",
    FontFamily->"Courier New"],
  Cell[BoxData[
      \(TraditionalForm\`\[Wedge]\)],
    FontFamily->"Courier New"]
}], "Subsection"],

Cell[TextData[{
  StyleBox["Wedge[",
    FontFamily->"Courier New"],
  StyleBox["vector1",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox[",",
    FontFamily->"Courier New"],
  StyleBox["vector2",
    FontFamily->"Times New Roman",
    FontSlant->"Italic"],
  StyleBox["]",
    FontFamily->"Courier New"],
  "  or ",
  StyleBox["vector1",
    FontSlant->"Italic"],
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Wedge]",
            FontFamily->"Courier New"], 
          RowBox[{
            StyleBox["vector2",
              FontSlant->"Italic"], "  ", "returns"}]}], TraditionalForm]]],
  " the cross product of the two Tens3D vectors (rank 1 Tens3D tensors)."
}], "DefinitionBox"],

Cell[TextData[{
  StyleBox["Wedge",
    FontFamily->"Courier New"],
  " remains unevaluated if one argument is not a rank 1 Tens3D tensor."
}], "Text",
  CellDingbat->"\[FilledSquare]",
  CellTags->"b:0.3"],

Cell[TextData[{
  "Symbol ",
  Cell[BoxData[
      \(TraditionalForm\`\[Wedge]\)]],
  " may be found in the front end menu \
File/Palettes/CompleteCharacters/Operators or rapidly typed with \
\[EscapeKey]",
  StyleBox["^\[EscapeKey]",
    FontFamily->"Courier New"],
  StyleBox[". ",
    FontFamily->"Times New Roman"],
  StyleBox["It is not the same than ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["\[And] ",
    FontFamily->"Times New Roman"],
  StyleBox[" ",
    FontFamily->"Times New Roman",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["(",
    FontFamily->"Times New Roman"],
  StyleBox["And",
    FontFamily->"Courier New"],
  StyleBox[").",
    FontFamily->"Times New Roman"]
}], "Text",
  CellDingbat->"\[GraySquare]",
  CellTags->"b:0.3"],

Cell[TextData[{
  "The french notation \[Wedge] for the cross product has been prefered \
because the symbol \[Times] is interpreted as ",
  StyleBox["Times",
    FontFamily->"Courier New"],
  " in ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellDingbat->"\[GraySquare]",
  CellTags->"b:0.3"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Needs["\<Tens3D`\>"];\)\), "\[IndentingNewLine]", 
    \(\(E1 = DefineTensor[{0, 1, 1}, {1}, CanonicalBasis];\)\), "\n", 
    \(\(E2 = DefineTensor[{1, 0, 1}, {1}, CanonicalBasis];\)\), "\n", 
    \(\(E3 = DefineTensor[{1, 1, 0}, {1}, CanonicalBasis];\)\), "\n", 
    \(\(basis = DefineBasis[E1, E2, E3];\)\)}], "Input",
  CellLabel->"In[7]:=",
  CellFrame->{{0, 0}, {0, 0.5}},
  CellTags->"b:0.3"],

Cell[BoxData[
    \("Direct basis."\)], "Print",
  CellLabel->"From In[7]:=",
  CellTags->"b:0.3"]
}, Open  ]],

Cell[BoxData[{
    \(\(v1 = 
        DefineTensor[{a1, b1, c1}, {1}, 
          CanonicalBasis];\)\), "\[IndentingNewLine]", 
    \(\(v2 = DefineTensor[{a1, b1, c1}, {1}, basis];\)\)}], "Input",
  CellLabel->"In[12]:="],

Cell[CellGroupData[{

Cell[BoxData[
    \(Components[v2, {1}, CanonicalBasis]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \({b1 + c1, a1 + c1, a1 + b1}\)], "Output",
  CellLabel->"Out[14]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(v1\[Wedge]v2 // Components\)], "Input",
  CellLabel->"In[15]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[15]:="],

Cell[BoxData[
    \({\((b1 - c1)\)\ \((a1 + b1 + c1)\), \(-\((a1 - c1)\)\)\ \((a1 + b1 + 
            c1)\), \((a1 - b1)\)\ \((a1 + b1 + c1)\)}\)], "Output",
  CellLabel->"Out[15]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(v2\[Wedge]v2 // Components\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    InterpretationBox[\("Note: Components in "\[InvisibleSpace]CanonicalBasis\
\),
      SequenceForm[ "Note: Components in ", CanonicalBasis],
      Editable->False]], "Print",
  CellLabel->"From In[16]:="],

Cell[BoxData[
    \({0, 0, 0}\)], "Output",
  CellLabel->"Out[16]=",
  CellFrame->{{0, 0}, {0.5, 0}}]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.2 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 979}},
WindowSize->{668, 740},
WindowMargins->{{Automatic, 46}, {60, Automatic}},
StyleDefinitions -> "HelpTens3D.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "b:0.3"->{
    Cell[2688, 88, 206, 6, 29, "Text",
      CellTags->"b:0.3"],
    Cell[2897, 96, 821, 29, 49, "Text",
      CellTags->"b:0.3"],
    Cell[3721, 127, 323, 11, 48, "Text",
      CellTags->"b:0.3"],
    Cell[4069, 142, 421, 8, 128, "Input",
      CellTags->"b:0.3"],
    Cell[4493, 152, 98, 3, 27, "Print",
      CellTags->"b:0.3"]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"b:0.3", 6667, 231}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 174, 6, 47, "Subsection"],
Cell[1953, 61, 732, 25, 69, "DefinitionBox"],
Cell[2688, 88, 206, 6, 29, "Text",
  CellTags->"b:0.3"],
Cell[2897, 96, 821, 29, 49, "Text",
  CellTags->"b:0.3"],
Cell[3721, 127, 323, 11, 48, "Text",
  CellTags->"b:0.3"],

Cell[CellGroupData[{
Cell[4069, 142, 421, 8, 128, "Input",
  CellTags->"b:0.3"],
Cell[4493, 152, 98, 3, 27, "Print",
  CellTags->"b:0.3"]
}, Open  ]],
Cell[4606, 158, 219, 5, 54, "Input"],

Cell[CellGroupData[{
Cell[4850, 167, 93, 2, 33, "Input"],
Cell[4946, 171, 86, 2, 32, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5069, 178, 84, 2, 33, "Input"],
Cell[5156, 182, 221, 5, 27, "Print"],
Cell[5380, 189, 182, 3, 53, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5599, 197, 84, 2, 33, "Input"],
Cell[5686, 201, 221, 5, 27, "Print"],
Cell[5910, 208, 101, 3, 43, "Output"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

